@@ -14,9 +14,10 @@
 static GWENHYWFAR_CB
 int Gtk2Gui_WScrollArea_SetIntProperty(GWEN_WIDGET *w,
                                        GWEN_DIALOG_PROPERTY prop,
-                                       int index,
+                                       GWEN_UNUSED int index,
                                        int value,
-                                       int doSignal) {
+                                       GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -25,7 +26,7 @@ int Gtk2Gui_WScrollArea_SetIntProperty(GWEN_WIDGET *w,
   gs=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(gs);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(gs), (value==0)?FALSE:TRUE);
     return 0;
@@ -55,8 +56,9 @@ int Gtk2Gui_WScrollArea_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WScrollArea_GetIntProperty(GWEN_WIDGET *w,
                                        GWEN_DIALOG_PROPERTY prop,
-                                       int index,
-                                       int defaultValue) {
+                                       GWEN_UNUSED int index,
+                                       int defaultValue)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -68,7 +70,7 @@ int Gtk2Gui_WScrollArea_GetIntProperty(GWEN_WIDGET *w,
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_CONTENT));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(gs))==TRUE)?1:0;
 
@@ -95,10 +97,11 @@ int Gtk2Gui_WScrollArea_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WScrollArea_SetCharProperty(GWEN_WIDGET *w,
-                                        GWEN_DIALOG_PROPERTY prop,
-                                        int index,
-                                        const char *value,
-                                        int doSignal) {
+                                        GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                        GWEN_UNUSED int index,
+                                        GWEN_UNUSED const char *value,
+                                        GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;         /* scrollable window */
   GtkWidget *gContent;  /* vbox */
 
@@ -116,10 +119,11 @@ int Gtk2Gui_WScrollArea_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WScrollArea_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk2Gui_WScrollArea_GetCharProperty(GWEN_WIDGET *w,
+                                                GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                                GWEN_UNUSED int index,
+                                                const char *defaultValue)
+{
   GtkWidget *gs; /* scrollable window */
   GtkWidget *g;  /* vbox */
 
@@ -137,7 +141,8 @@ const char* Gtk2Gui_WScrollArea_GetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-int Gtk2Gui_WScrollArea_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
+int Gtk2Gui_WScrollArea_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild)
+{
   GtkWidget *g;
   GtkWidget *gChild;
   uint32_t cflags;
@@ -160,13 +165,14 @@ int Gtk2Gui_WScrollArea_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
 
 
 
-int Gtk2Gui_WScrollArea_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WScrollArea_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   GtkWidget *gContent;
-  uint32_t flags;
+  /*uint32_t flags;*/
   GWEN_WIDGET *wParent;
 
-  flags=GWEN_Widget_GetFlags(w);
+  /*flags=GWEN_Widget_GetFlags(w);*/
   wParent=GWEN_Widget_Tree_GetParent(w);
 
   /* create widget */
@@ -174,8 +180,8 @@ int Gtk2Gui_WScrollArea_Setup(GWEN_WIDGET *w) {
   gContent=gtk_vbox_new(TRUE, GTK2_GUI_DIALOG_DEFAULT_BOX_SPACING);
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(g), gContent);
 
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) gContent);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) gContent);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WScrollArea_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WScrollArea_GetIntProperty);
