@@ -26,15 +26,16 @@ GWEN_INHERIT(GWEN_WIDGET, GTK3_GRIDLAYOUT_WIDGET)
 static GWENHYWFAR_CB
 int Gtk3Gui_WGridLayout_SetIntProperty(GWEN_WIDGET *w,
                                        GWEN_DIALOG_PROPERTY prop,
-                                       int index,
+                                       GWEN_UNUSED int index,
                                        int value,
-                                       int doSignal) {
+                                       GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -59,14 +60,15 @@ int Gtk3Gui_WGridLayout_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk3Gui_WGridLayout_GetIntProperty(GWEN_WIDGET *w,
                                        GWEN_DIALOG_PROPERTY prop,
-                                       int index,
-                                       int defaultValue) {
+                                       GWEN_UNUSED int index,
+                                       int defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -88,10 +90,11 @@ int Gtk3Gui_WGridLayout_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk3Gui_WGridLayout_SetCharProperty(GWEN_WIDGET *w,
-                                        GWEN_DIALOG_PROPERTY prop,
-                                        int index,
-                                        const char *value,
-                                        int doSignal) {
+                                        GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                        GWEN_UNUSED int index,
+                                        GWEN_UNUSED const char *value,
+                                        GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
@@ -106,10 +109,11 @@ int Gtk3Gui_WGridLayout_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk3Gui_WGridLayout_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk3Gui_WGridLayout_GetCharProperty(GWEN_WIDGET *w,
+                                                GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                                GWEN_UNUSED int index,
+                                                const char *defaultValue)
+{
   GtkWidget *g;
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
@@ -124,11 +128,11 @@ const char* Gtk3Gui_WGridLayout_GetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-int Gtk3Gui_WGridLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
+int Gtk3Gui_WGridLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild)
+{
   GTK3_GRIDLAYOUT_WIDGET *xw;
   GtkWidget *g;
   GtkWidget *gChild;
-  uint32_t cflags;
   int x;
   int y;
 
@@ -136,7 +140,6 @@ int Gtk3Gui_WGridLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
   xw=GWEN_INHERIT_GETDATA(GWEN_WIDGET, GTK3_GRIDLAYOUT_WIDGET, w);
   assert(xw);
 
-  cflags=GWEN_Widget_GetFlags(wChild);
 
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
@@ -182,19 +185,20 @@ int Gtk3Gui_WGridLayout_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
 
 
 static GWENHYWFAR_CB
-void Gtk3Gui_WGridLayout_FreeData(void *bp, void *p) {
+void Gtk3Gui_WGridLayout_FreeData(GWEN_UNUSED void *bp, void *p)
+{
   GTK3_GRIDLAYOUT_WIDGET *xw;
 
-  xw=(GTK3_GRIDLAYOUT_WIDGET*) p;
+  xw=(GTK3_GRIDLAYOUT_WIDGET *) p;
 
   GWEN_FREE_OBJECT(xw);
 }
 
 
 
-int Gtk3Gui_WGridLayout_Setup(GWEN_WIDGET *w) {
+int Gtk3Gui_WGridLayout_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
-  uint32_t flags;
   GWEN_WIDGET *wParent;
   GTK3_GRIDLAYOUT_WIDGET *xw;
   int rows;
@@ -203,7 +207,6 @@ int Gtk3Gui_WGridLayout_Setup(GWEN_WIDGET *w) {
   GWEN_NEW_OBJECT(GTK3_GRIDLAYOUT_WIDGET, xw);
   GWEN_INHERIT_SETDATA(GWEN_WIDGET, GTK3_GRIDLAYOUT_WIDGET, w, xw, Gtk3Gui_WGridLayout_FreeData);
 
-  flags=GWEN_Widget_GetFlags(w);
   wParent=GWEN_Widget_Tree_GetParent(w);
   cols=GWEN_Widget_GetColumns(w);
   rows=GWEN_Widget_GetRows(w);
@@ -221,8 +224,8 @@ int Gtk3Gui_WGridLayout_Setup(GWEN_WIDGET *w) {
 
   g=gtk_grid_new();
 
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk3Gui_WGridLayout_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk3Gui_WGridLayout_GetIntProperty);
