@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Fri Sep 12 2003
-    copyright   : (C) 2003-2010 by Martin Preuss
+    copyright   : (C) 2020 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -38,14 +38,15 @@
 GWEN_BUFFER *GWEN_Buffer_new(char *buffer,
                              uint32_t size,
                              uint32_t used,
-                             int take) {
+                             int take)
+{
   GWEN_BUFFER *bf;
 
   GWEN_NEW_OBJECT(GWEN_BUFFER, bf);
   bf->_refCount=1;
   if (!buffer) {
     /* allocate buffer */
-    bf->realPtr=(char*)GWEN_Memory_malloc(size+1);
+    bf->realPtr=(char *)GWEN_Memory_malloc(size?(size+1):0);
     assert(bf->realPtr);
     bf->ptr=bf->realPtr;
     bf->realBufferSize=size+1;
@@ -73,23 +74,21 @@ GWEN_BUFFER *GWEN_Buffer_new(char *buffer,
 
 
 
-void GWEN_Buffer_Attach(GWEN_BUFFER *bf) {
+void GWEN_Buffer_Attach(GWEN_BUFFER *bf)
+{
   assert(bf->_refCount);
   bf->_refCount++;
 }
 
 
 
-void GWEN_Buffer_free(GWEN_BUFFER *bf) {
+void GWEN_Buffer_free(GWEN_BUFFER *bf)
+{
   if (bf) {
     assert(bf->_refCount);
     if (bf->_refCount==1) {
       if (bf->flags & GWEN_BUFFER_FLAGS_OWNED)
         GWEN_Memory_dealloc(bf->realPtr);
-      if (bf->syncIo) {
-        if (bf->flags & GWEN_BUFFER_FLAGS_OWN_SYNCIO)
-          GWEN_SyncIo_free(bf->syncIo);
-      }
       GWEN_FREE_OBJECT(bf);
     }
     else
@@ -99,7 +98,8 @@ void GWEN_Buffer_free(GWEN_BUFFER *bf) {
 
 
 
-GWEN_BUFFER *GWEN_Buffer_dup(GWEN_BUFFER *bf) {
+GWEN_BUFFER *GWEN_Buffer_dup(GWEN_BUFFER *bf)
+{
   GWEN_BUFFER *newbf;
   uint32_t i;
 
@@ -107,7 +107,7 @@ GWEN_BUFFER *GWEN_Buffer_dup(GWEN_BUFFER *bf) {
   newbf->_refCount=1;
 
   if (bf->realPtr && bf->realBufferSize) {
-    newbf->realPtr=(char*)GWEN_Memory_malloc(bf->realBufferSize);
+    newbf->realPtr=(char *)GWEN_Memory_malloc((bf->realBufferSize)?(bf->realBufferSize+1):0);
     newbf->ptr=newbf->realPtr+(bf->ptr-bf->realPtr);
     newbf->realBufferSize=bf->realBufferSize;
     newbf->bufferSize=bf->bufferSize;
@@ -136,7 +136,8 @@ GWEN_BUFFER *GWEN_Buffer_dup(GWEN_BUFFER *bf) {
 
 
 
-int GWEN_Buffer_Relinquish(GWEN_BUFFER *bf) {
+int GWEN_Buffer_Relinquish(GWEN_BUFFER *bf)
+{
   assert(bf);
   if (!(bf->flags & GWEN_BUFFER_FLAGS_OWNED))
     return GWEN_ERROR_INVALID;
@@ -149,7 +150,8 @@ int GWEN_Buffer_Relinquish(GWEN_BUFFER *bf) {
 
 
 
-int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, uint32_t res) {
+int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, uint32_t res)
+{
   assert(bf);
   if (!res)
     return 0;
@@ -179,40 +181,46 @@ int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, uint32_t res) {
 
 
 
-uint32_t GWEN_Buffer_GetMode(GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetMode(GWEN_BUFFER *bf)
+{
   assert(bf);
   return bf->mode;
 }
 
 
 
-void GWEN_Buffer_SetMode(GWEN_BUFFER *bf, uint32_t mode) {
+void GWEN_Buffer_SetMode(GWEN_BUFFER *bf, uint32_t mode)
+{
   assert(bf);
   bf->mode=mode;
 }
 
 
-void GWEN_Buffer_AddMode(GWEN_BUFFER *bf, uint32_t mode) {
+void GWEN_Buffer_AddMode(GWEN_BUFFER *bf, uint32_t mode)
+{
   assert(bf);
   bf->mode|=mode;
 }
 
 
-void GWEN_Buffer_SubMode(GWEN_BUFFER *bf, uint32_t mode) {
+void GWEN_Buffer_SubMode(GWEN_BUFFER *bf, uint32_t mode)
+{
   assert(bf);
   bf->mode&=~mode;
 }
 
 
 
-uint32_t GWEN_Buffer_GetHardLimit(GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetHardLimit(GWEN_BUFFER *bf)
+{
   assert(bf);
   return bf->hardLimit;
 }
 
 
 
-void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, uint32_t l) {
+void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, uint32_t l)
+{
   assert(bf);
   assert(l);
   bf->hardLimit=l;
@@ -220,14 +228,16 @@ void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, uint32_t l) {
 
 
 
-char *GWEN_Buffer_GetStart(const GWEN_BUFFER *bf) {
+char *GWEN_Buffer_GetStart(const GWEN_BUFFER *bf)
+{
   assert(bf);
   return bf->ptr;
 }
 
 
 
-uint32_t GWEN_Buffer_GetSize(const GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetSize(const GWEN_BUFFER *bf)
+{
   assert(bf);
   if (bf->mode & GWEN_BUFFER_MODE_DYNAMIC)
     return bf->hardLimit;
@@ -236,26 +246,23 @@ uint32_t GWEN_Buffer_GetSize(const GWEN_BUFFER *bf) {
 
 
 
-uint32_t GWEN_Buffer_GetPos(const GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetPos(const GWEN_BUFFER *bf)
+{
   assert(bf);
   return bf->pos;
 }
 
 
 
-int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, uint32_t i) {
+int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, uint32_t i)
+{
   assert(bf);
 
   if (i>=bf->bufferSize) {
-    if (bf->mode & GWEN_BUFFER_MODE_USE_SYNCIO) {
-      bf->pos=i;
-    }
-    else {
-      DBG_ERROR(GWEN_LOGDOMAIN,
-                "Position %d outside buffer boundaries (%d bytes)",
-                i, bf->bufferSize);
-      return GWEN_ERROR_BUFFER_OVERFLOW;
-    }
+    DBG_ERROR(GWEN_LOGDOMAIN,
+              "Position %d outside buffer boundaries (%d bytes)",
+              i, (int)(bf->bufferSize));
+    return GWEN_ERROR_BUFFER_OVERFLOW;
   }
   bf->pos=i;
   return 0;
@@ -263,14 +270,16 @@ int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, uint32_t i) {
 
 
 
-uint32_t GWEN_Buffer_GetUsedBytes(const GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetUsedBytes(const GWEN_BUFFER *bf)
+{
   assert(bf);
   return bf->bytesUsed;
 }
 
 
 
-int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
+int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size)
+{
   assert(bf);
   if (bf->mode & GWEN_BUFFER_MODE_READONLY) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
@@ -311,7 +320,7 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
     if (nsize>bf->hardLimit) {
       DBG_ERROR(GWEN_LOGDOMAIN,
                 "Size is beyond hard limit (%d>%d)",
-                nsize, bf->hardLimit);
+                (int) nsize, (int)(bf->hardLimit));
       if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
         abort();
       }
@@ -320,10 +329,10 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
     DBG_VERBOUS(GWEN_LOGDOMAIN, "Reallocating from %d to %d bytes",
                 bf->bufferSize, nsize);
     if (bf->realPtr==NULL) {
-      p=GWEN_Memory_malloc(nsize);
+      p=GWEN_Memory_malloc(nsize?(nsize+1):0);
     }
     else {
-      p=GWEN_Memory_realloc(bf->realPtr, nsize);
+      p=GWEN_Memory_realloc(bf->realPtr, nsize?(nsize+1):0);
     }
     if (!p) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Realloc failed.");
@@ -334,7 +343,7 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
     }
 
     /* store new size and pointer */
-    bf->realPtr=p;
+    bf->realPtr=(char *)p;
     bf->ptr=bf->realPtr+reserved;
     bf->realBufferSize=nsize;
     bf->bufferSize+=noffs;
@@ -347,7 +356,8 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
 
 int GWEN_Buffer_AppendBytes(GWEN_BUFFER *bf,
                             const char *buffer,
-                            uint32_t size) {
+                            uint32_t size)
+{
   int rv;
 
   assert(bf);
@@ -360,7 +370,7 @@ int GWEN_Buffer_AppendBytes(GWEN_BUFFER *bf,
     return GWEN_ERROR_PERMISSIONS;
   }
 
-  rv=GWEN_Buffer_AllocRoom(bf, size);
+  rv=GWEN_Buffer_AllocRoom(bf, size+1);
   if (rv<0) {
     DBG_DEBUG(GWEN_LOGDOMAIN, "called from here");
     return rv;
@@ -377,7 +387,8 @@ int GWEN_Buffer_AppendBytes(GWEN_BUFFER *bf,
 
 
 
-int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c) {
+int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c)
+{
   int rv;
 
   assert(bf);
@@ -408,100 +419,41 @@ int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c) {
 
 
 
-int GWEN_Buffer__FillBuffer_SyncIo(GWEN_BUFFER *bf) {
-  if (bf->syncIo) {
-    uint32_t toread;
-    int rv;
-
-    toread=bf->pos-bf->bytesUsed+1;
-    if (GWEN_Buffer_AllocRoom(bf, toread+1)) {
-      DBG_INFO(GWEN_LOGDOMAIN, "Buffer too small");
-      return GWEN_ERROR_GENERIC;
-    }
-    rv=GWEN_SyncIo_ReadForced(bf->syncIo,
-                              (uint8_t*) (bf->ptr+bf->bytesUsed),
-                              toread);
-    if (rv<0) {
-      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-      return rv;
-    }
-    else if (rv==0) {
-      DBG_INFO(GWEN_LOGDOMAIN, "EOF met");
-      return GWEN_ERROR_EOF;
-    }
-
-    bf->bytesUsed+=rv;
-  }
-  else {
-    DBG_DEBUG(GWEN_LOGDOMAIN,
-              "End of used area reached and no SYNCIO (%d bytes)",
-              bf->pos);
-    return GWEN_ERROR_EOF;
-  }
-  return 0;
-}
-
-
-
-int GWEN_Buffer__FillBuffer(GWEN_BUFFER *bf) {
-  assert(bf);
-  if (bf->mode & GWEN_BUFFER_MODE_USE_SYNCIO)
-    return GWEN_Buffer__FillBuffer_SyncIo(bf);
-  else {
-    DBG_DEBUG(GWEN_LOGDOMAIN,
-              "End of used area reached (%d bytes)", bf->pos);
-    return GWEN_ERROR_EOF;
-  }
-}
-
-
-
-int GWEN_Buffer_PeekByte(GWEN_BUFFER *bf) {
+int GWEN_Buffer_PeekByte(GWEN_BUFFER *bf)
+{
   assert(bf);
 
   if (bf->pos>=bf->bytesUsed) {
-    int rv;
-
-    rv=GWEN_Buffer__FillBuffer(bf);
-    if (rv<0) {
-      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-      return rv;
-    }
+    return GWEN_ERROR_EOF;
   }
 
-  return (unsigned char) (bf->ptr[bf->pos]);
+  return (unsigned char)(bf->ptr[bf->pos]);
 }
 
 
 
-int GWEN_Buffer_ReadByte(GWEN_BUFFER *bf) {
+int GWEN_Buffer_ReadByte(GWEN_BUFFER *bf)
+{
   assert(bf);
 
   if (bf->pos>=bf->bytesUsed) {
-    int rv;
-
-    rv=GWEN_Buffer__FillBuffer(bf);
-    if (rv<0) {
-      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-      return rv;
-    }
+    return GWEN_ERROR_EOF;
   }
 
-  return (unsigned char) (bf->ptr[bf->pos++]);
+  return (unsigned char)(bf->ptr[bf->pos++]);
 }
 
 
 
-int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i) {
+int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i)
+{
   assert(bf);
 
   if (i+bf->pos>=bf->bufferSize) {
-    if (!(bf->mode & GWEN_BUFFER_MODE_USE_SYNCIO)) {
-      DBG_DEBUG(GWEN_LOGDOMAIN,
-                "Position %d outside buffer boundaries (%d bytes)\n"
-                "Incrementing anyway",
-                i+bf->pos, bf->bufferSize);
-    }
+    DBG_DEBUG(GWEN_LOGDOMAIN,
+              "Position %d outside buffer boundaries (%d bytes)\n"
+              "Incrementing anyway",
+              i+bf->pos, bf->bufferSize);
   }
 
   bf->pos+=i;
@@ -510,7 +462,8 @@ int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i) {
 
 
 
-int GWEN_Buffer_AdjustUsedBytes(GWEN_BUFFER *bf) {
+int GWEN_Buffer_AdjustUsedBytes(GWEN_BUFFER *bf)
+{
   assert(bf);
   if (bf->pos<=bf->bufferSize) {
     if (bf->pos>bf->bytesUsed) {
@@ -519,19 +472,20 @@ int GWEN_Buffer_AdjustUsedBytes(GWEN_BUFFER *bf) {
       bf->bytesUsed=bf->pos;
     }
     /* append a NULL to allow using the buffer as ASCIIZ string */
-    bf->ptr[bf->bytesUsed]=0;
+    bf->ptr[bf->bytesUsed]=0; /* TODO: This has to be checked (is it okay to add a byte here?)! */
     return 0;
   }
   else {
     DBG_ERROR(GWEN_LOGDOMAIN, "Pointer outside buffer size (%d bytes)",
-              bf->bufferSize);
+              (int)(bf->bufferSize));
     return GWEN_ERROR_BUFFER_OVERFLOW;
   }
 }
 
 
 
-int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, uint32_t i) {
+int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, uint32_t i)
+{
   assert(bf);
 
   if (bf->pos<i) {
@@ -546,7 +500,8 @@ int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, uint32_t i) {
 
 
 
-int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf, GWEN_BUFFER *sf) {
+int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf, GWEN_BUFFER *sf)
+{
 
   assert(bf);
   assert(sf);
@@ -566,15 +521,17 @@ int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf, GWEN_BUFFER *sf) {
 
 
 
-uint32_t GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf)
+{
   assert(bf);
 
-  return (bf->bufferSize-bf->bytesUsed);
+  return (bf->bufferSize-(bf->bytesUsed+1));
 }
 
 
 
-uint32_t GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf)
+{
   assert(bf);
 
   if (bf->pos<bf->bytesUsed)
@@ -585,14 +542,16 @@ uint32_t GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf) {
 
 
 
-char *GWEN_Buffer_GetPosPointer(const GWEN_BUFFER *bf) {
+char *GWEN_Buffer_GetPosPointer(const GWEN_BUFFER *bf)
+{
   assert(bf);
   return bf->ptr+bf->pos;
 }
 
 
 
-void GWEN_Buffer_OverwriteContent(GWEN_BUFFER *bf, int c) {
+void GWEN_Buffer_OverwriteContent(GWEN_BUFFER *bf, int c)
+{
   assert(bf);
   if (bf->realPtr && bf->realBufferSize) {
     memset(bf->realPtr, c, bf->realBufferSize);
@@ -601,7 +560,8 @@ void GWEN_Buffer_OverwriteContent(GWEN_BUFFER *bf, int c) {
 
 
 
-uint32_t GWEN_Buffer_GetBookmark(const GWEN_BUFFER *bf, unsigned int idx) {
+uint32_t GWEN_Buffer_GetBookmark(const GWEN_BUFFER *bf, unsigned int idx)
+{
   assert(bf);
   assert(idx<GWEN_BUFFER_MAX_BOOKMARKS);
   return bf->bookmarks[idx];
@@ -610,7 +570,8 @@ uint32_t GWEN_Buffer_GetBookmark(const GWEN_BUFFER *bf, unsigned int idx) {
 
 
 void GWEN_Buffer_SetBookmark(GWEN_BUFFER *bf, unsigned int idx,
-                             uint32_t v) {
+                             uint32_t v)
+{
   assert(bf);
   assert(idx<GWEN_BUFFER_MAX_BOOKMARKS);
   bf->bookmarks[idx]=v;
@@ -618,7 +579,8 @@ void GWEN_Buffer_SetBookmark(GWEN_BUFFER *bf, unsigned int idx,
 
 
 
-void GWEN_Buffer_Dump(GWEN_BUFFER *bf, unsigned int insert) {
+void GWEN_Buffer_Dump(GWEN_BUFFER *bf, unsigned int insert)
+{
   uint32_t k;
 
   for (k=0; k<insert; k++)
@@ -681,7 +643,8 @@ void GWEN_Buffer_Dump(GWEN_BUFFER *bf, unsigned int insert) {
 
 
 
-void GWEN_Buffer_Reset(GWEN_BUFFER *bf) {
+void GWEN_Buffer_Reset(GWEN_BUFFER *bf)
+{
   assert(bf);
   bf->pos=0;
   bf->bytesUsed=0;
@@ -690,14 +653,16 @@ void GWEN_Buffer_Reset(GWEN_BUFFER *bf) {
 
 
 
-void GWEN_Buffer_Rewind(GWEN_BUFFER *bf) {
+void GWEN_Buffer_Rewind(GWEN_BUFFER *bf)
+{
   assert(bf);
   bf->pos=0;
 }
 
 
 
-int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf, char *buffer, uint32_t *size) {
+int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf, char *buffer, uint32_t *size)
+{
   /* optimized for speed */
   uint32_t i;
   char *pdst;
@@ -706,16 +671,12 @@ int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf, char *buffer, uint32_t *size) {
   i=0;
   pdst=buffer;
 
-  while(i<*size) {
+  while (i<*size) {
     int j;
     int srcLeft;
 
-    if (bf->pos>=bf->bytesUsed) {
-      if (GWEN_Buffer__FillBuffer(bf)) {
-        DBG_DEBUG(GWEN_LOGDOMAIN, "Could not fill buffer, but that's ok");
-        break;
-      }
-    }
+    if (bf->pos>=bf->bytesUsed)
+      break;
 
     srcLeft=bf->bytesUsed - bf->pos;
     if (srcLeft==0)
@@ -737,14 +698,16 @@ int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf, char *buffer, uint32_t *size) {
 
 
 
-uint32_t GWEN_Buffer_GetStep(GWEN_BUFFER *bf) {
+uint32_t GWEN_Buffer_GetStep(GWEN_BUFFER *bf)
+{
   assert(bf);
   return bf->step;
 }
 
 
 
-void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, uint32_t step) {
+void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, uint32_t step)
+{
   assert(bf);
   bf->step=step;
 }
@@ -753,7 +716,8 @@ void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, uint32_t step) {
 
 void GWEN_Buffer_AdjustBookmarks(GWEN_BUFFER *bf,
                                  uint32_t pos,
-                                 int offset) {
+                                 int offset)
+{
   uint32_t i;
 
   assert(bf);
@@ -766,7 +730,8 @@ void GWEN_Buffer_AdjustBookmarks(GWEN_BUFFER *bf,
 
 
 int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
-                           uint32_t size) {
+                           uint32_t size)
+{
   char *p;
   int i;
   int rv;
@@ -795,7 +760,7 @@ int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
       return 0;
     }
     else {
-      if ( (bf->ptr - bf->realPtr) >= (int)size ) {
+      if ((bf->ptr - bf->realPtr) >= (int)size) {
         /* simply occupy the reserved space */
         bf->ptr-=size;
         bf->bytesUsed+=size;
@@ -826,7 +791,8 @@ int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
 
 
 
-int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size) {
+int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size)
+{
   char *p;
   int i;
 
@@ -871,7 +837,8 @@ int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size) {
 int GWEN_Buffer_ReplaceBytes(GWEN_BUFFER *bf,
                              uint32_t rsize,
                              const char *buffer,
-                             uint32_t size) {
+                             uint32_t size)
+{
   int32_t d;
   int rv;
 
@@ -911,7 +878,8 @@ int GWEN_Buffer_ReplaceBytes(GWEN_BUFFER *bf,
 
 int GWEN_Buffer_InsertBytes(GWEN_BUFFER *bf,
                             const char *buffer,
-                            uint32_t size) {
+                            uint32_t size)
+{
   int rv;
 
   assert(bf);
@@ -936,7 +904,8 @@ int GWEN_Buffer_InsertBytes(GWEN_BUFFER *bf,
 
 
 
-int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c) {
+int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c)
+{
   int rv;
 
   assert(bf);
@@ -961,7 +930,8 @@ int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c) {
 
 
 int GWEN_Buffer_InsertBuffer(GWEN_BUFFER *bf,
-                             GWEN_BUFFER *sf) {
+                             GWEN_BUFFER *sf)
+{
   assert(bf);
   assert(sf);
 
@@ -972,7 +942,8 @@ int GWEN_Buffer_InsertBuffer(GWEN_BUFFER *bf,
 
 int GWEN_Buffer_Crop(GWEN_BUFFER *bf,
                      uint32_t pos,
-                     uint32_t l) {
+                     uint32_t l)
+{
   int offset;
 
   if (bf->mode & GWEN_BUFFER_MODE_READONLY) {
@@ -1012,7 +983,8 @@ int GWEN_Buffer_Crop(GWEN_BUFFER *bf,
 
 
 int GWEN_Buffer_AppendString(GWEN_BUFFER *bf,
-                             const char *buffer) {
+                             const char *buffer)
+{
   assert(bf);
   assert(buffer);
   return GWEN_Buffer_AppendBytes(bf, buffer, strlen(buffer));
@@ -1021,7 +993,8 @@ int GWEN_Buffer_AppendString(GWEN_BUFFER *bf,
 
 
 int GWEN_Buffer_InsertString(GWEN_BUFFER *bf,
-                             const char *buffer) {
+                             const char *buffer)
+{
   assert(bf);
   assert(buffer);
   return GWEN_Buffer_InsertBytes(bf, buffer, strlen(buffer));
@@ -1029,27 +1002,10 @@ int GWEN_Buffer_InsertString(GWEN_BUFFER *bf,
 
 
 
-void GWEN_Buffer_SetSourceSyncIo(GWEN_BUFFER *bf,
-                                 GWEN_SYNCIO *sio,
-                                 int take) {
-  assert(bf);
-  if (bf->syncIo) {
-    if (bf->flags & GWEN_BUFFER_FLAGS_OWN_SYNCIO) {
-      GWEN_SyncIo_free(bf->syncIo);
-    }
-  }
-  if (take)
-    bf->flags|=GWEN_BUFFER_FLAGS_OWN_SYNCIO;
-  else
-    bf->flags&=~GWEN_BUFFER_FLAGS_OWN_SYNCIO;
-  bf->syncIo=sio;
-}
-
-
-
 int GWEN_Buffer_FillWithBytes(GWEN_BUFFER *bf,
                               unsigned char c,
-                              uint32_t size) {
+                              uint32_t size)
+{
   int rv;
 
   assert(bf);
@@ -1080,7 +1036,8 @@ int GWEN_Buffer_FillWithBytes(GWEN_BUFFER *bf,
 
 int GWEN_Buffer_FillLeftWithBytes(GWEN_BUFFER *bf,
                                   unsigned char c,
-                                  uint32_t size) {
+                                  uint32_t size)
+{
   int rv;
 
   assert(bf);
@@ -1104,15 +1061,17 @@ int GWEN_Buffer_FillLeftWithBytes(GWEN_BUFFER *bf,
 
 
 
-int GWENHYWFAR_CB GWEN_Buffer_CacheFn_Attach(void *ptr) {
-  GWEN_Buffer_Attach((GWEN_BUFFER*) ptr);
+int GWENHYWFAR_CB GWEN_Buffer_CacheFn_Attach(void *ptr)
+{
+  GWEN_Buffer_Attach((GWEN_BUFFER *) ptr);
   return 0;
 }
 
 
 
-int GWENHYWFAR_CB GWEN_Buffer_CacheFn_Free(void *ptr) {
-  GWEN_Buffer_free((GWEN_BUFFER*) ptr);
+int GWENHYWFAR_CB GWEN_Buffer_CacheFn_Free(void *ptr)
+{
+  GWEN_Buffer_free((GWEN_BUFFER *) ptr);
   return 0;
 }
 
