@@ -44,7 +44,8 @@ typedef enum {
   /** handle string list entries as integers (-> correct sorting of ASCII
    * coded values like "10", "1") */
   GWEN_StringList_SortModeInt
-} GWEN_STRINGLIST_SORT_MODE;
+}
+GWEN_STRINGLIST_SORT_MODE;
 
 
 typedef struct GWEN_STRINGLISTENTRYSTRUCT GWEN_STRINGLISTENTRY;
@@ -53,18 +54,18 @@ typedef struct GWEN_STRINGLISTENTRYSTRUCT GWEN_STRINGLISTENTRY;
 typedef struct GWEN_STRINGLISTSTRUCT GWEN_STRINGLIST;
 
 
-GWENHYWFAR_API GWEN_STRINGLIST *GWEN_StringList_new();
+GWENHYWFAR_API GWEN_STRINGLIST *GWEN_StringList_new(void);
 
 GWENHYWFAR_API GWEN_STRINGLIST *GWEN_StringList_fromTabString(const char *s, int checkDup);
 
 GWENHYWFAR_API void GWEN_StringList_free(GWEN_STRINGLIST *sl);
 GWENHYWFAR_API
-  GWEN_STRINGLIST *GWEN_StringList_dup(const GWEN_STRINGLIST *sl);
+GWEN_STRINGLIST *GWEN_StringList_dup(const GWEN_STRINGLIST *sl);
 GWENHYWFAR_API void GWEN_StringList_Clear(GWEN_STRINGLIST *sl);
 
 /** Returns the number of elements in this list. */
 GWENHYWFAR_API
-  unsigned int GWEN_StringList_Count(const GWEN_STRINGLIST *sl);
+unsigned int GWEN_StringList_Count(const GWEN_STRINGLIST *sl);
 
 GWENHYWFAR_API GWEN_STRINGLISTENTRY *GWEN_StringListEntry_new(const char *s,
                                                               int take);
@@ -77,16 +78,16 @@ GWENHYWFAR_API void GWEN_StringList_AppendEntry(GWEN_STRINGLIST *sl,
 GWENHYWFAR_API void GWEN_StringList_RemoveEntry(GWEN_STRINGLIST *sl,
                                                 GWEN_STRINGLISTENTRY *se);
 GWENHYWFAR_API
-  GWEN_STRINGLISTENTRY *GWEN_StringList_FirstEntry(const GWEN_STRINGLIST *sl);
+GWEN_STRINGLISTENTRY *GWEN_StringList_FirstEntry(const GWEN_STRINGLIST *sl);
 GWENHYWFAR_API
-  GWEN_STRINGLISTENTRY *GWEN_StringListEntry_Next(const GWEN_STRINGLISTENTRY *se);
+GWEN_STRINGLISTENTRY *GWEN_StringListEntry_Next(const GWEN_STRINGLISTENTRY *se);
 
 GWENHYWFAR_API
-  const char *GWEN_StringListEntry_Data(const GWEN_STRINGLISTENTRY *se);
+const char *GWEN_StringListEntry_Data(const GWEN_STRINGLISTENTRY *se);
 
 GWENHYWFAR_API
-  void GWEN_StringListEntry_SetData(GWEN_STRINGLISTENTRY *se,
-                                    const char *s);
+void GWEN_StringListEntry_SetData(GWEN_STRINGLISTENTRY *se,
+                                  const char *s);
 
 /**
  * Normally this group of functions ignores cases when comparing two strings.
@@ -138,6 +139,12 @@ GWENHYWFAR_API int GWEN_StringList_InsertString(GWEN_STRINGLIST *sl,
 GWENHYWFAR_API int GWEN_StringList_RemoveString(GWEN_STRINGLIST *sl,
                                                 const char *s);
 
+/**
+ * Removes the first string from the stringlist (if any).
+ */
+GWENHYWFAR_API void GWEN_StringList_RemoveFirstString(GWEN_STRINGLIST *sl);
+
+
 /**
  * Checks whether the given string already exists within in the
  * string list.
@@ -154,10 +161,17 @@ GWENHYWFAR_API int GWEN_StringList_HasString(const GWEN_STRINGLIST *sl,
 GWENHYWFAR_API int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const char *s);
 
 
+/**
+ * Returns the first stringlist entry which contains the given string
+ * @return string list entry containing the given string, NULL otherwise
+ */
+GWENHYWFAR_API GWEN_STRINGLISTENTRY *GWEN_StringList_FindStringEntry(const GWEN_STRINGLIST *sl, const char *s);
+
+
 /** Traverses the list, calling the callback function 'func' on
  * each list element.  Traversal will stop when 'func' returns a
  * non-NULL value, and the routine will return with that
- * value. Otherwise the routine will return NULL. 
+ * value. Otherwise the routine will return NULL.
  * @param l The list to traverse.
  * @param func The function to be called with each list element.
  * @param user_data A pointer passed on to the function 'func'.
@@ -166,9 +180,9 @@ GWENHYWFAR_API int GWEN_StringList_GetStringPos(const GWEN_STRINGLIST *sl, const
  * returns NULL.
  */
 GWENHYWFAR_API
-void *GWEN_StringList_ForEach(const GWEN_STRINGLIST *l, 
-			      void *(*func)(const char *s, void *u), 
-			      void *user_data);
+void *GWEN_StringList_ForEach(const GWEN_STRINGLIST *l,
+                              void *(*func)(const char *s, void *u),
+                              void *user_data);
 
 /** Returns the first string in this list. */
 GWENHYWFAR_API
