@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: crypttoken.h 1113 2007-01-10 09:14:16Z martin $
     begin       : Wed Mar 16 2005
-    copyright   : (C) 2005 by Martin Preuss
+    copyright   : (C) 2005-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -14,6 +11,8 @@
 # include <config.h>
 #endif
 
+#define DISABLE_DEBUGLOG
+
 
 #include "ct_p.h"
 #include "i18n_l.h"
@@ -32,8 +31,9 @@ GWEN_LIST2_FUNCTIONS(GWEN_CRYPT_TOKEN, GWEN_Crypt_Token)
 
 
 GWEN_CRYPT_TOKEN *GWEN_Crypt_Token_new(GWEN_CRYPT_TOKEN_DEVICE dev,
-				       const char *typeName,
-				       const char *tokenName) {
+                                       const char *typeName,
+                                       const char *tokenName)
+{
   GWEN_CRYPT_TOKEN *ct;
 
   assert(typeName);
@@ -53,7 +53,8 @@ GWEN_CRYPT_TOKEN *GWEN_Crypt_Token_new(GWEN_CRYPT_TOKEN_DEVICE dev,
 
 
 
-void GWEN_Crypt_Token_free(GWEN_CRYPT_TOKEN *ct) {
+void GWEN_Crypt_Token_free(GWEN_CRYPT_TOKEN *ct)
+{
   if (ct) {
     assert(ct->refCount);
     if (ct->refCount==1) {
@@ -72,7 +73,8 @@ void GWEN_Crypt_Token_free(GWEN_CRYPT_TOKEN *ct) {
 
 
 
-GWEN_CRYPT_TOKEN_DEVICE GWEN_Crypt_Token_GetDevice(const GWEN_CRYPT_TOKEN *ct) {
+GWEN_CRYPT_TOKEN_DEVICE GWEN_Crypt_Token_GetDevice(const GWEN_CRYPT_TOKEN *ct)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -81,7 +83,8 @@ GWEN_CRYPT_TOKEN_DEVICE GWEN_Crypt_Token_GetDevice(const GWEN_CRYPT_TOKEN *ct) {
 
 
 
-const char *GWEN_Crypt_Token_GetTypeName(const GWEN_CRYPT_TOKEN *ct) {
+const char *GWEN_Crypt_Token_GetTypeName(const GWEN_CRYPT_TOKEN *ct)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -90,7 +93,8 @@ const char *GWEN_Crypt_Token_GetTypeName(const GWEN_CRYPT_TOKEN *ct) {
 
 
 
-const char *GWEN_Crypt_Token_GetTokenName(const GWEN_CRYPT_TOKEN *ct) {
+const char *GWEN_Crypt_Token_GetTokenName(const GWEN_CRYPT_TOKEN *ct)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -99,7 +103,8 @@ const char *GWEN_Crypt_Token_GetTokenName(const GWEN_CRYPT_TOKEN *ct) {
 
 
 
-void GWEN_Crypt_Token_SetTokenName(GWEN_CRYPT_TOKEN *ct, const char *s) {
+void GWEN_Crypt_Token_SetTokenName(GWEN_CRYPT_TOKEN *ct, const char *s)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -111,7 +116,8 @@ void GWEN_Crypt_Token_SetTokenName(GWEN_CRYPT_TOKEN *ct, const char *s) {
 
 
 
-const char *GWEN_Crypt_Token_GetFriendlyName(const GWEN_CRYPT_TOKEN *ct) {
+const char *GWEN_Crypt_Token_GetFriendlyName(const GWEN_CRYPT_TOKEN *ct)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -120,7 +126,8 @@ const char *GWEN_Crypt_Token_GetFriendlyName(const GWEN_CRYPT_TOKEN *ct) {
 
 
 
-void GWEN_Crypt_Token_SetFriendlyName(GWEN_CRYPT_TOKEN *ct, const char *s) {
+void GWEN_Crypt_Token_SetFriendlyName(GWEN_CRYPT_TOKEN *ct, const char *s)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -132,7 +139,8 @@ void GWEN_Crypt_Token_SetFriendlyName(GWEN_CRYPT_TOKEN *ct, const char *s) {
 
 
 
-uint32_t GWEN_Crypt_Token_GetFlags(const GWEN_CRYPT_TOKEN *ct) {
+uint32_t GWEN_Crypt_Token_GetFlags(const GWEN_CRYPT_TOKEN *ct)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -141,7 +149,8 @@ uint32_t GWEN_Crypt_Token_GetFlags(const GWEN_CRYPT_TOKEN *ct) {
 
 
 
-void GWEN_Crypt_Token_SetFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
+void GWEN_Crypt_Token_SetFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -150,7 +159,8 @@ void GWEN_Crypt_Token_SetFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
 
 
 
-void GWEN_Crypt_Token_AddFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
+void GWEN_Crypt_Token_AddFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -159,7 +169,8 @@ void GWEN_Crypt_Token_AddFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
 
 
 
-void GWEN_Crypt_Token_SubFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
+void GWEN_Crypt_Token_SubFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -168,7 +179,8 @@ void GWEN_Crypt_Token_SubFlags(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
 
 
 
-uint32_t GWEN_Crypt_Token_GetModes(const GWEN_CRYPT_TOKEN *ct) {
+uint32_t GWEN_Crypt_Token_GetModes(const GWEN_CRYPT_TOKEN *ct)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -177,7 +189,8 @@ uint32_t GWEN_Crypt_Token_GetModes(const GWEN_CRYPT_TOKEN *ct) {
 
 
 
-void GWEN_Crypt_Token_SetModes(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
+void GWEN_Crypt_Token_SetModes(GWEN_CRYPT_TOKEN *ct, uint32_t f)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -186,7 +199,8 @@ void GWEN_Crypt_Token_SetModes(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
 
 
 
-void GWEN_Crypt_Token_AddModes(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
+void GWEN_Crypt_Token_AddModes(GWEN_CRYPT_TOKEN *ct, uint32_t f)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -195,7 +209,8 @@ void GWEN_Crypt_Token_AddModes(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
 
 
 
-void GWEN_Crypt_Token_SubModes(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
+void GWEN_Crypt_Token_SubModes(GWEN_CRYPT_TOKEN *ct, uint32_t f)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -204,7 +219,8 @@ void GWEN_Crypt_Token_SubModes(GWEN_CRYPT_TOKEN *ct, uint32_t f) {
 
 
 
-int GWEN_Crypt_Token_Open(GWEN_CRYPT_TOKEN *ct, int admin, uint32_t gid) {
+int GWEN_Crypt_Token_Open(GWEN_CRYPT_TOKEN *ct, int admin, uint32_t gid)
+{
   int rv;
 
   assert(ct);
@@ -227,7 +243,8 @@ int GWEN_Crypt_Token_Open(GWEN_CRYPT_TOKEN *ct, int admin, uint32_t gid) {
 
 
 
-int GWEN_Crypt_Token_Create(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
+int GWEN_Crypt_Token_Create(GWEN_CRYPT_TOKEN *ct, uint32_t gid)
+{
   int rv;
 
   assert(ct);
@@ -245,7 +262,8 @@ int GWEN_Crypt_Token_Create(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
 
 
 
-int GWEN_Crypt_Token_Close(GWEN_CRYPT_TOKEN *ct, int abandon, uint32_t gid) {
+int GWEN_Crypt_Token_Close(GWEN_CRYPT_TOKEN *ct, int abandon, uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -270,7 +288,8 @@ int GWEN_Crypt_Token_Close(GWEN_CRYPT_TOKEN *ct, int abandon, uint32_t gid) {
 
 
 
-int GWEN_Crypt_Token_IsOpen(const GWEN_CRYPT_TOKEN *ct) {
+int GWEN_Crypt_Token_IsOpen(const GWEN_CRYPT_TOKEN *ct)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -280,9 +299,10 @@ int GWEN_Crypt_Token_IsOpen(const GWEN_CRYPT_TOKEN *ct) {
 
 
 int GWEN_Crypt_Token_GetKeyIdList(GWEN_CRYPT_TOKEN *ct,
-				  uint32_t *pIdList,
-				  uint32_t *pCount,
-				  uint32_t gid) {
+                                  uint32_t *pIdList,
+                                  uint32_t *pCount,
+                                  uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -297,10 +317,11 @@ int GWEN_Crypt_Token_GetKeyIdList(GWEN_CRYPT_TOKEN *ct,
 
 
 
-const GWEN_CRYPT_TOKEN_KEYINFO* GWEN_Crypt_Token_GetKeyInfo(GWEN_CRYPT_TOKEN *ct,
-							    uint32_t id,
+const GWEN_CRYPT_TOKEN_KEYINFO *GWEN_Crypt_Token_GetKeyInfo(GWEN_CRYPT_TOKEN *ct,
+                                                            uint32_t id,
                                                             uint32_t flags,
-							    uint32_t gid) {
+                                                            uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -318,9 +339,10 @@ const GWEN_CRYPT_TOKEN_KEYINFO* GWEN_Crypt_Token_GetKeyInfo(GWEN_CRYPT_TOKEN *ct
 
 
 int GWEN_Crypt_Token_SetKeyInfo(GWEN_CRYPT_TOKEN *ct,
-				uint32_t id,
-				const GWEN_CRYPT_TOKEN_KEYINFO *ki,
-				uint32_t gid) {
+                                uint32_t id,
+                                const GWEN_CRYPT_TOKEN_KEYINFO *ki,
+                                uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -336,9 +358,10 @@ int GWEN_Crypt_Token_SetKeyInfo(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_GetContextIdList(GWEN_CRYPT_TOKEN *ct,
-				      uint32_t *pIdList,
-				      uint32_t *pCount,
-				      uint32_t gid) {
+                                      uint32_t *pIdList,
+                                      uint32_t *pCount,
+                                      uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -353,9 +376,10 @@ int GWEN_Crypt_Token_GetContextIdList(GWEN_CRYPT_TOKEN *ct,
 
 
 
-const GWEN_CRYPT_TOKEN_CONTEXT* GWEN_Crypt_Token_GetContext(GWEN_CRYPT_TOKEN *ct,
-							    uint32_t id,
-							    uint32_t gid) {
+const GWEN_CRYPT_TOKEN_CONTEXT *GWEN_Crypt_Token_GetContext(GWEN_CRYPT_TOKEN *ct,
+                                                            uint32_t id,
+                                                            uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -373,9 +397,10 @@ const GWEN_CRYPT_TOKEN_CONTEXT* GWEN_Crypt_Token_GetContext(GWEN_CRYPT_TOKEN *ct
 
 
 int GWEN_Crypt_Token_SetContext(GWEN_CRYPT_TOKEN *ct,
-				uint32_t id,
-				const GWEN_CRYPT_TOKEN_CONTEXT *ctx,
-				uint32_t gid) {
+                                uint32_t id,
+                                const GWEN_CRYPT_TOKEN_CONTEXT *ctx,
+                                uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -391,14 +416,15 @@ int GWEN_Crypt_Token_SetContext(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_Sign(GWEN_CRYPT_TOKEN *ct,
-			  uint32_t keyId,
-			  GWEN_CRYPT_PADDALGO *a,
-			  const uint8_t *pInData,
-			  uint32_t inLen,
-			  uint8_t *pSignatureData,
-			  uint32_t *pSignatureLen,
-			  uint32_t *pSeqCounter,
-			  uint32_t gid) {
+                          uint32_t keyId,
+                          GWEN_CRYPT_PADDALGO *a,
+                          const uint8_t *pInData,
+                          uint32_t inLen,
+                          uint8_t *pSignatureData,
+                          uint32_t *pSignatureLen,
+                          uint32_t *pSeqCounter,
+                          uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -407,7 +433,7 @@ int GWEN_Crypt_Token_Sign(GWEN_CRYPT_TOKEN *ct,
 
   if (ct->signFn)
     return ct->signFn(ct, keyId, a, pInData, inLen, pSignatureData, pSignatureLen,
-		      pSeqCounter, gid);
+                      pSeqCounter, gid);
   else
     return GWEN_ERROR_NOT_IMPLEMENTED;
 }
@@ -415,14 +441,15 @@ int GWEN_Crypt_Token_Sign(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_Verify(GWEN_CRYPT_TOKEN *ct,
-			    uint32_t keyId,
-			    GWEN_CRYPT_PADDALGO *a,
-			    const uint8_t *pInData,
-			    uint32_t inLen,
-			    const uint8_t *pSignatureData,
-			    uint32_t signatureLen,
-			    uint32_t seqCounter,
-			    uint32_t gid) {
+                            uint32_t keyId,
+                            GWEN_CRYPT_PADDALGO *a,
+                            const uint8_t *pInData,
+                            uint32_t inLen,
+                            const uint8_t *pSignatureData,
+                            uint32_t signatureLen,
+                            uint32_t seqCounter,
+                            uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -431,7 +458,7 @@ int GWEN_Crypt_Token_Verify(GWEN_CRYPT_TOKEN *ct,
 
   if (ct->verifyFn)
     return ct->verifyFn(ct, keyId, a, pInData, inLen, pSignatureData, signatureLen,
-			seqCounter, gid);
+                        seqCounter, gid);
   else
     return GWEN_ERROR_NOT_IMPLEMENTED;
 }
@@ -439,13 +466,14 @@ int GWEN_Crypt_Token_Verify(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_Encipher(GWEN_CRYPT_TOKEN *ct,
-			      uint32_t keyId,
-			      GWEN_CRYPT_PADDALGO *a,
-			      const uint8_t *pInData,
-			      uint32_t inLen,
-			      uint8_t *pOutData,
-			      uint32_t *pOutLen,
-			      uint32_t gid) {
+                              uint32_t keyId,
+                              GWEN_CRYPT_PADDALGO *a,
+                              const uint8_t *pInData,
+                              uint32_t inLen,
+                              uint8_t *pOutData,
+                              uint32_t *pOutLen,
+                              uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -461,13 +489,14 @@ int GWEN_Crypt_Token_Encipher(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_Decipher(GWEN_CRYPT_TOKEN *ct,
-			      uint32_t keyId,
-			      GWEN_CRYPT_PADDALGO *a,
-			      const uint8_t *pInData,
-			      uint32_t inLen,
-			      uint8_t *pOutData,
-			      uint32_t *pOutLen,
-			      uint32_t gid) {
+                              uint32_t keyId,
+                              GWEN_CRYPT_PADDALGO *a,
+                              const uint8_t *pInData,
+                              uint32_t inLen,
+                              uint8_t *pOutData,
+                              uint32_t *pOutLen,
+                              uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -484,9 +513,10 @@ int GWEN_Crypt_Token_Decipher(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_GenerateKey(GWEN_CRYPT_TOKEN *ct,
-				 uint32_t keyId,
-				 const GWEN_CRYPT_CRYPTALGO *a,
-				 uint32_t gid) {
+                                 uint32_t keyId,
+                                 const GWEN_CRYPT_CRYPTALGO *a,
+                                 uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -501,7 +531,8 @@ int GWEN_Crypt_Token_GenerateKey(GWEN_CRYPT_TOKEN *ct,
 
 
 
-int GWEN_Crypt_Token_ChangePin(GWEN_CRYPT_TOKEN *ct, int admin, uint32_t gid) {
+int GWEN_Crypt_Token_ChangePin(GWEN_CRYPT_TOKEN *ct, int admin, uint32_t gid)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -516,11 +547,28 @@ int GWEN_Crypt_Token_ChangePin(GWEN_CRYPT_TOKEN *ct, int admin, uint32_t gid) {
 
 
 
+int  GWEN_Crypt_Token_ActivateKey(GWEN_CRYPT_TOKEN *ct, uint32_t id, uint32_t gid)
+{
+  assert(ct);
+  assert(ct->refCount);
+
+  if (ct->openCount<1)
+    return GWEN_ERROR_NOT_OPEN;
+
+  if (ct->activateKeyFn)
+    return ct->activateKeyFn(ct, id, gid);
+  else
+    return GWEN_ERROR_NOT_IMPLEMENTED;
+}
+
+
+
 
 
 
 GWEN_CRYPT_TOKEN_OPEN_FN GWEN_Crypt_Token_SetOpenFn(GWEN_CRYPT_TOKEN *ct,
-						    GWEN_CRYPT_TOKEN_OPEN_FN f) {
+                                                    GWEN_CRYPT_TOKEN_OPEN_FN f)
+{
   GWEN_CRYPT_TOKEN_OPEN_FN of;
 
   assert(ct);
@@ -534,7 +582,8 @@ GWEN_CRYPT_TOKEN_OPEN_FN GWEN_Crypt_Token_SetOpenFn(GWEN_CRYPT_TOKEN *ct,
 
 
 GWEN_CRYPT_TOKEN_CREATE_FN GWEN_Crypt_Token_SetCreateFn(GWEN_CRYPT_TOKEN *ct,
-							GWEN_CRYPT_TOKEN_CREATE_FN f) {
+                                                        GWEN_CRYPT_TOKEN_CREATE_FN f)
+{
   GWEN_CRYPT_TOKEN_CREATE_FN of;
 
   assert(ct);
@@ -549,7 +598,8 @@ GWEN_CRYPT_TOKEN_CREATE_FN GWEN_Crypt_Token_SetCreateFn(GWEN_CRYPT_TOKEN *ct,
 
 
 GWEN_CRYPT_TOKEN_CLOSE_FN GWEN_Crypt_Token_SetCloseFn(GWEN_CRYPT_TOKEN *ct,
-						      GWEN_CRYPT_TOKEN_CLOSE_FN f) {
+                                                      GWEN_CRYPT_TOKEN_CLOSE_FN f)
+{
   GWEN_CRYPT_TOKEN_CLOSE_FN of;
 
   assert(ct);
@@ -562,9 +612,9 @@ GWEN_CRYPT_TOKEN_CLOSE_FN GWEN_Crypt_Token_SetCloseFn(GWEN_CRYPT_TOKEN *ct,
 
 
 
-GWEN_CRYPT_TOKEN_GETKEYIDLIST_FN
-GWEN_Crypt_Token_SetGetKeyIdListFn(GWEN_CRYPT_TOKEN *ct,
-				   GWEN_CRYPT_TOKEN_GETKEYIDLIST_FN f) {
+GWEN_CRYPT_TOKEN_GETKEYIDLIST_FN GWEN_Crypt_Token_SetGetKeyIdListFn(GWEN_CRYPT_TOKEN *ct,
+                                                                    GWEN_CRYPT_TOKEN_GETKEYIDLIST_FN f)
+{
   GWEN_CRYPT_TOKEN_GETKEYIDLIST_FN of;
 
   assert(ct);
@@ -577,9 +627,9 @@ GWEN_Crypt_Token_SetGetKeyIdListFn(GWEN_CRYPT_TOKEN *ct,
 
 
 
-GWEN_CRYPT_TOKEN_GETKEYINFO_FN
-GWEN_Crypt_Token_SetGetKeyInfoFn(GWEN_CRYPT_TOKEN *ct,
-				 GWEN_CRYPT_TOKEN_GETKEYINFO_FN f) {
+GWEN_CRYPT_TOKEN_GETKEYINFO_FN GWEN_Crypt_Token_SetGetKeyInfoFn(GWEN_CRYPT_TOKEN *ct,
+                                                                GWEN_CRYPT_TOKEN_GETKEYINFO_FN f)
+{
   GWEN_CRYPT_TOKEN_GETKEYINFO_FN of;
 
   assert(ct);
@@ -593,7 +643,8 @@ GWEN_Crypt_Token_SetGetKeyInfoFn(GWEN_CRYPT_TOKEN *ct,
 
 
 GWEN_CRYPT_TOKEN_SETKEYINFO_FN GWEN_Crypt_Token_SetSetKeyInfoFn(GWEN_CRYPT_TOKEN *ct,
-								GWEN_CRYPT_TOKEN_SETKEYINFO_FN f) {
+                                                                GWEN_CRYPT_TOKEN_SETKEYINFO_FN f)
+{
   GWEN_CRYPT_TOKEN_SETKEYINFO_FN of;
 
   assert(ct);
@@ -606,9 +657,9 @@ GWEN_CRYPT_TOKEN_SETKEYINFO_FN GWEN_Crypt_Token_SetSetKeyInfoFn(GWEN_CRYPT_TOKEN
 
 
 
-GWEN_CRYPT_TOKEN_GETCONTEXTIDLIST_FN
-GWEN_Crypt_Token_SetGetContextIdListFn(GWEN_CRYPT_TOKEN *ct,
-				       GWEN_CRYPT_TOKEN_GETCONTEXTIDLIST_FN f) {
+GWEN_CRYPT_TOKEN_GETCONTEXTIDLIST_FN GWEN_Crypt_Token_SetGetContextIdListFn(GWEN_CRYPT_TOKEN *ct,
+                                                                            GWEN_CRYPT_TOKEN_GETCONTEXTIDLIST_FN f)
+{
   GWEN_CRYPT_TOKEN_GETCONTEXTIDLIST_FN of;
 
   assert(ct);
@@ -621,9 +672,9 @@ GWEN_Crypt_Token_SetGetContextIdListFn(GWEN_CRYPT_TOKEN *ct,
 
 
 
-GWEN_CRYPT_TOKEN_GETCONTEXT_FN
-GWEN_Crypt_Token_SetGetContextFn(GWEN_CRYPT_TOKEN *ct,
-				 GWEN_CRYPT_TOKEN_GETCONTEXT_FN f) {
+GWEN_CRYPT_TOKEN_GETCONTEXT_FN GWEN_Crypt_Token_SetGetContextFn(GWEN_CRYPT_TOKEN *ct,
+                                                                GWEN_CRYPT_TOKEN_GETCONTEXT_FN f)
+{
   GWEN_CRYPT_TOKEN_GETCONTEXT_FN of;
 
   assert(ct);
@@ -636,9 +687,9 @@ GWEN_Crypt_Token_SetGetContextFn(GWEN_CRYPT_TOKEN *ct,
 
 
 
-GWEN_CRYPT_TOKEN_SETCONTEXT_FN
-GWEN_Crypt_Token_SetSetContextFn(GWEN_CRYPT_TOKEN *ct,
-				 GWEN_CRYPT_TOKEN_SETCONTEXT_FN f) {
+GWEN_CRYPT_TOKEN_SETCONTEXT_FN GWEN_Crypt_Token_SetSetContextFn(GWEN_CRYPT_TOKEN *ct,
+                                                                GWEN_CRYPT_TOKEN_SETCONTEXT_FN f)
+{
   GWEN_CRYPT_TOKEN_SETCONTEXT_FN of;
 
   assert(ct);
@@ -652,7 +703,8 @@ GWEN_Crypt_Token_SetSetContextFn(GWEN_CRYPT_TOKEN *ct,
 
 
 GWEN_CRYPT_TOKEN_SIGN_FN GWEN_Crypt_Token_SetSignFn(GWEN_CRYPT_TOKEN *ct,
-						    GWEN_CRYPT_TOKEN_SIGN_FN f) {
+                                                    GWEN_CRYPT_TOKEN_SIGN_FN f)
+{
   GWEN_CRYPT_TOKEN_SIGN_FN of;
 
   assert(ct);
@@ -666,7 +718,8 @@ GWEN_CRYPT_TOKEN_SIGN_FN GWEN_Crypt_Token_SetSignFn(GWEN_CRYPT_TOKEN *ct,
 
 
 GWEN_CRYPT_TOKEN_VERIFY_FN GWEN_Crypt_Token_SetVerifyFn(GWEN_CRYPT_TOKEN *ct,
-							GWEN_CRYPT_TOKEN_VERIFY_FN f) {
+                                                        GWEN_CRYPT_TOKEN_VERIFY_FN f)
+{
   GWEN_CRYPT_TOKEN_VERIFY_FN of;
 
   assert(ct);
@@ -680,7 +733,8 @@ GWEN_CRYPT_TOKEN_VERIFY_FN GWEN_Crypt_Token_SetVerifyFn(GWEN_CRYPT_TOKEN *ct,
 
 
 GWEN_CRYPT_TOKEN_ENCIPHER_FN GWEN_Crypt_Token_SetEncipherFn(GWEN_CRYPT_TOKEN *ct,
-							    GWEN_CRYPT_TOKEN_ENCIPHER_FN f) {
+                                                            GWEN_CRYPT_TOKEN_ENCIPHER_FN f)
+{
   GWEN_CRYPT_TOKEN_ENCIPHER_FN of;
 
   assert(ct);
@@ -694,7 +748,8 @@ GWEN_CRYPT_TOKEN_ENCIPHER_FN GWEN_Crypt_Token_SetEncipherFn(GWEN_CRYPT_TOKEN *ct
 
 
 GWEN_CRYPT_TOKEN_DECIPHER_FN GWEN_Crypt_Token_SetDecipherFn(GWEN_CRYPT_TOKEN *ct,
-							    GWEN_CRYPT_TOKEN_DECIPHER_FN f) {
+                                                            GWEN_CRYPT_TOKEN_DECIPHER_FN f)
+{
   GWEN_CRYPT_TOKEN_DECIPHER_FN of;
 
   assert(ct);
@@ -707,9 +762,9 @@ GWEN_CRYPT_TOKEN_DECIPHER_FN GWEN_Crypt_Token_SetDecipherFn(GWEN_CRYPT_TOKEN *ct
 
 
 
-GWEN_CRYPT_TOKEN_GENERATEKEY_FN
-GWEN_Crypt_Token_SetGenerateKeyFn(GWEN_CRYPT_TOKEN *ct,
-				  GWEN_CRYPT_TOKEN_GENERATEKEY_FN f) {
+GWEN_CRYPT_TOKEN_GENERATEKEY_FN GWEN_Crypt_Token_SetGenerateKeyFn(GWEN_CRYPT_TOKEN *ct,
+                                                                  GWEN_CRYPT_TOKEN_GENERATEKEY_FN f)
+{
   GWEN_CRYPT_TOKEN_GENERATEKEY_FN of;
 
   assert(ct);
@@ -723,7 +778,8 @@ GWEN_Crypt_Token_SetGenerateKeyFn(GWEN_CRYPT_TOKEN *ct,
 
 
 GWEN_CRYPT_TOKEN_CHANGEPIN_FN GWEN_Crypt_Token_SetChangePinFn(GWEN_CRYPT_TOKEN *ct,
-							      GWEN_CRYPT_TOKEN_CHANGEPIN_FN f) {
+                                                              GWEN_CRYPT_TOKEN_CHANGEPIN_FN f)
+{
   GWEN_CRYPT_TOKEN_CHANGEPIN_FN of;
 
   assert(ct);
@@ -736,11 +792,27 @@ GWEN_CRYPT_TOKEN_CHANGEPIN_FN GWEN_Crypt_Token_SetChangePinFn(GWEN_CRYPT_TOKEN *
 
 
 
+GWEN_CRYPT_TOKEN_ACTIVATEKEY_FN GWEN_Crypt_Token_SetActivateKeyFn(GWEN_CRYPT_TOKEN *ct,
+                                                                  GWEN_CRYPT_TOKEN_ACTIVATEKEY_FN f)
+{
+  GWEN_CRYPT_TOKEN_ACTIVATEKEY_FN of;
+
+  assert(ct);
+  assert(ct->refCount);
+  of=ct->activateKeyFn;
+  ct->activateKeyFn=f;
+
+  return of;
+}
+
+
+
 
 
 int GWEN_Crypt_Token__CreatePasswordName(GWEN_CRYPT_TOKEN *ct,
-					 GWEN_CRYPT_PINTYPE pt,
-					 GWEN_BUFFER *nbuf) {
+                                         GWEN_CRYPT_PINTYPE pt,
+                                         GWEN_BUFFER *nbuf)
+{
   const char *tname;
   const char *dname;
 
@@ -765,14 +837,15 @@ int GWEN_Crypt_Token__CreatePasswordName(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_GetPin(GWEN_CRYPT_TOKEN *ct,
-			    GWEN_CRYPT_PINTYPE pt,
-			    GWEN_CRYPT_PINENCODING pe,
-			    uint32_t flags,
-			    unsigned char *pwbuffer,
-			    unsigned int minLength,
-			    unsigned int maxLength,
-			    unsigned int *pinLength,
-			    uint32_t gid) {
+                            GWEN_CRYPT_PINTYPE pt,
+                            GWEN_CRYPT_PINENCODING pe,
+                            uint32_t flags,
+                            unsigned char *pwbuffer,
+                            unsigned int minLength,
+                            unsigned int maxLength,
+                            unsigned int *pinLength,
+                            uint32_t gid)
+{
   int rv;
   const char *dname;
   const char *mode;
@@ -802,60 +875,62 @@ int GWEN_Crypt_Token_GetPin(GWEN_CRYPT_TOKEN *ct,
 
   if (flags & GWEN_GUI_INPUT_FLAGS_CONFIRM) {
     snprintf(buffer, sizeof(buffer)-1,
-	     I18N("Please enter a new %s for \n"
-		  "%s\n"
-		  "The password must be at least %d characters long.%s"
-		  "<html>"
-		  "Please enter a new %s for <i>%s</i>. "
-		  "The password must be at least %d characters long.%s"
-		  "</html>"),
-	     mode,
-	     dname,
-	     minLength,
-	     numeric_warning,
-	     mode,
-	     dname,
-	     minLength,
-	     numeric_warning);
+             I18N("Please enter a new %s for \n"
+                  "%s\n"
+                  "The password must be at least %d characters long.%s"
+                  "<html>"
+                  "Please enter a new %s for <i>%s</i>. "
+                  "The password must be at least %d characters long.%s"
+                  "</html>"),
+             mode,
+             dname,
+             minLength,
+             numeric_warning,
+             mode,
+             dname,
+             minLength,
+             numeric_warning);
   }
   else {
     snprintf(buffer, sizeof(buffer)-1,
-	     I18N("Please enter the %s for \n"
-		  "%s\n"
-		  "%s<html>"
-		  "Please enter the %s for <i>%s</i>.%s"
-		  "</html>"),
-	     mode,
-	     dname,
-	     numeric_warning,
-	     mode,
-	     dname,
-	     numeric_warning);
+             I18N("Please enter the %s for \n"
+                  "%s\n"
+                  "%s<html>"
+                  "Please enter the %s for <i>%s</i>.%s"
+                  "</html>"),
+             mode,
+             dname,
+             numeric_warning,
+             mode,
+             dname,
+             numeric_warning);
   }
 
   nameBuffer=GWEN_Buffer_new(0, 256, 0, 1);
   GWEN_Crypt_Token__CreatePasswordName(ct, pt, nameBuffer);
   rv=GWEN_Gui_GetPassword(flags,
-			  GWEN_Buffer_GetStart(nameBuffer),
-			  I18N("Enter Password"),
-			  buffer,
-			  (char*)pwbuffer,
-			  minLength,
-			  maxLength, gid);
+                          GWEN_Buffer_GetStart(nameBuffer),
+                          I18N("Enter Password"),
+                          buffer,
+                          (char *)pwbuffer,
+                          minLength,
+                          maxLength,
+                          GWEN_Gui_PasswordMethod_Text, NULL,
+                          gid);
   GWEN_Buffer_free(nameBuffer);
   if (rv) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     return rv;
   }
 
-  *pinLength=strlen((char*)pwbuffer);
+  *pinLength=strlen((char *)pwbuffer);
 
   if (pe!=GWEN_Crypt_PinEncoding_Ascii) {
     rv=GWEN_Crypt_TransformPin(GWEN_Crypt_PinEncoding_Ascii,
-			       pe,
-			       pwbuffer,
-			       maxLength,
-			       pinLength);
+                               pe,
+                               pwbuffer,
+                               maxLength,
+                               pinLength);
     if (rv) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       return rv;
@@ -868,13 +943,14 @@ int GWEN_Crypt_Token_GetPin(GWEN_CRYPT_TOKEN *ct,
 
 
 int GWEN_Crypt_Token_SetPinStatus(GWEN_CRYPT_TOKEN *ct,
-				  GWEN_CRYPT_PINTYPE pt,
-				  GWEN_CRYPT_PINENCODING pe,
-				  GWEN_UNUSED uint32_t flags,
-				  const unsigned char *buffer,
-				  unsigned int pinLength,
-				  int isOk,
-				  uint32_t gid) {
+                                  GWEN_CRYPT_PINTYPE pt,
+                                  GWEN_CRYPT_PINENCODING pe,
+                                  GWEN_UNUSED uint32_t flags,
+                                  const unsigned char *buffer,
+                                  unsigned int pinLength,
+                                  int isOk,
+                                  uint32_t gid)
+{
   GWEN_BUFFER *nameBuffer;
   int rv;
   unsigned char ibuffer[256];
@@ -890,10 +966,10 @@ int GWEN_Crypt_Token_SetPinStatus(GWEN_CRYPT_TOKEN *ct,
     memset(ibuffer, 0, sizeof(ibuffer));
     memmove(ibuffer, buffer, pinLength);
     rv=GWEN_Crypt_TransformPin(pe,
-			       GWEN_Crypt_PinEncoding_Ascii,
-			       ibuffer,
-			       sizeof(ibuffer)-1,
-			       &pinLength);
+                               GWEN_Crypt_PinEncoding_Ascii,
+                               ibuffer,
+                               sizeof(ibuffer)-1,
+                               &pinLength);
     if (rv) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       return rv;
@@ -904,9 +980,9 @@ int GWEN_Crypt_Token_SetPinStatus(GWEN_CRYPT_TOKEN *ct,
   nameBuffer=GWEN_Buffer_new(0, 256, 0, 1);
   GWEN_Crypt_Token__CreatePasswordName(ct, pt, nameBuffer);
   rv=GWEN_Gui_SetPasswordStatus(GWEN_Buffer_GetStart(nameBuffer),
-				(const char*)buffer,
-				isOk?GWEN_Gui_PasswordStatus_Ok:
-				GWEN_Gui_PasswordStatus_Bad, gid);
+                                (const char *)buffer,
+                                isOk?GWEN_Gui_PasswordStatus_Ok:
+                                GWEN_Gui_PasswordStatus_Bad, gid);
   memset(ibuffer, 0, sizeof(ibuffer));
   GWEN_Buffer_free(nameBuffer);
   return rv;
@@ -916,8 +992,9 @@ int GWEN_Crypt_Token_SetPinStatus(GWEN_CRYPT_TOKEN *ct,
 
 
 uint32_t GWEN_Crypt_Token_BeginEnterPin(GWEN_CRYPT_TOKEN *ct,
-					GWEN_UNUSED GWEN_CRYPT_PINTYPE pt,
-					uint32_t gid) {
+                                        GWEN_UNUSED GWEN_CRYPT_PINTYPE pt,
+                                        uint32_t gid)
+{
   char buffer[512];
 
   assert(ct);
@@ -927,21 +1004,22 @@ uint32_t GWEN_Crypt_Token_BeginEnterPin(GWEN_CRYPT_TOKEN *ct,
   buffer[sizeof(buffer)-1]=0;
 
   snprintf(buffer, sizeof(buffer)-1, "%s",
-	   I18N("Please enter your PIN into the card reader."
-		"<html>"
-		"Please enter your PIN into the card reader."
-		"</html>"));
+           I18N("Please enter your PIN into the card reader."
+                "<html>"
+                "Please enter your PIN into the card reader."
+                "</html>"));
   return GWEN_Gui_ShowBox(GWEN_GUI_SHOWBOX_FLAGS_BEEP,
-			  I18N("Secure PIN Input"),
-			  buffer, gid);
+                          I18N("Secure PIN Input"),
+                          buffer, gid);
 }
 
 
 
 int GWEN_Crypt_Token_EndEnterPin(GWEN_CRYPT_TOKEN *ct,
-				 GWEN_UNUSED GWEN_CRYPT_PINTYPE pt,
-				 GWEN_UNUSED int ok,
-				 uint32_t id) {
+                                 GWEN_UNUSED GWEN_CRYPT_PINTYPE pt,
+                                 GWEN_UNUSED int ok,
+                                 uint32_t id)
+{
   assert(ct);
   assert(ct->refCount);
 
@@ -952,7 +1030,8 @@ int GWEN_Crypt_Token_EndEnterPin(GWEN_CRYPT_TOKEN *ct,
 
 
 
-int GWEN_Crypt_Token_InsertToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
+int GWEN_Crypt_Token_InsertToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid)
+{
   int rv;
   char buffer[512];
   const char *dname;
@@ -969,36 +1048,36 @@ int GWEN_Crypt_Token_InsertToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
 
   if (GWEN_Crypt_Token_GetDevice(ct)==GWEN_Crypt_Token_Device_File)
     snprintf(buffer, sizeof(buffer)-1,
-	     I18N("Please insert the security disc\nfor %s"
-		  "<html>"
-		  "Please insert the security disc for <i>%s</i>"
-		  "</html>"), dname, dname);
+             I18N("Please insert the security disc\nfor %s"
+                  "<html>"
+                  "Please insert the security disc for <i>%s</i>"
+                  "</html>"), dname, dname);
   else
     snprintf(buffer, sizeof(buffer)-1,
-	     I18N("Please insert the chip card\nfor %s"
-		  "<html>"
-		  "Please insert the chip card for <i>%s</i>"
-		  "</html>"), dname, dname);
+             I18N("Please insert the chip card\nfor %s"
+                  "<html>"
+                  "Please insert the chip card for <i>%s</i>"
+                  "</html>"), dname, dname);
 
   rv=GWEN_Gui_MessageBox(GWEN_GUI_MSG_FLAGS_TYPE_WARN |
-			 GWEN_GUI_MSG_FLAGS_SEVERITY_NORMAL |
-			 GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
-			 I18N("Insert Medium"),
-			 buffer,
-			 I18N("OK"), I18N("Abort"), 0, gid);
+                         GWEN_GUI_MSG_FLAGS_SEVERITY_NORMAL |
+                         GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
+                         I18N("Insert Medium"),
+                         buffer,
+                         I18N("OK"), I18N("Abort"), 0, gid);
   if (rv==2) {
     DBG_ERROR(GWEN_LOGDOMAIN, "User aborted");
     GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Notice,
-			 I18N("Aborted by user."));
+                         I18N("Aborted by user."));
     return GWEN_ERROR_USER_ABORTED;
   }
   else if (rv!=1) {
     GWEN_Gui_MessageBox(GWEN_GUI_MSG_FLAGS_TYPE_ERROR |
-			GWEN_GUI_MSG_FLAGS_SEVERITY_DANGEROUS |
-			GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
-			I18N("Error"),
-			I18N("An internal error occurred."),
-			I18N("Dismiss"), 0, 0, gid);
+                        GWEN_GUI_MSG_FLAGS_SEVERITY_DANGEROUS |
+                        GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
+                        I18N("Error"),
+                        I18N("An internal error occurred."),
+                        I18N("Dismiss"), 0, 0, gid);
     return -1;
   }
 
@@ -1007,7 +1086,8 @@ int GWEN_Crypt_Token_InsertToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
 
 
 
-int GWEN_Crypt_Token_InsertCorrectToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
+int GWEN_Crypt_Token_InsertCorrectToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid)
+{
   int rv;
   char buffer[512];
   const char *dname;
@@ -1024,52 +1104,52 @@ int GWEN_Crypt_Token_InsertCorrectToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
 
   if (GWEN_Crypt_Token_GetDevice(ct)==GWEN_Crypt_Token_Device_File)
     snprintf(buffer, sizeof(buffer)-1,
-	     I18N("Please insert the correct security disc\nfor %s"
-		  "<html>"
-		  "Please insert the correct security disc for <i>%s</i>"
-		  "</html>"), dname, dname);
+             I18N("Please insert the correct security disc\nfor %s"
+                  "<html>"
+                  "Please insert the correct security disc for <i>%s</i>"
+                  "</html>"), dname, dname);
   else {
     if (dname && *dname) {
       snprintf(buffer, sizeof(buffer)-1,
-	       I18N("The wrong chipcard has been inserted.\n"
-		    "Please insert the chipcard with the number\n"
-		    "  %s\n"
-		    "into the card reader.\n"
-		    "<html>"
-		    "<p>The wrong card has been inserted.</p>"
-		    "<p>Please insert the chipcard with the number"
-		    "<b>%s</b> into the card reader.</p>"
-		    "</html>"),
-	       dname,
-	       dname);
+               I18N("The wrong chipcard has been inserted.\n"
+                    "Please insert the chipcard with the number\n"
+                    "  %s\n"
+                    "into the card reader.\n"
+                    "<html>"
+                    "<p>The wrong card has been inserted.</p>"
+                    "<p>Please insert the chipcard with the number"
+                    "<b>%s</b> into the card reader.</p>"
+                    "</html>"),
+               dname,
+               dname);
     }
     else
       snprintf(buffer, sizeof(buffer)-1,
-	       I18N("Please insert the correct chipcard\nfor %s"
-		    "<html>"
-		    "Please insert the correct chipcard for <i>%s</i>"
-		    "</html>"), dname, dname);
+               I18N("Please insert the correct chipcard\nfor %s"
+                    "<html>"
+                    "Please insert the correct chipcard for <i>%s</i>"
+                    "</html>"), dname, dname);
   }
 
   rv=GWEN_Gui_MessageBox(GWEN_GUI_MSG_FLAGS_TYPE_WARN |
-			 GWEN_GUI_MSG_FLAGS_SEVERITY_DANGEROUS |
-			 GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
-			 I18N("Insert Medium"),
-			 buffer,
-			 I18N("OK"), I18N("Abort"), 0, gid);
+                         GWEN_GUI_MSG_FLAGS_SEVERITY_DANGEROUS |
+                         GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
+                         I18N("Insert Medium"),
+                         buffer,
+                         I18N("OK"), I18N("Abort"), 0, gid);
   if (rv==2) {
     DBG_ERROR(GWEN_LOGDOMAIN, "User aborted");
     GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Notice,
-			 I18N("Aborted by user."));
+                         I18N("Aborted by user."));
     return GWEN_ERROR_USER_ABORTED;
   }
   else if (rv!=1) {
     GWEN_Gui_MessageBox(GWEN_GUI_MSG_FLAGS_TYPE_ERROR |
-			GWEN_GUI_MSG_FLAGS_SEVERITY_DANGEROUS |
-			GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
-			I18N("Error"),
-			I18N("An internal error occurred."),
-			I18N("Dismiss"), 0, 0, gid);
+                        GWEN_GUI_MSG_FLAGS_SEVERITY_DANGEROUS |
+                        GWEN_GUI_MSG_FLAGS_CONFIRM_B1,
+                        I18N("Error"),
+                        I18N("An internal error occurred."),
+                        I18N("Dismiss"), 0, 0, gid);
     return -1;
   }
 
@@ -1078,7 +1158,8 @@ int GWEN_Crypt_Token_InsertCorrectToken(GWEN_CRYPT_TOKEN *ct, uint32_t gid) {
 
 
 
-GWEN_CRYPT_TOKEN_DEVICE GWEN_Crypt_Token_Device_fromString(const char *s){
+GWEN_CRYPT_TOKEN_DEVICE GWEN_Crypt_Token_Device_fromString(const char *s)
+{
   assert(s);
   if (strcasecmp(s, "none")==0)
     return GWEN_Crypt_Token_Device_None;
@@ -1093,8 +1174,9 @@ GWEN_CRYPT_TOKEN_DEVICE GWEN_Crypt_Token_Device_fromString(const char *s){
 
 
 
-const char *GWEN_Crypt_Token_Device_toString(GWEN_CRYPT_TOKEN_DEVICE d){
-  switch(d) {
+const char *GWEN_Crypt_Token_Device_toString(GWEN_CRYPT_TOKEN_DEVICE d)
+{
+  switch (d) {
   case GWEN_Crypt_Token_Device_None:
     return "none";
   case GWEN_Crypt_Token_Device_File:
