@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: crypttoken.h 1113 2007-01-10 09:14:16Z martin $
     begin       : Wed Mar 16 2005
-    copyright   : (C) 2005 by Martin Preuss
+    copyright   : (C) 2005-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -14,6 +11,8 @@
 # include <config.h>
 #endif
 
+#define DISABLE_DEBUGLOG
+
 
 #include "ctf_context_p.h"
 #include <gwenhywfar/misc.h>
@@ -28,21 +27,23 @@ GWEN_INHERIT(GWEN_CRYPT_TOKEN_CONTEXT, GWEN_CTF_CONTEXT)
 
 
 
-GWEN_CRYPT_TOKEN_CONTEXT *GWEN_CTF_Context_new() {
+GWEN_CRYPT_TOKEN_CONTEXT *GWEN_CTF_Context_new()
+{
   GWEN_CRYPT_TOKEN_CONTEXT *ctx;
   GWEN_CTF_CONTEXT *fctx;
 
   ctx=GWEN_Crypt_Token_Context_new();
   GWEN_NEW_OBJECT(GWEN_CTF_CONTEXT, fctx)
   GWEN_INHERIT_SETDATA(GWEN_CRYPT_TOKEN_CONTEXT, GWEN_CTF_CONTEXT, ctx, fctx,
-		       GWEN_CTF_Context_freeData)
+                       GWEN_CTF_Context_freeData)
 
   return ctx;
 }
 
 
 
-int GWEN_CTF_Context_IsOfThisType(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+int GWEN_CTF_Context_IsOfThisType(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   assert(ctx);
   return GWEN_INHERIT_ISOFTYPE(GWEN_CRYPT_TOKEN_CONTEXT, GWEN_CTF_CONTEXT, ctx);
 }
@@ -50,16 +51,18 @@ int GWEN_CTF_Context_IsOfThisType(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
 
 
 GWENHYWFAR_CB
-void GWEN_CTF_Context_freeData(GWEN_UNUSED void *bp, void *p) {
+void GWEN_CTF_Context_freeData(GWEN_UNUSED void *bp, void *p)
+{
   GWEN_CTF_CONTEXT *fctx;
 
-  fctx=(GWEN_CTF_CONTEXT*) p;
+  fctx=(GWEN_CTF_CONTEXT *) p;
   GWEN_Crypt_Key_free(fctx->localSignKey);
   GWEN_Crypt_Key_free(fctx->localCryptKey);
   GWEN_Crypt_Key_free(fctx->remoteSignKey);
   GWEN_Crypt_Key_free(fctx->remoteCryptKey);
   GWEN_Crypt_Key_free(fctx->localAuthKey);
   GWEN_Crypt_Key_free(fctx->remoteAuthKey);
+  GWEN_Crypt_Key_free(fctx->tempLocalSignKey);
 
   GWEN_Crypt_Token_KeyInfo_free(fctx->localSignKeyInfo);
   GWEN_Crypt_Token_KeyInfo_free(fctx->localCryptKeyInfo);
@@ -67,13 +70,15 @@ void GWEN_CTF_Context_freeData(GWEN_UNUSED void *bp, void *p) {
   GWEN_Crypt_Token_KeyInfo_free(fctx->remoteCryptKeyInfo);
   GWEN_Crypt_Token_KeyInfo_free(fctx->localAuthKeyInfo);
   GWEN_Crypt_Token_KeyInfo_free(fctx->remoteAuthKeyInfo);
+  GWEN_Crypt_Token_KeyInfo_free(fctx->tempLocalSignKeyInfo);
 
   GWEN_FREE_OBJECT(fctx);
 }
 
 
 
-GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalSignKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalSignKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -85,7 +90,8 @@ GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalSignKey(const GWEN_CRYPT_TOKEN_CONTEXT
 
 
 
-void GWEN_CTF_Context_SetLocalSignKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k) {
+void GWEN_CTF_Context_SetLocalSignKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -98,7 +104,8 @@ void GWEN_CTF_Context_SetLocalSignKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_
 
 
 
-GWEN_CRYPT_TOKEN_KEYINFO*GWEN_CTF_Context_GetLocalSignKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetLocalSignKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -110,7 +117,8 @@ GWEN_CRYPT_TOKEN_KEYINFO*GWEN_CTF_Context_GetLocalSignKeyInfo(const GWEN_CRYPT_T
 
 
 
-void GWEN_CTF_Context_SetLocalSignKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki) {
+void GWEN_CTF_Context_SetLocalSignKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -123,7 +131,8 @@ void GWEN_CTF_Context_SetLocalSignKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CR
 
 
 
-GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalCryptKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalCryptKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -135,7 +144,8 @@ GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalCryptKey(const GWEN_CRYPT_TOKEN_CONTEXT
 
 
 
-void GWEN_CTF_Context_SetLocalCryptKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k) {
+void GWEN_CTF_Context_SetLocalCryptKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -148,7 +158,8 @@ void GWEN_CTF_Context_SetLocalCryptKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT
 
 
 
-GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetLocalCryptKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetLocalCryptKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -160,7 +171,8 @@ GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetLocalCryptKeyInfo(const GWEN_CRYPT
 
 
 
-void GWEN_CTF_Context_SetLocalCryptKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki) {
+void GWEN_CTF_Context_SetLocalCryptKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -173,7 +185,8 @@ void GWEN_CTF_Context_SetLocalCryptKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_C
 
 
 
-GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteSignKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteSignKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -185,7 +198,8 @@ GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteSignKey(const GWEN_CRYPT_TOKEN_CONTEXT
 
 
 
-void GWEN_CTF_Context_SetRemoteSignKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k) {
+void GWEN_CTF_Context_SetRemoteSignKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -198,7 +212,8 @@ void GWEN_CTF_Context_SetRemoteSignKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT
 
 
 
-GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteSignKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteSignKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -210,7 +225,8 @@ GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteSignKeyInfo(const GWEN_CRYPT
 
 
 
-void GWEN_CTF_Context_SetRemoteSignKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki) {
+void GWEN_CTF_Context_SetRemoteSignKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -223,7 +239,8 @@ void GWEN_CTF_Context_SetRemoteSignKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_C
 
 
 
-GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteCryptKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteCryptKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -235,7 +252,8 @@ GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteCryptKey(const GWEN_CRYPT_TOKEN_CONTEX
 
 
 
-void GWEN_CTF_Context_SetRemoteCryptKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k) {
+void GWEN_CTF_Context_SetRemoteCryptKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -248,7 +266,8 @@ void GWEN_CTF_Context_SetRemoteCryptKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYP
 
 
 
-GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteCryptKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteCryptKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -260,7 +279,8 @@ GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteCryptKeyInfo(const GWEN_CRYP
 
 
 
-void GWEN_CTF_Context_SetRemoteCryptKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki) {
+void GWEN_CTF_Context_SetRemoteCryptKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -273,7 +293,8 @@ void GWEN_CTF_Context_SetRemoteCryptKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_
 
 
 
-GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalAuthKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalAuthKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -285,7 +306,8 @@ GWEN_CRYPT_KEY *GWEN_CTF_Context_GetLocalAuthKey(const GWEN_CRYPT_TOKEN_CONTEXT
 
 
 
-void GWEN_CTF_Context_SetLocalAuthKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k) {
+void GWEN_CTF_Context_SetLocalAuthKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -298,7 +320,8 @@ void GWEN_CTF_Context_SetLocalAuthKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_
 
 
 
-GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetLocalAuthKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetLocalAuthKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -310,7 +333,8 @@ GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetLocalAuthKeyInfo(const GWEN_CRYPT_
 
 
 
-void GWEN_CTF_Context_SetLocalAuthKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki) {
+void GWEN_CTF_Context_SetLocalAuthKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -323,7 +347,8 @@ void GWEN_CTF_Context_SetLocalAuthKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CR
 
 
 
-GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteAuthKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteAuthKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -335,7 +360,8 @@ GWEN_CRYPT_KEY *GWEN_CTF_Context_GetRemoteAuthKey(const GWEN_CRYPT_TOKEN_CONTEXT
 
 
 
-void GWEN_CTF_Context_SetRemoteAuthKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k) {
+void GWEN_CTF_Context_SetRemoteAuthKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -348,7 +374,8 @@ void GWEN_CTF_Context_SetRemoteAuthKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT
 
 
 
-GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteAuthKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx) {
+GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteAuthKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -360,7 +387,8 @@ GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetRemoteAuthKeyInfo(const GWEN_CRYPT
 
 
 
-void GWEN_CTF_Context_SetRemoteAuthKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki) {
+void GWEN_CTF_Context_SetRemoteAuthKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki)
+{
   GWEN_CTF_CONTEXT *fctx;
 
   assert(ctx);
@@ -373,6 +401,60 @@ void GWEN_CTF_Context_SetRemoteAuthKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_C
 
 
 
+GWEN_CRYPT_KEY *GWEN_CTF_Context_GetTempLocalSignKey(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
+  GWEN_CTF_CONTEXT *fctx;
+
+  assert(ctx);
+  fctx=GWEN_INHERIT_GETDATA(GWEN_CRYPT_TOKEN_CONTEXT, GWEN_CTF_CONTEXT, ctx);
+  assert(fctx);
+
+  return fctx->tempLocalSignKey;
+}
+
+
+
+void GWEN_CTF_Context_SetTempLocalSignKey(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_KEY *k)
+{
+  GWEN_CTF_CONTEXT *fctx;
+
+  assert(ctx);
+  fctx=GWEN_INHERIT_GETDATA(GWEN_CRYPT_TOKEN_CONTEXT, GWEN_CTF_CONTEXT, ctx);
+  assert(fctx);
+
+  GWEN_Crypt_Key_free(fctx->tempLocalSignKey);
+  fctx->tempLocalSignKey=k;
+}
+
+
+
+GWEN_CRYPT_TOKEN_KEYINFO *GWEN_CTF_Context_GetTempLocalSignKeyInfo(const GWEN_CRYPT_TOKEN_CONTEXT *ctx)
+{
+  GWEN_CTF_CONTEXT *fctx;
+
+  assert(ctx);
+  fctx=GWEN_INHERIT_GETDATA(GWEN_CRYPT_TOKEN_CONTEXT, GWEN_CTF_CONTEXT, ctx);
+  assert(fctx);
+
+  return fctx->tempLocalSignKeyInfo;
+}
+
+
+
+void GWEN_CTF_Context_SetTempLocalSignKeyInfo(GWEN_CRYPT_TOKEN_CONTEXT *ctx, GWEN_CRYPT_TOKEN_KEYINFO *ki)
+{
+  GWEN_CTF_CONTEXT *fctx;
+
+  assert(ctx);
+  fctx=GWEN_INHERIT_GETDATA(GWEN_CRYPT_TOKEN_CONTEXT, GWEN_CTF_CONTEXT, ctx);
+  assert(fctx);
+
+  GWEN_Crypt_Token_KeyInfo_free(fctx->tempLocalSignKeyInfo);
+  fctx->tempLocalSignKeyInfo=ki;
+}
+
+
+
 
 
 
