@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Wed Jan 20 2010
-    copyright   : (C) 2010 by Martin Preuss
+    copyright   : (C) 2019 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -50,7 +50,8 @@ GWEN_LIST2_FUNCTIONS(GWEN_DIALOG, GWEN_Dialog)
 
 
 
-GWEN_DIALOG *GWEN_Dialog_new(const char *dialogId) {
+GWEN_DIALOG *GWEN_Dialog_new(const char *dialogId)
+{
   GWEN_DIALOG *dlg;
   int rv;
   GWEN_DB_NODE *db=NULL;
@@ -85,7 +86,55 @@ GWEN_DIALOG *GWEN_Dialog_new(const char *dialogId) {
 
 
 
-void GWEN_Dialog_free(GWEN_DIALOG *dlg) {
+GWEN_DIALOG *GWEN_Dialog_CreateAndLoadWithPath(const char *dialogId,
+                                               const char *pmLibName,
+                                               const char *pmDataDir,
+                                               const char *fileName)
+{
+  GWEN_DIALOG *dlg;
+  GWEN_BUFFER *fbuf;
+  int rv;
+
+  assert(dialogId);
+  assert(pmLibName);
+  assert(pmDataDir);
+  assert(fileName);
+
+  dlg=GWEN_Dialog_new(dialogId);
+  if (dlg==NULL) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Could not create dialog");
+    return NULL;
+  }
+
+  /* get path of dialog description file */
+  fbuf=GWEN_Buffer_new(0, 256, 0, 1);
+  rv=GWEN_PathManager_FindFile(pmLibName, pmDataDir, fileName, fbuf);
+  if (rv<0) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Dialog description file not found (%d).", rv);
+    GWEN_Buffer_free(fbuf);
+    GWEN_Dialog_free(dlg);
+    return NULL;
+  }
+
+  /* read dialog from dialog description file */
+  rv=GWEN_Dialog_ReadXmlFile(dlg, GWEN_Buffer_GetStart(fbuf));
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d).", rv);
+    GWEN_Buffer_free(fbuf);
+    GWEN_Dialog_free(dlg);
+    return NULL;
+  }
+  DBG_INFO(GWEN_LOGDOMAIN, "Dialog \"%s\" loaded from \"%s\"", dialogId, GWEN_Buffer_GetStart(fbuf));
+  GWEN_Buffer_free(fbuf);
+
+  return dlg;
+}
+
+
+
+
+void GWEN_Dialog_free(GWEN_DIALOG *dlg)
+{
   if (dlg) {
     assert(dlg->refCount);
 
@@ -98,7 +147,7 @@ void GWEN_Dialog_free(GWEN_DIALOG *dlg) {
       /* try to save preferences */
       rv=GWEN_Gui_WriteDialogPrefs(dlg->dialogId, dlg->dbPreferences);
       if (rv<0) {
-	DBG_WARN(GWEN_LOGDOMAIN, "Could not write dialog preferences (%d)", rv);
+        DBG_WARN(GWEN_LOGDOMAIN, "Could not write dialog preferences (%d)", rv);
       }
 
       GWEN_INHERIT_FINI(GWEN_DIALOG, dlg);
@@ -119,7 +168,8 @@ void GWEN_Dialog_free(GWEN_DIALOG *dlg) {
 
 
 
-GWEN_DIALOG *GWEN_Dialog_GetParentDialog(const GWEN_DIALOG *dlg) {
+GWEN_DIALOG *GWEN_Dialog_GetParentDialog(const GWEN_DIALOG *dlg)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -128,7 +178,8 @@ GWEN_DIALOG *GWEN_Dialog_GetParentDialog(const GWEN_DIALOG *dlg) {
 
 
 
-const char *GWEN_Dialog_GetId(const GWEN_DIALOG *dlg) {
+const char *GWEN_Dialog_GetId(const GWEN_DIALOG *dlg)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -137,7 +188,8 @@ const char *GWEN_Dialog_GetId(const GWEN_DIALOG *dlg) {
 
 
 
-uint32_t GWEN_Dialog_GetGuiId(const GWEN_DIALOG *dlg) {
+uint32_t GWEN_Dialog_GetGuiId(const GWEN_DIALOG *dlg)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -146,7 +198,8 @@ uint32_t GWEN_Dialog_GetGuiId(const GWEN_DIALOG *dlg) {
 
 
 
-void GWEN_Dialog_SetGuiId(GWEN_DIALOG *dlg, uint32_t guiid) {
+void GWEN_Dialog_SetGuiId(GWEN_DIALOG *dlg, uint32_t guiid)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -155,18 +208,22 @@ void GWEN_Dialog_SetGuiId(GWEN_DIALOG *dlg, uint32_t guiid) {
 
 
 
-void GWEN_Dialog_SetI18nDomain(GWEN_DIALOG *dlg, const char *s) {
+void GWEN_Dialog_SetI18nDomain(GWEN_DIALOG *dlg, const char *s)
+{
   assert(dlg);
   assert(dlg->refCount);
 
   free(dlg->i18nDomain);
-  if (s) dlg->i18nDomain=strdup(s);
-  else dlg->i18nDomain=strdup(PACKAGE);
+  if (s)
+    dlg->i18nDomain=strdup(s);
+  else
+    dlg->i18nDomain=strdup(PACKAGE);
 }
 
 
 
-const char *GWEN_Dialog_GetI18nDomain(const GWEN_DIALOG *dlg) {
+const char *GWEN_Dialog_GetI18nDomain(const GWEN_DIALOG *dlg)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -175,7 +232,8 @@ const char *GWEN_Dialog_GetI18nDomain(const GWEN_DIALOG *dlg) {
 
 
 
-const char *GWEN_Dialog_TranslateString(const GWEN_DIALOG *dlg, const char *s) {
+const char *GWEN_Dialog_TranslateString(const GWEN_DIALOG *dlg, const char *s)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -184,7 +242,8 @@ const char *GWEN_Dialog_TranslateString(const GWEN_DIALOG *dlg, const char *s) {
 
 
 
-void GWEN_Dialog_AddMediaPath(GWEN_DIALOG *dlg, const char *s) {
+void GWEN_Dialog_AddMediaPath(GWEN_DIALOG *dlg, const char *s)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -194,9 +253,10 @@ void GWEN_Dialog_AddMediaPath(GWEN_DIALOG *dlg, const char *s) {
 
 
 void GWEN_Dialog_AddMediaPathsFromPathManager(GWEN_DIALOG *dlg,
-					      const char *destlib,
-					      const char *pathName,
-					      const char *relPath) {
+                                              const char *destlib,
+                                              const char *pathName,
+                                              const char *relPath)
+{
   GWEN_STRINGLIST *sl;
 
   sl=GWEN_PathManager_GetPaths(destlib, pathName);
@@ -207,21 +267,21 @@ void GWEN_Dialog_AddMediaPathsFromPathManager(GWEN_DIALOG *dlg,
       GWEN_BUFFER *tbuf;
 
       tbuf=GWEN_Buffer_new(0, 256, 0, 1);
-      while(se) {
-	const char *s;
+      while (se) {
+        const char *s;
 
-	s=GWEN_StringListEntry_Data(se);
-	assert(s);
-	if (relPath) {
-	  GWEN_Buffer_AppendString(tbuf, s);
-	  GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
-	  GWEN_Buffer_AppendString(tbuf, relPath);
-	  GWEN_StringList_AppendString(dlg->mediaPaths, GWEN_Buffer_GetStart(tbuf), 0, 1);
-	  GWEN_Buffer_Reset(tbuf);
-	}
-	else
-	  GWEN_StringList_AppendString(dlg->mediaPaths, s, 0, 1);
-	se=GWEN_StringListEntry_Next(se);
+        s=GWEN_StringListEntry_Data(se);
+        assert(s);
+        if (relPath) {
+          GWEN_Buffer_AppendString(tbuf, s);
+          GWEN_Buffer_AppendString(tbuf, GWEN_DIR_SEPARATOR_S);
+          GWEN_Buffer_AppendString(tbuf, relPath);
+          GWEN_StringList_AppendString(dlg->mediaPaths, GWEN_Buffer_GetStart(tbuf), 0, 1);
+          GWEN_Buffer_Reset(tbuf);
+        }
+        else
+          GWEN_StringList_AppendString(dlg->mediaPaths, s, 0, 1);
+        se=GWEN_StringListEntry_Next(se);
       }
       GWEN_Buffer_free(tbuf);
     }
@@ -231,7 +291,8 @@ void GWEN_Dialog_AddMediaPathsFromPathManager(GWEN_DIALOG *dlg,
 
 
 
-GWEN_STRINGLIST *GWEN_Dialog_GetMediaPaths(const GWEN_DIALOG *dlg) {
+GWEN_STRINGLIST *GWEN_Dialog_GetMediaPaths(const GWEN_DIALOG *dlg)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -241,7 +302,8 @@ GWEN_STRINGLIST *GWEN_Dialog_GetMediaPaths(const GWEN_DIALOG *dlg) {
 
 
 GWEN_DIALOG_SIGNALHANDLER GWEN_Dialog_SetSignalHandler(GWEN_DIALOG *dlg,
-						       GWEN_DIALOG_SIGNALHANDLER fn) {
+                                                       GWEN_DIALOG_SIGNALHANDLER fn)
+{
   GWEN_DIALOG_SIGNALHANDLER oh;
 
   assert(dlg);
@@ -256,8 +318,9 @@ GWEN_DIALOG_SIGNALHANDLER GWEN_Dialog_SetSignalHandler(GWEN_DIALOG *dlg,
 
 
 int GWEN_Dialog_EmitSignal(GWEN_DIALOG *dlg,
-			   GWEN_DIALOG_EVENTTYPE t,
-			   const char *sender) {
+                           GWEN_DIALOG_EVENTTYPE t,
+                           const char *sender)
+{
   assert(dlg);
   assert(dlg->refCount);
 
@@ -265,7 +328,7 @@ int GWEN_Dialog_EmitSignal(GWEN_DIALOG *dlg,
     return (dlg->signalHandler)(dlg, t, sender);
   else {
     DBG_WARN(GWEN_LOGDOMAIN, "No signal handler in dialog [%s]",
-	     (dlg->dialogId)?(dlg->dialogId):"-unnamed-");
+             (dlg->dialogId)?(dlg->dialogId):"-unnamed-");
     return GWEN_DialogEvent_ResultNotHandled;
   }
 }
@@ -273,8 +336,9 @@ int GWEN_Dialog_EmitSignal(GWEN_DIALOG *dlg,
 
 
 int GWEN_Dialog_EmitSignalToAll(GWEN_DIALOG *dlg,
-				GWEN_DIALOG_EVENTTYPE t,
-				const char *sender) {
+                                GWEN_DIALOG_EVENTTYPE t,
+                                const char *sender)
+{
   int rv;
   GWEN_DIALOG *subdlg;
 
@@ -282,10 +346,10 @@ int GWEN_Dialog_EmitSignalToAll(GWEN_DIALOG *dlg,
   assert(dlg->refCount);
 
   subdlg=GWEN_Dialog_List_First(dlg->subDialogs);
-  while(subdlg) {
+  while (subdlg) {
     rv=GWEN_Dialog_EmitSignalToAll(subdlg, t, sender);
     if (rv!=GWEN_DialogEvent_ResultHandled &&
-	rv!=GWEN_DialogEvent_ResultNotHandled)
+        rv!=GWEN_DialogEvent_ResultNotHandled)
       return rv;
     subdlg=GWEN_Dialog_List_Next(subdlg);
   }
@@ -293,7 +357,7 @@ int GWEN_Dialog_EmitSignalToAll(GWEN_DIALOG *dlg,
   if (dlg->signalHandler) {
     rv=(dlg->signalHandler)(dlg, t, sender);
     if (rv!=GWEN_DialogEvent_ResultHandled &&
-	rv!=GWEN_DialogEvent_ResultNotHandled)
+        rv!=GWEN_DialogEvent_ResultNotHandled)
       return rv;
   }
 
@@ -304,7 +368,8 @@ int GWEN_Dialog_EmitSignalToAll(GWEN_DIALOG *dlg,
 
 int GWEN_Dialog_AddSubDialog(GWEN_DIALOG *dlg,
                              const char *parentName,
-			     GWEN_DIALOG *subdlg) {
+                             GWEN_DIALOG *subdlg)
+{
   GWEN_WIDGET *wparent;
 
   wparent=GWEN_Dialog_FindWidgetByName(dlg, parentName);
@@ -315,11 +380,11 @@ int GWEN_Dialog_AddSubDialog(GWEN_DIALOG *dlg,
     /* move all widgets from the below sub dialog's root widget to the parent dialog */
     subRoot=GWEN_Widget_Tree_GetFirst(subdlg->widgets);
     if (subRoot) {
-      while( (cw=GWEN_Widget_Tree_GetFirstChild(subRoot)) ) {
-	if (subdlg->firstSubWidget==NULL)
-	  subdlg->firstSubWidget=cw;
-	GWEN_Widget_Tree_Del(cw);
-	GWEN_Widget_Tree_AddChild(wparent, cw);
+      while ((cw=GWEN_Widget_Tree_GetFirstChild(subRoot))) {
+        if (subdlg->firstSubWidget==NULL)
+          subdlg->firstSubWidget=cw;
+        GWEN_Widget_Tree_Del(cw);
+        GWEN_Widget_Tree_AddChild(wparent, cw);
       }
     }
 
@@ -342,8 +407,9 @@ int GWEN_Dialog_AddSubDialog(GWEN_DIALOG *dlg,
 
 
 int GWEN_Dialog__ReadXmlWidget(GWEN_DIALOG *dlg,
-			       GWEN_WIDGET *wparent,
-			       GWEN_XMLNODE *node) {
+                               GWEN_WIDGET *wparent,
+                               GWEN_XMLNODE *node)
+{
   GWEN_XMLNODE *n;
   GWEN_WIDGET *w;
   int rv;
@@ -363,7 +429,7 @@ int GWEN_Dialog__ReadXmlWidget(GWEN_DIALOG *dlg,
 
 
   n=GWEN_XMLNode_FindFirstTag(node, "widget", NULL, NULL);
-  while(n) {
+  while (n) {
     int rv;
 
     rv=GWEN_Dialog__ReadXmlWidget(dlg, w, n);
@@ -377,7 +443,8 @@ int GWEN_Dialog__ReadXmlWidget(GWEN_DIALOG *dlg,
 
 
 
-int GWEN_Dialog_ReadXml(GWEN_DIALOG *dlg, GWEN_XMLNODE *node) {
+int GWEN_Dialog_ReadXml(GWEN_DIALOG *dlg, GWEN_XMLNODE *node)
+{
   int rv;
   const char *s;
 
@@ -404,24 +471,25 @@ int GWEN_Dialog_ReadXml(GWEN_DIALOG *dlg, GWEN_XMLNODE *node) {
 
 
 
-int GWEN_Dialog_ReadXmlFile(GWEN_DIALOG *dlg, const char *fname) {
+int GWEN_Dialog_ReadXmlFile(GWEN_DIALOG *dlg, const char *fname)
+{
   GWEN_XMLNODE *n;
   GWEN_XMLNODE *nDialog;
   int rv;
 
   n=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "root");
   rv=GWEN_XML_ReadFile(n, fname,
-		       GWEN_XML_FLAGS_DEFAULT |
-		       GWEN_XML_FLAGS_HANDLE_HEADERS);
+                       GWEN_XML_FLAGS_DEFAULT |
+                       GWEN_XML_FLAGS_HANDLE_HEADERS);
   if (rv<0) {
-    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    DBG_ERROR(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_XMLNode_free(n);
     return rv;
   }
 
   nDialog=GWEN_XMLNode_FindFirstTag(n, "dialog", NULL, NULL);
   if (nDialog==NULL) {
-    DBG_INFO(GWEN_LOGDOMAIN, "Dialog element not found in XML file [%s]", fname);
+    DBG_ERROR(GWEN_LOGDOMAIN, "Dialog element not found in XML file [%s]", fname);
     GWEN_XMLNode_free(n);
     return rv;
   }
@@ -439,7 +507,8 @@ int GWEN_Dialog_ReadXmlFile(GWEN_DIALOG *dlg, const char *fname) {
 
 
 
-GWEN_WIDGET *GWEN_Dialog_FindWidgetByName(const GWEN_DIALOG *dlg, const char *name) {
+GWEN_WIDGET *GWEN_Dialog_FindWidgetByName(const GWEN_DIALOG *dlg, const char *name)
+{
   GWEN_WIDGET *w;
 
   assert(dlg);
@@ -462,7 +531,7 @@ GWEN_WIDGET *GWEN_Dialog_FindWidgetByName(const GWEN_DIALOG *dlg, const char *na
   }
 #endif
 
-  while(w) {
+  while (w) {
     const char *s;
 
     s=GWEN_Widget_GetName(w);
@@ -476,7 +545,8 @@ GWEN_WIDGET *GWEN_Dialog_FindWidgetByName(const GWEN_DIALOG *dlg, const char *na
 
 
 
-GWEN_WIDGET *GWEN_Dialog_FindWidgetByImplData(const GWEN_DIALOG *dlg, int index, const void *ptr) {
+GWEN_WIDGET *GWEN_Dialog_FindWidgetByImplData(const GWEN_DIALOG *dlg, int index, const void *ptr)
+{
   GWEN_WIDGET *w;
 
   assert(dlg);
@@ -488,7 +558,7 @@ GWEN_WIDGET *GWEN_Dialog_FindWidgetByImplData(const GWEN_DIALOG *dlg, int index,
   else
     w=GWEN_Widget_Tree_GetFirst(dlg->widgets);
 
-  while(w) {
+  while (w) {
     if (ptr==GWEN_Widget_GetImplData(w, index))
       break;
     w=GWEN_Widget_Tree_GetBelow(w);
@@ -499,7 +569,8 @@ GWEN_WIDGET *GWEN_Dialog_FindWidgetByImplData(const GWEN_DIALOG *dlg, int index,
 
 
 
-GWEN_WIDGET_TREE *GWEN_Dialog_GetWidgets(const GWEN_DIALOG *dlg) {
+GWEN_WIDGET_TREE *GWEN_Dialog_GetWidgets(const GWEN_DIALOG *dlg)
+{
   assert(dlg);
   assert(dlg->refCount);
   assert(dlg->widgets);
@@ -510,7 +581,8 @@ GWEN_WIDGET_TREE *GWEN_Dialog_GetWidgets(const GWEN_DIALOG *dlg) {
 
 
 GWEN_DIALOG_SETINTPROPERTY_FN GWEN_Dialog_SetSetIntPropertyFn(GWEN_DIALOG *dlg,
-							      GWEN_DIALOG_SETINTPROPERTY_FN fn) {
+                                                              GWEN_DIALOG_SETINTPROPERTY_FN fn)
+{
   GWEN_DIALOG_SETINTPROPERTY_FN oh;
 
   assert(dlg);
@@ -524,7 +596,8 @@ GWEN_DIALOG_SETINTPROPERTY_FN GWEN_Dialog_SetSetIntPropertyFn(GWEN_DIALOG *dlg,
 
 
 GWEN_DIALOG_GETINTPROPERTY_FN GWEN_Dialog_SetGetIntPropertyFn(GWEN_DIALOG *dlg,
-							      GWEN_DIALOG_GETINTPROPERTY_FN fn) {
+                                                              GWEN_DIALOG_GETINTPROPERTY_FN fn)
+{
   GWEN_DIALOG_GETINTPROPERTY_FN oh;
 
   assert(dlg);
@@ -538,7 +611,8 @@ GWEN_DIALOG_GETINTPROPERTY_FN GWEN_Dialog_SetGetIntPropertyFn(GWEN_DIALOG *dlg,
 
 
 GWEN_DIALOG_SETCHARPROPERTY_FN GWEN_Dialog_SetSetCharPropertyFn(GWEN_DIALOG *dlg,
-								GWEN_DIALOG_SETCHARPROPERTY_FN fn) {
+                                                                GWEN_DIALOG_SETCHARPROPERTY_FN fn)
+{
   GWEN_DIALOG_SETCHARPROPERTY_FN oh;
 
   assert(dlg);
@@ -552,7 +626,8 @@ GWEN_DIALOG_SETCHARPROPERTY_FN GWEN_Dialog_SetSetCharPropertyFn(GWEN_DIALOG *dlg
 
 
 GWEN_DIALOG_GETCHARPROPERTY_FN GWEN_Dialog_SetGetCharPropertyFn(GWEN_DIALOG *dlg,
-								GWEN_DIALOG_GETCHARPROPERTY_FN fn) {
+                                                                GWEN_DIALOG_GETCHARPROPERTY_FN fn)
+{
   GWEN_DIALOG_GETCHARPROPERTY_FN oh;
 
   assert(dlg);
@@ -569,11 +644,12 @@ GWEN_DIALOG_GETCHARPROPERTY_FN GWEN_Dialog_SetGetCharPropertyFn(GWEN_DIALOG *dlg
 
 
 int GWEN_Dialog_SetIntProperty(GWEN_DIALOG *dlg,
-			       const char *name,
-			       GWEN_DIALOG_PROPERTY prop,
-			       int index,
-			       int value,
-			       int doSignal) {
+                               const char *name,
+                               GWEN_DIALOG_PROPERTY prop,
+                               int index,
+                               int value,
+                               int doSignal)
+{
   GWEN_WIDGET *w;
 
   assert(dlg);
@@ -598,10 +674,11 @@ int GWEN_Dialog_SetIntProperty(GWEN_DIALOG *dlg,
 
 
 int GWEN_Dialog_GetIntProperty(GWEN_DIALOG *dlg,
-			       const char *name,
-			       GWEN_DIALOG_PROPERTY prop,
-			       int index,
-			       int defaultProperty) {
+                               const char *name,
+                               GWEN_DIALOG_PROPERTY prop,
+                               int index,
+                               int defaultProperty)
+{
   GWEN_WIDGET *w;
 
   assert(dlg);
@@ -626,11 +703,12 @@ int GWEN_Dialog_GetIntProperty(GWEN_DIALOG *dlg,
 
 
 int GWEN_Dialog_SetCharProperty(GWEN_DIALOG *dlg,
-				const char *name,
-				GWEN_DIALOG_PROPERTY prop,
-				int index,
-				const char *value,
-				int doSignal) {
+                                const char *name,
+                                GWEN_DIALOG_PROPERTY prop,
+                                int index,
+                                const char *value,
+                                int doSignal)
+{
   GWEN_WIDGET *w;
 
   assert(dlg);
@@ -655,10 +733,11 @@ int GWEN_Dialog_SetCharProperty(GWEN_DIALOG *dlg,
 
 
 const char *GWEN_Dialog_GetCharProperty(GWEN_DIALOG *dlg,
-					const char *name,
-					GWEN_DIALOG_PROPERTY prop,
-					int index,
-					const char *defaultProperty) {
+                                        const char *name,
+                                        GWEN_DIALOG_PROPERTY prop,
+                                        int index,
+                                        const char *defaultProperty)
+{
   GWEN_WIDGET *w;
 
   assert(dlg);
@@ -682,7 +761,8 @@ const char *GWEN_Dialog_GetCharProperty(GWEN_DIALOG *dlg,
 
 
 
-int GWEN_Dialog_RemoveWidget(GWEN_DIALOG *dlg, const char *name) {
+int GWEN_Dialog_RemoveWidget(GWEN_DIALOG *dlg, const char *name)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -696,7 +776,8 @@ int GWEN_Dialog_RemoveWidget(GWEN_DIALOG *dlg, const char *name) {
 }
 
 
-uint32_t GWEN_Dialog_GetWidgetFlags(const GWEN_DIALOG *dlg, const char *name) {
+uint32_t GWEN_Dialog_GetWidgetFlags(const GWEN_DIALOG *dlg, const char *name)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -709,7 +790,8 @@ uint32_t GWEN_Dialog_GetWidgetFlags(const GWEN_DIALOG *dlg, const char *name) {
 
 
 
-void GWEN_Dialog_SetWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl) {
+void GWEN_Dialog_SetWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -720,7 +802,8 @@ void GWEN_Dialog_SetWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl)
 
 
 
-void GWEN_Dialog_AddWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl) {
+void GWEN_Dialog_AddWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -731,7 +814,8 @@ void GWEN_Dialog_AddWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl)
 
 
 
-void GWEN_Dialog_SubWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl) {
+void GWEN_Dialog_SubWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -742,7 +826,8 @@ void GWEN_Dialog_SubWidgetFlags(GWEN_DIALOG *dlg, const char *name, uint32_t fl)
 
 
 
-int GWEN_Dialog_GetWidgetColumns(const GWEN_DIALOG *dlg, const char *name) {
+int GWEN_Dialog_GetWidgetColumns(const GWEN_DIALOG *dlg, const char *name)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -755,7 +840,8 @@ int GWEN_Dialog_GetWidgetColumns(const GWEN_DIALOG *dlg, const char *name) {
 
 
 
-void GWEN_Dialog_SetWidgetColumns(GWEN_DIALOG *dlg, const char *name, int i) {
+void GWEN_Dialog_SetWidgetColumns(GWEN_DIALOG *dlg, const char *name, int i)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -766,7 +852,8 @@ void GWEN_Dialog_SetWidgetColumns(GWEN_DIALOG *dlg, const char *name, int i) {
 
 
 
-int GWEN_Dialog_GetWidgetRows(const GWEN_DIALOG *dlg, const char *name) {
+int GWEN_Dialog_GetWidgetRows(const GWEN_DIALOG *dlg, const char *name)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -779,7 +866,8 @@ int GWEN_Dialog_GetWidgetRows(const GWEN_DIALOG *dlg, const char *name) {
 
 
 
-void GWEN_Dialog_SetWidgetRows(GWEN_DIALOG *dlg, const char *name, int i) {
+void GWEN_Dialog_SetWidgetRows(GWEN_DIALOG *dlg, const char *name, int i)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -790,7 +878,8 @@ void GWEN_Dialog_SetWidgetRows(GWEN_DIALOG *dlg, const char *name, int i) {
 
 
 
-void GWEN_Dialog_SetWidgetText(GWEN_DIALOG *dlg, const char *name, const char *t) {
+void GWEN_Dialog_SetWidgetText(GWEN_DIALOG *dlg, const char *name, const char *t)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -801,7 +890,8 @@ void GWEN_Dialog_SetWidgetText(GWEN_DIALOG *dlg, const char *name, const char *t
 
 
 
-const char *GWEN_Dialog_GetWidgetText(const GWEN_DIALOG *dlg, const char *name) {
+const char *GWEN_Dialog_GetWidgetText(const GWEN_DIALOG *dlg, const char *name)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Dialog_FindWidgetByName(dlg, name);
@@ -814,7 +904,8 @@ const char *GWEN_Dialog_GetWidgetText(const GWEN_DIALOG *dlg, const char *name)
 
 
 
-static void GWEN_Dialog_DumpWidget(const GWEN_WIDGET *w, FILE *f, unsigned int indent) {
+static void GWEN_Dialog_DumpWidget(const GWEN_WIDGET *w, FILE *f, unsigned int indent)
+{
   int i;
   const char *s;
   const char *dname=NULL;
@@ -830,7 +921,7 @@ static void GWEN_Dialog_DumpWidget(const GWEN_WIDGET *w, FILE *f, unsigned int i
 
   fprintf(f, "Widget %s: %d [%s]\n", s?s:"unnamed", GWEN_Widget_GetType(w), dname?dname:"no dialog");
   c=GWEN_Widget_Tree_GetFirstChild(w);
-  while(c) {
+  while (c) {
     GWEN_Dialog_DumpWidget(c, f, indent+2);
     c=GWEN_Widget_Tree_GetNext(c);
   }
@@ -838,7 +929,8 @@ static void GWEN_Dialog_DumpWidget(const GWEN_WIDGET *w, FILE *f, unsigned int i
 
 
 
-void GWEN_Dialog_Dump(const GWEN_DIALOG *dlg, FILE *f, unsigned int indent) {
+void GWEN_Dialog_Dump(const GWEN_DIALOG *dlg, FILE *f, unsigned int indent)
+{
   GWEN_WIDGET *w;
 
   w=GWEN_Widget_Tree_GetFirst(dlg->widgets);
@@ -850,7 +942,8 @@ void GWEN_Dialog_Dump(const GWEN_DIALOG *dlg, FILE *f, unsigned int indent) {
 
 
 
-GWEN_DB_NODE *GWEN_Dialog_GetPreferences(const GWEN_DIALOG *dlg) {
+GWEN_DB_NODE *GWEN_Dialog_GetPreferences(const GWEN_DIALOG *dlg)
+{
   assert(dlg);
   assert(dlg->refCount);
 
