@@ -33,10 +33,19 @@
 #include <gwenhywfar/ssl_cert_descr.h>
 #include <gwenhywfar/syncio.h>
 #include <gwenhywfar/dialog.h>
+#include <gwenhywfar/passwdstore.h>
 
 #include <inttypes.h>
 
 
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+
+
 /** @defgroup MOD_GUI Graphical User Interface
  *
  * @brief This module contains the definition of GWEN_GUI.
@@ -48,7 +57,7 @@
  * The GWEN_GUI object contains callbacks for message display, user
  * input, progress reports, SSL certificate checking etc.
  *
- * There are implementations of GWEN_GUI based on console, QT3, QT4 and FOX.
+ * There are implementations of GWEN_GUI based on console, QT4, QT5 and FOX.
  *
  * GWEN_GUI uses flags to tell implementations what the caller needs of the GUI
  * implementation.
@@ -104,9 +113,64 @@
  */
 /*@{*/
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+
+
+/** @defgroup MOD_GUI_PASSWORD_METHOD Password Methods
+ *
+ * The pasword entry function is used by homebanking apps/libraries for input of passwords for keyfiles,
+ * for pin input and for tan input.
+ * FinTS in Germany uses several methods to get a tan; some just ask for transaction number (TAN) from a previously
+ * mailed list.  Others ask you to hold a special tan generator device to the monitor to let it read a special
+ * flicker graphic. Some show an image to the user from which he must derive the tan in some way.
+ * Therefore the password entry function needed to be extended to allow for a more generic way to ask the user
+ * for a password. Previously, some specific data was included in the text parameter, from which the GUI implementation
+ * needed to extract that data (i.e. "$OBEGIN" and "$OEND" for optical data).
+ *
+ * Therefore we define methods of pin/tan/password entry here with the matching method parameters.
+ */
+/*@{*/
+
+/** @defgroup MOD_GUI_PASSWORD_METHOD_TEXT Textual Input
+ *
+ * This method doesn't need any parameters except those which are already defined by the function
+ * prototype (i.e. min/max length etc.)
+ *
+ */
+
+/** @defgroup MOD_GUI_PASSWORD_METHOD_OPTICALHHD Optical Input (i.e. flicker code)
+ *
+ * This method uses a so-called "challenge" which is chiefly a row of digits which are encoded in a
+ * flicker graphic which is then read by a specific card reader device which is held to the monitor to read
+ * that code.
+ * The possible contents of the methodParams are:
+ * <ul>
+ *   <li>char challenge: Hex code in ASCII form with a row of bytes to be converted to a flicker code (e.g. "123456789ABC" </li>
+ *   <li>char methodName: Name of the method (optional)</li>
+ *   <li>char methodDescription: Description of the method (optional)</li>
+ * </ul>
+ *
+ */
+
+
+/**
+ * Password/pin/tan entry method.
+ * The method id uses the higher 16 bits of a 32 bit word to define the method.
+ * The lower 16 bits are used to define the version of the method. E.g. the method for
+ * input using optical data (i.e. flicker code) knows multiple versions, currently 1.3 and 1.4.
+ * So the complete method id for optical input method HHD version 1.4 would be 0x20104.
+ * Use @ref GWEN_Gui_PasswordMethod_Mask to get the basic method id.
+ */
+typedef enum {
+  GWEN_Gui_PasswordMethod_Unknown   =0,
+  GWEN_Gui_PasswordMethod_Mask      =0xffff0000,
+  GWEN_Gui_PasswordMethod_Text      =0x10000,
+  GWEN_Gui_PasswordMethod_OpticalHHD=0x20000,
+} GWEN_GUI_PASSWORD_METHOD;
+
+
+/*@}*/
+
+
 
 
 typedef struct GWEN_GUI GWEN_GUI;
@@ -158,6 +222,8 @@ GWEN_INHERIT_FUNCTION_LIB_DEFS(GWEN_GUI, GWENHYWFAR_API)
 #define GWEN_GUI_INPUT_FLAGS_TAN            0x00000020
 /** The input contains optical data encapsuled in "$OBEGIN$" and "$OEND$" (this is used by @ref GWEN_Gui_GetPassword) */
 #define GWEN_GUI_INPUT_FLAGS_OPTICAL        0x00000040
+/** The input MUST come via user input, not from some sort of password cache */
+#define GWEN_GUI_INPUT_FLAGS_DIRECT         0x00000080
 
 /*@}*/
 
@@ -332,19 +398,19 @@ typedef enum {
  *
  */
 /*@{*/
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_GUI *GWEN_Gui_new(void);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_Gui_free(GWEN_GUI *gui);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_Gui_Attach(GWEN_GUI *gui);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_Gui_SetGui(GWEN_GUI *gui);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_GUI *GWEN_Gui_GetGui(void);
 
 /*@}*/
@@ -359,11 +425,17 @@ GWEN_GUI *GWEN_Gui_GetGui(void);
  * character sets.
  */
 /*@{*/
-GWENHYWFAR_API 
+GWENHYWFAR_API
 const char *GWEN_Gui_GetCharSet(const GWEN_GUI *gui);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_Gui_SetCharSet(GWEN_GUI *gui, const char *s);
+
+GWENHYWFAR_API
+int GWEN_Gui_ConvertString(const char *text, size_t len, GWEN_BUFFER *tbuf,
+                           const char *fromCs, const char *toCs);
+
+
 /*@}*/
 
 
@@ -406,6 +478,7 @@ void GWEN_Gui_SetCharSet(GWEN_GUI *gui, const char *s);
  * </p>
  */
 /*@{*/
+
 /**
  * <p>
  * Show a message box with optional buttons.
@@ -438,21 +511,21 @@ void GWEN_Gui_SetCharSet(GWEN_GUI *gui, const char *s);
  * @param b3 text for the optional third button
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_MessageBox(uint32_t flags,
-			const char *title,
-			const char *text,
-			const char *b1,
-			const char *b2,
-			const char *b3,
-			uint32_t guiid);
+                        const char *title,
+                        const char *text,
+                        const char *b1,
+                        const char *b2,
+                        const char *b3,
+                        uint32_t guiid);
 
 /**
  * This is a convenience function which calls @ref GWEN_Gui_MessageBox showing the given
  * message and a single "Close" button.
  * It is especially well suited to show an error message.
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_Gui_ShowError(const char *title, const char *text, ...);
 
 
@@ -475,20 +548,22 @@ void GWEN_Gui_ShowError(const char *title, const char *text, ...);
  * a 5 as maxLen.
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  *
- * @return Zero on success, nonzero when the user requested abort or there was
+ * @return Zero on success, less than zero when the user requested abort or there was
  * any error. The special value AB_ERROR_DEFAULT_VALUE should be returned if
  * the flag GWEN_GUI_INPUT_FLAGS_ALLOW_DEFAULT was given and the user has
  * chosen to use the default value (e.g. pressed the "default" button in a
  * GUI).
+ * A return value of "1" means the result may be stored by the application. This value is
+ * returned when the user ticks the checkbox "Store permanently".
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_InputBox(uint32_t flags,
-		      const char *title,
-		      const char *text,
-		      char *buffer,
-		      int minLen,
-		      int maxLen,
-		      uint32_t guiid);
+                      const char *title,
+                      const char *text,
+                      char *buffer,
+                      int minLen,
+                      int maxLen,
+                      uint32_t guiid);
 
 /**
  * <p>
@@ -507,28 +582,26 @@ int GWEN_Gui_InputBox(uint32_t flags,
  * This function MUST return immediately (non-blocking).
  * </p>
  * @return returns an id to be presented to @ref GWEN_Gui_HideBox.
- * @param ab banking interface
  * @param flags flags, see @ref GWEN_GUI_SHOWBOX_FLAGS_BEEP ff
  * @param title title of the box
  * @param text Text of the box: UTF-8, with both a normal text and a HTML variant of the text in the same string. See text restrictions note above.
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 uint32_t GWEN_Gui_ShowBox(uint32_t flags,
-			  const char *title,
-			  const char *text,
-			  uint32_t guiid);
+                          const char *title,
+                          const char *text,
+                          uint32_t guiid);
 
 /**
  * Hides a message box previously shown by a call to @ref GWEN_Gui_ShowBox.
  * <p>
  * This function MUST return immediately (non-blocking).
  * </p>
- * @param ab banking interface
  * @param id id returned by @ref GWEN_Gui_ShowBox. If @b 0 then the last
  * message shown is referred to.
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_Gui_HideBox(uint32_t id);
 
 
@@ -563,12 +636,12 @@ void GWEN_Gui_HideBox(uint32_t id);
  *  which represents 100%)
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 uint32_t GWEN_Gui_ProgressStart(uint32_t progressFlags,
-				const char *title,
-				const char *text,
-				uint64_t total,
-				uint32_t guiid);
+                                const char *title,
+                                const char *text,
+                                uint64_t total,
+                                uint32_t guiid);
 
 /**
  * <p>
@@ -590,10 +663,10 @@ uint32_t GWEN_Gui_ProgressStart(uint32_t progressFlags,
  *  GWEN_GUI_PROGRESS_NONE which means that the progress is unchanged.
  * This might be used as a keepalive call to a GUI.
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_ProgressAdvance(uint32_t id, uint32_t progress);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_ProgressSetTotal(uint32_t id, uint64_t total);
 
 /**
@@ -606,10 +679,10 @@ int GWEN_Gui_ProgressSetTotal(uint32_t id, uint64_t total);
  * @param level log level (see @ref GWEN_Gui_LogLevelPanic ff.)
  * @param text Text of the box: UTF-8, with both a normal text and a HTML variant of the text in the same string. See text restrictions note above.
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_ProgressLog(uint32_t id,
-			 GWEN_LOGGER_LEVEL level,
-			 const char *text);
+                         GWEN_LOGGER_LEVEL level,
+                         const char *text);
 
 /**
  * Adds a log message to the referred process dialog and returns immediately.
@@ -623,10 +696,10 @@ int GWEN_Gui_ProgressLog(uint32_t id,
  * @param text Text of the box (possibly including printf format string characters): UTF-8, with both a normal text
  * and a HTML variant of the text in the same string. See text restrictions note above.
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_ProgressLog2(uint32_t id,
-			  GWEN_LOGGER_LEVEL level,
-			  const char *text, ...);
+                          GWEN_LOGGER_LEVEL level,
+                          const char *text, ...);
 
 /**
  * <p>
@@ -652,7 +725,7 @@ int GWEN_Gui_ProgressLog2(uint32_t id,
  * @param id id assigned by @ref GWEN_Gui_ProgressStart (if 0 then the
  * last started progress dialog is referred to)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_ProgressEnd(uint32_t id);
 
 
@@ -669,12 +742,12 @@ int GWEN_Gui_ProgressEnd(uint32_t id);
  * @param text text to be printed (see text restriction notes above).
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_Print(const char *docTitle,
-		   const char *docType,
-		   const char *descr,
-		   const char *text,
-		   uint32_t guiid);
+                   const char *docType,
+                   const char *descr,
+                   const char *text,
+                   uint32_t guiid);
 
 /**
  * This function retrieves a password or pin. The implementation might want to use a cache or
@@ -682,6 +755,13 @@ int GWEN_Gui_Print(const char *docTitle,
  * The function @ref GWEN_Gui_SetPasswordStatus() is used to communicate the status of a password.
  * So if this function here uses a password cache then the callback for @ref GWEN_Gui_SetPasswordStatus()
  * should also be implemented.
+ *
+ * NOTE:
+ * AqBanking uses GWEN_Gui_PasswordMethod_OpticalHHD as methodId for all optical TAN input methods like
+ * "chipTAN optisch" and others. To determine which optical method is actually requested see the DB variable
+ * "tanMethodId" inside the methodParams parameter.
+ * The data to send to the TAN generator can be found in the toplevel variable "challenge".
+ *
  * @param flags flags, see @ref GWEN_GUI_INPUT_FLAGS_CONFIRM ff.
  * @param token unique identification for the password or pin. This can be used to read the password from a cache or file.
  * @param title title of the input box
@@ -693,27 +773,32 @@ int GWEN_Gui_Print(const char *docTitle,
  * This means that if you want to ask the user for a PIN of at most 4
  * characters you need to supply a buffer of at least @b 5 bytes and provide
  * a 5 as maxLen.
+ * @param methodId Id of the pin/password/tan entry.
+ * @param methodParams additional parameters for the pin/password/tan entry, content depends on
+ * the methodId (my be NULL for simple text input)
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  */
 GWENHYWFAR_API
 int GWEN_Gui_GetPassword(uint32_t flags,
-			 const char *token,
-			 const char *title,
-			 const char *text,
-			 char *buffer,
-			 int minLen,
-			 int maxLen,
-			 uint32_t guiid);
+                         const char *token,
+                         const char *title,
+                         const char *text,
+                         char *buffer,
+                         int minLen,
+                         int maxLen,
+                         GWEN_GUI_PASSWORD_METHOD methodId,
+                         GWEN_DB_NODE *methodParams,
+                         uint32_t guiid);
 
 /**
  * This functions sets the status of a password.
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_SetPasswordStatus(const char *token,
-			       const char *pin,
-			       GWEN_GUI_PASSWORD_STATUS status,
-			       uint32_t guiid);
+                               const char *pin,
+                               GWEN_GUI_PASSWORD_STATUS status,
+                               uint32_t guiid);
 
 /**
  * This function is called internally by @ref GWEN_Logger_Log.
@@ -725,9 +810,10 @@ int GWEN_Gui_SetPasswordStatus(const char *token,
  * @param priority priority of the message
  * @param s string to log
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_LogHook(const char *logDomain,
-		     GWEN_LOGGER_LEVEL priority, const char *s);
+                     GWEN_LOGGER_LEVEL priority,
+                     const char *s);
 
 
 /**
@@ -738,11 +824,27 @@ int GWEN_Gui_LogHook(const char *logDomain,
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  * @param msecs time in milliseconds to wait for at max
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_WaitForSockets(GWEN_SOCKET_LIST2 *readSockets,
-			    GWEN_SOCKET_LIST2 *writeSockets,
+                            GWEN_SOCKET_LIST2 *writeSockets,
                             uint32_t guiid,
-			    int msecs);
+                            int msecs);
+
+/**
+ * This function creates a base layer GWEN_SYNCIO.
+ * The idea is to allow applications to implement their own PROXY handling.
+ * @param url url to which the caller wants to connect to. You should call @ref GWEN_Url_fromString()
+ *   to get the information required to determine the protocol and destination.
+ * @param defaultProto default protocol name if not specified by the url (e.g. "http", "https", "hbci")
+ * @param defaultPort default port if not specified by the url
+ * @param pSio pointer to a variable to receive the created GWEN_SYNCIO.
+ */
+GWENHYWFAR_API
+int GWEN_Gui_GetSyncIo(const char *url,
+                       const char *defaultProto,
+                       int defaultPort,
+                       GWEN_SYNCIO **pSio);
+
 
 /**
  * This function checks the given certificate.
@@ -752,10 +854,10 @@ int GWEN_Gui_WaitForSockets(GWEN_SOCKET_LIST2 *readSockets,
  * @param io IO layer from which the certificate was received
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart or @ref GWEN_Gui_ShowBox)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_Gui_CheckCert(const GWEN_SSLCERTDESCR *cert,
-		       GWEN_SYNCIO *sio,
-		       uint32_t guiid);
+                       GWEN_SYNCIO *sio,
+                       uint32_t guiid);
 
 
 /**
@@ -770,27 +872,70 @@ int GWEN_Gui_CheckCert(const GWEN_SSLCERTDESCR *cert,
  */
 GWENHYWFAR_API
 int GWEN_Gui_KeyDataFromText_OpenSSL(const char *text,
-				     unsigned char *buffer,
-				     unsigned int bufLength);
+                                     unsigned char *buffer,
+                                     unsigned int bufLength);
+
+
+/*@}*/
+
+
+/** @name Dialogs
+ *
+ * Providing dialog functionality is optional for the implementation.
+ * The internal implementations of the password and message box functions
+ * internally use dialog functions, so if your implementation of GWEN_GUI
+ * also implements the dialogs API then you're already set for most of the
+ * interactive callbacks.
+ */
+/*@{*/
 
 /**
  * This function shows and executes the given dialog and returns the result.
  * See @ref MOD_GUI_DIALOG for a description of the dialog framework.
+ *
+ * @return <0: error code, 0: aborted, 1: accepted (e.g. "Ok" pressed)
+ * @param dlg pointer to the dialog object
  * @param guiid id as returned by @ref GWEN_Gui_ProgressStart, @ref GWEN_Gui_ShowBox or as can be found
  * via @ref GWEN_Dialog_GetGuiId())
- * @return <0: error code, 0: aborted, 1: accepted (e.g. "Ok" pressed)
  */
 GWENHYWFAR_API
 int GWEN_Gui_ExecDialog(GWEN_DIALOG *dlg, uint32_t guiid);
 
 
-
+/**
+ * Open a dialog.
+ * This function should create all the necessary dialog resources (=windows) and return.
+ *
+ * @return <0: error code
+ * @param dlg pointer to the dialog object
+ * @param guiid id as returned by @ref GWEN_Gui_ProgressStart, @ref GWEN_Gui_ShowBox or as can be found
+ * via @ref GWEN_Dialog_GetGuiId())
+ */
 GWENHYWFAR_API
 int GWEN_Gui_OpenDialog(GWEN_DIALOG *dlg, uint32_t guiid);
 
+
+/**
+ * Close a dialog.
+ * This function should hide the given dialog and release all its resources.
+ *
+ * @return <0: error code
+ * @param dlg pointer to the dialog object
+ * @param guiid id as returned by @ref GWEN_Gui_ProgressStart, @ref GWEN_Gui_ShowBox or as can be found
+ * via @ref GWEN_Dialog_GetGuiId())
+ */
 GWENHYWFAR_API
 int GWEN_Gui_CloseDialog(GWEN_DIALOG *dlg);
 
+
+/**
+ * Run a dialog.
+ * This function should run the given dialog and return when the user is done with it.
+ *
+ * @return <0: error code, 0: aborted, 1: accepted (e.g. "Ok" pressed)
+ * @param dlg pointer to the dialog object
+ * @param untilEnd if not zero, the dialog should run until completely finished (e.g. "OK" pressed)
+ */
 GWENHYWFAR_API
 int GWEN_Gui_RunDialog(GWEN_DIALOG *dlg, int untilEnd);
 
@@ -802,19 +947,14 @@ typedef enum {
 
 } GWEN_GUI_FILENAME_TYPE;
 
-
 /**
  * This function is used to get the path and name of a single file or folder.
  *
  * @param caption title for the dialog
- *
  * @param fnt type of the operation (see @ref GWEN_Gui_FileNameType_OpenFileName and following)
- *
  * @param flags currently reserved, use 0
- *
  * @param patterns multiple tab-separated entries like in:
  *   "All Files (*)\tC++ Sources (*.cpp,*.cc)\tC++ Headers (*.hpp,*.hh,*.h)"
- *
  * @param pathBuffer upon call this may contain a preselected path/filename, upon return
  *   this will contain the selected name
  *
@@ -822,32 +962,19 @@ typedef enum {
  */
 GWENHYWFAR_API
 int GWEN_Gui_GetFileName(const char *caption,
-			 GWEN_GUI_FILENAME_TYPE fnt,
+                         GWEN_GUI_FILENAME_TYPE fnt,
                          uint32_t flags,
-			 const char *patterns,
-			 GWEN_BUFFER *pathBuffer,
-			 uint32_t guiid);
-
-/**
- * This function creates a base layer GWEN_SYNCIO.
- * The idea is to allow applications to implement their own PROXY handling.
- * @param url url to which the caller wants to connect to. You should call @ref GWEN_Url_fromString()
- *   to get the information required to determine the protocol and destination.
- * @param defaultProto default protocol name if not specified by the url (e.g. "http", "https", "hbci")
- * @param defaultPort default port if not specified by the url
- * @param pSio pointer to a variable to receive the created GWEN_SYNCIO.
- */
-GWENHYWFAR_API
-int GWEN_Gui_GetSyncIo(const char *url,
-		       const char *defaultProto,
-		       int defaultPort,
-		       GWEN_SYNCIO **pSio);
-
+                         const char *patterns,
+                         GWEN_BUFFER *pathBuffer,
+                         uint32_t guiid);
 
 /*@}*/
 
 
 
+
+
+
 /** @name Flags
  *
  * Functions in this group influence the behaviour of GWEN_GUI implementations.
@@ -861,6 +988,9 @@ int GWEN_Gui_GetSyncIo(const char *url,
 #define GWEN_GUI_FLAGS_ACCEPTVALIDCERTS   0x00000002
 /** GUI automatically rejects invalid certs */
 #define GWEN_GUI_FLAGS_REJECTINVALIDCERTS 0x00000004
+/** GUI uses permanent password storage */
+#define GWEN_GUI_FLAGS_PERMPASSWORDS      0x00000008
+
 /** GUI implementation supports dialogs (see @ref MOD_GUI_DIALOG) */
 #define GWEN_GUI_FLAGS_DIALOGSUPPORTED    0x80000000
 
@@ -874,6 +1004,83 @@ GWENHYWFAR_API void GWEN_Gui_SubFlags(GWEN_GUI *gui, uint32_t fl);
 GWENHYWFAR_API const char *GWEN_Gui_GetName(void);
 
 
+
+/** @name Password Cache
+ *
+ * This implementation provides a password cache. This will be
+ * consulted upon @ref GWEN_Gui_GetPassword. The implementation of
+ * @ref GWEN_Gui_SetPasswordStatus also accesses this password cache.
+ *
+ * Normally this cache is filled from password files (like those
+ * specified via option <i>-P</i> of <i>aqbanking-cli</i>).
+ */
+/**@{*/
+/**
+ * Set the password DB. Takes over the given DB.
+ * @param gui GUI object
+ * @param dbPasswords password cache
+ * @param persistent if !=0 then the passwords come from a password file
+ * and a request to clear the password cache will be ignored.
+ */
+GWENHYWFAR_API
+void GWEN_Gui_SetPasswordDb(GWEN_GUI *gui,
+                            GWEN_DB_NODE *dbPasswords,
+                            int persistent);
+
+/**
+ * Returns a pointer to the internally used password cache. The GUI
+ * object remains the owner of the object returned (if any).
+ */
+GWENHYWFAR_API
+GWEN_DB_NODE *GWEN_Gui_GetPasswordDb(const GWEN_GUI *gui);
+/*@}*/
+
+
+
+/** @name Password Store
+ * This is the second level password storage. It can be used to safely store passwords
+ * in an encrypted file. This is used when a pin/password is requested which is not already
+ * in the password db (see Password Cache). This store is consulted if a given password is
+ * not found in the current pasword db (see @ref GWEN_Gui_SetPasswordDb).
+ */
+/**@{*/
+
+GWENHYWFAR_API GWEN_PASSWD_STORE *GWEN_Gui_GetPasswdStore(const GWEN_GUI *gui);
+GWENHYWFAR_API void GWEN_Gui_SetPasswdStore(GWEN_GUI *gui, GWEN_PASSWD_STORE *sto);
+/*@}*/
+
+
+
+/** Returns the minimum log level needed to show progress logs */
+GWENHYWFAR_API GWEN_LOGGER_LEVEL GWEN_Gui_GetMinProgressLogLevel(const GWEN_GUI *gui);
+GWENHYWFAR_API void GWEN_Gui_SetMinProgressLogLevel(GWEN_GUI *gui, GWEN_LOGGER_LEVEL ll);
+
+
+
+/**
+ * Stack sync io layers above the given base layer.
+ *
+ * This is a convenience function to extend a base layer (e.g. created by @ref GWEN_SyncIo_Socket_new)
+ * to support HTTP or HTTPS over the given base layer.
+ *
+ * You can use this function to allow for e.g. HTTPS over a socket created by
+ * functions @ref GWEN_Socket_Accept and @ref GWEN_SyncIo_Socket_TakeOver.
+ *
+ * The caller is responsible for freeing the object returned (if any).
+ *
+ * @return syncio object supporting the given protocol (e.g. HTTP, HTTPS), NULL on error
+ * @param url url to which the caller wants to connect to. You should call @ref GWEN_Url_fromString()
+ *   to get the information required to determine the protocol and destination.
+ * @param defaultProto default protocol name if not specified by the url (e.g. "http", "https")
+ * @param defaultPort default port if not specified by the url
+ * @param baseSio base layer to extend (e.g. created by @ref GWEN_SyncIo_Socket_new)
+ */
+GWEN_SYNCIO *GWEN_Gui_ExtendSyncIo(const char *url,
+                                   const char *defaultProto,
+                                   int defaultPort,
+                                   GWEN_SYNCIO *baseSio);
+
+
 #ifdef __cplusplus
 }
 #endif
