@@ -36,10 +36,12 @@
 #include <string.h>
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/misc.h>
+#include <direct.h> /* for _mkdir */
 
 
 
-GWEN_DIRECTORY *GWEN_Directory_new(){
+GWEN_DIRECTORY *GWEN_Directory_new(void)
+{
   GWEN_DIRECTORY *d;
 
   GWEN_NEW_OBJECT(GWEN_DIRECTORY, d);
@@ -48,7 +50,8 @@ GWEN_DIRECTORY *GWEN_Directory_new(){
 
 
 
-void GWEN_Directory_free(GWEN_DIRECTORY *d){
+void GWEN_Directory_free(GWEN_DIRECTORY *d)
+{
   if (d) {
     if (d->handle!=INVALID_HANDLE_VALUE)
       FindClose(d->handle);
@@ -59,7 +62,8 @@ void GWEN_Directory_free(GWEN_DIRECTORY *d){
 
 
 
-int GWEN_Directory_Open(GWEN_DIRECTORY *d, const char *n){
+int GWEN_Directory_Open(GWEN_DIRECTORY *d, const char *n)
+{
   assert(d);
   assert(n);
   if ((strlen(n)+5)>=sizeof(d->pattern)) {
@@ -74,7 +78,8 @@ int GWEN_Directory_Open(GWEN_DIRECTORY *d, const char *n){
 
 
 
-int GWEN_Directory_Close(GWEN_DIRECTORY *d){
+int GWEN_Directory_Close(GWEN_DIRECTORY *d)
+{
   int rv;
 
   rv=0;
@@ -87,8 +92,9 @@ int GWEN_Directory_Close(GWEN_DIRECTORY *d){
 
 
 int GWEN_Directory_Read(GWEN_DIRECTORY *d,
-			char *buffer,
-			unsigned int len){
+                        char *buffer,
+                        unsigned int len)
+{
   WIN32_FIND_DATA wd;
 
   assert(d);
@@ -110,23 +116,24 @@ int GWEN_Directory_Read(GWEN_DIRECTORY *d,
 
   /* read next entry */
   d->lastName[0]=0;
-  if (FindNextFile(d->handle,&wd)) {
+  if (FindNextFile(d->handle, &wd)) {
     if ((strlen(wd.cFileName)+1)>=sizeof(d->lastName)) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Entry too long");
     }
 
-    strcpy(d->lastName,wd.cFileName);
+    strcpy(d->lastName, wd.cFileName);
   }
   return 0;
 }
 
 
 
-int GWEN_Directory_Rewind(GWEN_DIRECTORY *d){
+int GWEN_Directory_Rewind(GWEN_DIRECTORY *d)
+{
   WIN32_FIND_DATA wd;
 
   assert(d);
-  d->handle=FindFirstFile(d->pattern,&wd);
+  d->handle=FindFirstFile(d->pattern, &wd);
   if (d->handle==INVALID_HANDLE_VALUE) {
     DBG_DEBUG(GWEN_LOGDOMAIN, "No entry for \"%s\"", d->pattern);
     return GWEN_ERROR_NOT_FOUND;
@@ -135,13 +142,14 @@ int GWEN_Directory_Rewind(GWEN_DIRECTORY *d){
     DBG_ERROR(GWEN_LOGDOMAIN, "Entry name too long");
     return GWEN_ERROR_BUFFER_OVERFLOW;
   }
-  strcpy(d->lastName,wd.cFileName);
+  strcpy(d->lastName, wd.cFileName);
   return 0;
 }
 
 
 
-int GWEN_Directory_Create(const char *path){
+int GWEN_Directory_Create(const char *path)
+{
 
   if (_mkdir(path)) {
     DBG_INFO(GWEN_LOGDOMAIN, "Error on _mkdir(%s): %s",
@@ -153,7 +161,8 @@ int GWEN_Directory_Create(const char *path){
 
 
 
-int GWEN_Directory_CreatePublic(const char *path){
+int GWEN_Directory_CreatePublic(const char *path)
+{
   /* same as above, since on WIN32 all folders are public (gulp) */
   return GWEN_Directory_Create(path);
 }
@@ -162,13 +171,14 @@ int GWEN_Directory_CreatePublic(const char *path){
 /** Returns TRUE (nonzero) if the given path is an absolute one. */
 static int path_is_absolute(const char *path)
 {
-  return path && 
-    ( (path[0] == '\\') ||
-      (path[0] == '/') ||
-      ( (strlen(path) > 2) && (path[1] == ':') ) );
+  return path &&
+         ((path[0] == '\\') ||
+          (path[0] == '/') ||
+          ((strlen(path) > 2) && (path[1] == ':')));
 }
 
-int GWEN_Directory_GetHomeDirectory(char *buffer, unsigned int size){
+int GWEN_Directory_GetHomeDirectory(char *buffer, unsigned int size)
+{
   int rv;
   char *home_dir;
 
@@ -180,48 +190,43 @@ int GWEN_Directory_GetHomeDirectory(char *buffer, unsigned int size){
   /* We check $HOME first for Win32, though it is a last resort for Unix
    * where we prefer the results of getpwuid().
    */
-  home_dir = getenv ("HOME");
+  home_dir = getenv("HOME");
 
   /* Only believe HOME if it is an absolute path and exists */
-  if (home_dir)
-    {
-      if (!(path_is_absolute (home_dir)
-	    /* && g_file_test (home_dir, G_FILE_TEST_IS_DIR) */ 
-	    ))
-	{
-	  home_dir = NULL;
-	}
-    }
-  
-  if (!home_dir)
-    {
-      /* USERPROFILE is probably the closest equivalent to $HOME? */
-      if (getenv ("USERPROFILE") != NULL)
-	home_dir = getenv ("USERPROFILE");
+  if (home_dir) {
+    if (!(path_is_absolute(home_dir)
+          /* && g_file_test (home_dir, G_FILE_TEST_IS_DIR) */
+         )) {
+      home_dir = NULL;
     }
+  }
+
+  if (!home_dir) {
+    /* USERPROFILE is probably the closest equivalent to $HOME? */
+    if (getenv("USERPROFILE") != NULL)
+      home_dir = getenv("USERPROFILE");
+  }
 
   /* Did we find any home_dir? Copy it to buffer. */
-  if (home_dir)
-    {
-      char *p;
+  if (home_dir) {
+    char *p;
 
-      rv = strlen (home_dir);
-      strncpy (buffer, home_dir, size);
-      
-      /* In case HOME is Unix-style (it happens), convert it to
-       * Windows style.
-       */
-      while ((p = strchr (buffer, '/')) != NULL)
-	*p = '\\';
-    }
-  else
-    {
-      rv=GetWindowsDirectory(buffer, size);
-      if (rv==0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "Error on GetWindowsDirectory");
-	return -1;
-      }
+    rv = strlen(home_dir);
+    strncpy(buffer, home_dir, size);
+
+    /* In case HOME is Unix-style (it happens), convert it to
+     * Windows style.
+     */
+    while ((p = strchr(buffer, '/')) != NULL)
+      *p = '\\';
+  }
+  else {
+    rv=GetWindowsDirectory(buffer, size);
+    if (rv==0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "Error on GetWindowsDirectory");
+      return -1;
     }
+  }
 
   if (rv>=size) {
     DBG_INFO(GWEN_LOGDOMAIN, "Buffer too small");
@@ -232,7 +237,8 @@ int GWEN_Directory_GetHomeDirectory(char *buffer, unsigned int size){
 
 
 
-int GWEN_Directory_GetPrefixDirectory(char *buffer, unsigned int size){
+int GWEN_Directory_GetPrefixDirectory(char *buffer, unsigned int size)
+{
   DWORD rv;
   char *p;
   char cwd[256];
@@ -241,8 +247,8 @@ int GWEN_Directory_GetPrefixDirectory(char *buffer, unsigned int size){
   rv=GetModuleFileName(NULL, cwd, sizeof(cwd)-1);
   if (rv==0) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "GetModuleFileName(): %d",
-	      (int)GetLastError());
+              "GetModuleFileName(): %d",
+              (int)GetLastError());
     return GWEN_ERROR_IO;
   }
 
@@ -262,7 +268,7 @@ int GWEN_Directory_GetPrefixDirectory(char *buffer, unsigned int size){
        here. */
     if ((strcmp(p+1, "bin") == 0) || (strcmp(p+1, "lib") == 0)) {
       /* The path ends in "bin" or "lib", hence we strip that suffix
-	 so that we now only have the prefix. */
+      so that we now only have the prefix. */
       *p=0;
     }
   }
