@@ -82,14 +82,14 @@ extern "C" {
  *
  * <ol>
  * <li> Iterate through groups or get a variable with
- *  e.g. GWEN_DB_GetNextGroup(), GWEN_DB_GetNextVar() 
- * <li> Get the type of a variable with e.g. GWEN_DB_GetVariableType() 
- *  -- the value of a variable is retrieved by the shortcut functions 
+ *  e.g. GWEN_DB_GetNextGroup(), GWEN_DB_GetNextVar()
+ * <li> Get the type of a variable with e.g. GWEN_DB_GetVariableType()
+ *  -- the value of a variable is retrieved by the shortcut functions
  *  explained below.
  * <li> Get the type of a value with GWEN_DB_GetValueType(). Again the
  * value itself is retrieved with the shortcut functions below.
  * </ol>
- * 
+ *
  * To retrieve or set the value of such a variable, the following
  * "shortcut" functions for all three supported typed exist:
  * GWEN_DB_GetIntValue(), GWEN_DB_GetCharValue(),
@@ -159,12 +159,12 @@ extern "C" {
  * values/groups rather than appending them.*/
 #define GWEN_DB_FLAGS_INSERT                 0x40000000
 
-  /**
-   * When writing a DB use DOS line termination (e.g. CR/LF) instead if unix mode (LF only)
-   */
+/**
+ * When writing a DB use DOS line termination (e.g. CR/LF) instead if unix mode (LF only)
+ */
 #define GWEN_DB_FLAGS_DOSMODE                0x80000000
 
-  /** These are the default flags which you use in most cases */
+/** These are the default flags which you use in most cases */
 #define GWEN_DB_FLAGS_DEFAULT \
   (\
   GWEN_DB_FLAGS_QUOTE_VALUES | \
@@ -210,6 +210,8 @@ extern "C" {
 /** this is only valid for groups. It determines whether subgroups will
  *  inherit the hash mechanism set in the root node. */
 #define GWEN_DB_NODE_FLAGS_INHERIT_HASH_MECHANISM  0x00000004
+/** node has to be disposed of safely (i.e. it will be overridden before freeing it) */
+#define GWEN_DB_NODE_FLAGS_SAFE                    0x00000008
 /*@}*/
 
 
@@ -218,7 +220,7 @@ extern "C" {
 
 /**
  * This is the type used to store a DB. Its contents are explicitly NOT
- * part of the API. 
+ * part of the API.
  *
  * A description of what can be done with this type can be found in
  * @ref db.h
@@ -260,7 +262,7 @@ typedef enum {
  * using @ref GWEN_DB_Group_free() in order to avoid memory leaks.
  * @param name name of the group to create
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_Group_new(const char *name);
 
 /**
@@ -268,7 +270,7 @@ GWEN_DB_NODE *GWEN_DB_Group_new(const char *name);
  * avoid memory leaks.
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_DB_Group_free(GWEN_DB_NODE *n);
 
 
@@ -278,14 +280,14 @@ void GWEN_DB_Group_free(GWEN_DB_NODE *n);
  * GWEN_DB_Group_free().
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_Group_dup(const GWEN_DB_NODE *n);
 
 /*@}*/
 
 
 
-/** @name Iterating Through Groups 
+/** @name Iterating Through Groups
  *
  */
 /*@{*/
@@ -298,7 +300,7 @@ GWEN_DB_NODE *GWEN_DB_Group_dup(const GWEN_DB_NODE *n);
  *
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetFirstGroup(GWEN_DB_NODE *n);
 
 /**
@@ -323,7 +325,7 @@ GWEN_DB_NODE *GWEN_DB_GetFirstGroup(GWEN_DB_NODE *n);
  *
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetNextGroup(GWEN_DB_NODE *n);
 
 
@@ -338,7 +340,7 @@ GWEN_DB_NODE *GWEN_DB_GetNextGroup(GWEN_DB_NODE *n);
  * @param n db node
  * @param name name to look for (joker and wildcards allowed)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_FindFirstGroup(GWEN_DB_NODE *n, const char *name);
 
 /**
@@ -359,14 +361,14 @@ GWEN_DB_NODE *GWEN_DB_FindFirstGroup(GWEN_DB_NODE *n, const char *name);
  * @param n db node
  * @param name name to look for (joker and wildcards allowed)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_FindNextGroup(GWEN_DB_NODE *n, const char *name);
 
 
 /** Callback function type for GWEN_DB_Groups_Foreach(),
  * GWEN_DB_Variables_Foreach(), and GWEN_DB_Values_Foreach().
  *
- * @param node The current node element 
+ * @param node The current node element
  *
  * @param user_data The arbitrary data passed to the foreach function.
  *
@@ -391,20 +393,20 @@ typedef void *(*GWEN_DB_NODES_CB)(GWEN_DB_NODE *node, void *user_data);
  * returns one. Otherwise (i.e. 'func' always returns NULL)
  * returns NULL.
  * @author Christian Stimming <stimming@tuhh.de> */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void *GWEN_DB_Groups_Foreach(GWEN_DB_NODE *node, GWEN_DB_NODES_CB func,
-			     void *user_data);
+                             void *user_data);
 
 /** Returns the number of group nodes that are @e direct children of
  * the given node. In other words, this is the number of group nodes
  * that will be reached in the GWEN_DB_Groups_foreach() function. */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 unsigned int GWEN_DB_Groups_Count(const GWEN_DB_NODE *node);
 
 /**
  * Returns the parent group of the given node.
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetParentGroup(GWEN_DB_NODE *n);
 
 /*@}*/
@@ -464,7 +466,7 @@ GWEN_DB_NODE *GWEN_DB_GetParentGroup(GWEN_DB_NODE *n);
  * @param idx index number of the value to return
  * @param defVal default value to return in case there is no real value
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 const char *GWEN_DB_GetCharValue(GWEN_DB_NODE *n,
                                  const char *path,
                                  int idx,
@@ -477,13 +479,28 @@ const char *GWEN_DB_GetCharValue(GWEN_DB_NODE *n,
  * @param path path and name of the variable
  * @param val The string value that is copied into the DB
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_SetCharValue(GWEN_DB_NODE *n,
                          uint32_t flags,
                          const char *path,
                          const char *val);
 
 
+
+/**
+ * @return 0 on success, nonzero on error
+ * @param n db node
+ * @param flags see @ref GWEN_DB_FLAGS_OVERWRITE_VARS and others which
+ * can all be OR-combined to form the flags to use.
+ * @param path path and name of the variable
+ * @param val The integer value to be stored as string value in the DB
+ */
+int GWEN_DB_SetCharValueFromInt(GWEN_DB_NODE *n,
+                                uint32_t flags,
+                                const char *path,
+                                int val);
+
+
 /**
  * Adds the given char value to the given variable if it not already exists
  * (depending on the arguments senseCase and check).
@@ -494,7 +511,7 @@ int GWEN_DB_SetCharValue(GWEN_DB_NODE *n,
  * @param senseCase if 0 then the case of the value is ignored while checking
  * @param check if 1 then the variable will be checked for this value
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_AddCharValue(GWEN_DB_NODE *n,
                          const char *path,
                          const char *val,
@@ -511,7 +528,7 @@ int GWEN_DB_AddCharValue(GWEN_DB_NODE *n,
  * @param val The string value to be removed
  * @param senseCase if 0 then the case of the value is ignored while checking
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_RemoveCharValue(GWEN_DB_NODE *n,
                             const char *path,
                             const char *val,
@@ -525,7 +542,7 @@ int GWEN_DB_RemoveCharValue(GWEN_DB_NODE *n,
  * @param idx index number of the value to return
  * @param defVal default value to return in case there is no real value
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_GetIntValue(GWEN_DB_NODE *n,
                         const char *path,
                         int idx,
@@ -539,7 +556,7 @@ int GWEN_DB_GetIntValue(GWEN_DB_NODE *n,
  * @param path path and name of the variable
  * @param val new value
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_SetIntValue(GWEN_DB_NODE *n,
                         uint32_t flags,
                         const char *path,
@@ -557,7 +574,7 @@ int GWEN_DB_SetIntValue(GWEN_DB_NODE *n,
  * @param returnValueSize pointer to a variable to receive the length
  * of the data returned
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 const void *GWEN_DB_GetBinValue(GWEN_DB_NODE *n,
                                 const char *path,
                                 int idx,
@@ -575,10 +592,10 @@ const void *GWEN_DB_GetBinValue(GWEN_DB_NODE *n,
  *
  * @return 0 on success, nonzero on error
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_SetBinValue(GWEN_DB_NODE *n,
-			uint32_t flags,
-			const char *path,
+                        uint32_t flags,
+                        const char *path,
                         const void *val,
                         unsigned int valSize);
 
@@ -610,6 +627,21 @@ int GWEN_DB_SetPtrValue(GWEN_DB_NODE *n,
                         uint32_t flags,
                         const char *path,
                         void *val);
+
+
+/**
+ * @return 0 if okay, error code on error (GWEN_ERROR_NO_DATA if the variable doesn't exist or has no value)
+ * @param n db node
+ * @param path path and name of the variable
+ * @param index number of value to read (if there are multiple values in the variable, 0 being the first)
+ * @param dstBuf buffer to write the value into
+ *
+ * @return 0 on success, nonzero on error
+ */
+GWENHYWFAR_API
+int GWEN_DB_WriteVarValueToBuffer(GWEN_DB_NODE *n, const char *path, int index, GWEN_BUFFER *dstBuf);
+
+
 /*@}*/
 
 
@@ -628,7 +660,7 @@ int GWEN_DB_SetPtrValue(GWEN_DB_NODE *n,
  * can all be OR-combined to form the flags to use.
  * @param path path and name of the group to be created/located
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetGroup(GWEN_DB_NODE *n,
                                uint32_t flags,
                                const char *path);
@@ -636,7 +668,7 @@ GWEN_DB_NODE *GWEN_DB_GetGroup(GWEN_DB_NODE *n,
 /**
  * Returns the name of the given group.
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 const char *GWEN_DB_GroupName(GWEN_DB_NODE *n);
 
 /**
@@ -644,7 +676,7 @@ const char *GWEN_DB_GroupName(GWEN_DB_NODE *n);
  * @param n db node
  * @param newname new name for the group
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_DB_GroupRename(GWEN_DB_NODE *n, const char *newname);
 
 /**
@@ -661,7 +693,7 @@ void GWEN_DB_GroupRename(GWEN_DB_NODE *n, const char *newname);
  * @param parent Some group node that will be the parent of the added node
  * @param node Group node to add
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_AddGroup(GWEN_DB_NODE *parent, GWEN_DB_NODE *node);
 
 /**
@@ -679,7 +711,7 @@ int GWEN_DB_AddGroup(GWEN_DB_NODE *parent, GWEN_DB_NODE *node);
  * @param parent Some group node that will be the parent of the added node
  * @param node Group node to add
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_InsertGroup(GWEN_DB_NODE *parent, GWEN_DB_NODE *node);
 
 /**
@@ -691,7 +723,7 @@ int GWEN_DB_InsertGroup(GWEN_DB_NODE *parent, GWEN_DB_NODE *node);
  * @param n db node
  * @param nn node whose children are to be added (makes deep copies)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_AddGroupChildren(GWEN_DB_NODE *n, GWEN_DB_NODE *nn);
 
 /**
@@ -703,7 +735,7 @@ int GWEN_DB_AddGroupChildren(GWEN_DB_NODE *n, GWEN_DB_NODE *nn);
  * other position of even in other DBs.
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_DB_UnlinkGroup(GWEN_DB_NODE *n);
 
 /**
@@ -712,7 +744,7 @@ void GWEN_DB_UnlinkGroup(GWEN_DB_NODE *n);
  * @param n db node
  * @param path path to the group to delete
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_DeleteGroup(GWEN_DB_NODE *n,
                         const char *path);
 /**
@@ -722,7 +754,7 @@ int GWEN_DB_DeleteGroup(GWEN_DB_NODE *n,
  * @param path path to the group under the given node to clear
  * (if 0 then clear the given node)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_ClearGroup(GWEN_DB_NODE *n,
                        const char *path);
 
@@ -732,7 +764,7 @@ int GWEN_DB_ClearGroup(GWEN_DB_NODE *n,
  *
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_IsGroup(const GWEN_DB_NODE *n);
 
 /**
@@ -746,17 +778,17 @@ int GWEN_DB_IsGroup(const GWEN_DB_NODE *n);
  *
  * @param n db node
  */
-GWENHYWFAR_API 
-  uint32_t GWEN_DB_GetNodeFlags(const GWEN_DB_NODE *n);
+GWENHYWFAR_API
+uint32_t GWEN_DB_GetNodeFlags(const GWEN_DB_NODE *n);
 
 /**
  * Modifies the node flags for the given db node
  * @param n db node
  * @param flags flags to set (see @ref GWEN_DB_NODE_FLAGS_DIRTY)
  */
-GWENHYWFAR_API 
-  void GWEN_DB_SetNodeFlags(GWEN_DB_NODE *n,
-                            uint32_t flags);
+GWENHYWFAR_API
+void GWEN_DB_SetNodeFlags(GWEN_DB_NODE *n,
+                          uint32_t flags);
 
 /**
  * Modifies the flags of the given node and all its parents according
@@ -766,7 +798,7 @@ GWENHYWFAR_API
  * @param mask only those flags which are set in this mask are modified
  *  according to newflags
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_DB_ModifyBranchFlagsUp(GWEN_DB_NODE *n,
                                  uint32_t newflags,
                                  uint32_t mask);
@@ -779,7 +811,7 @@ void GWEN_DB_ModifyBranchFlagsUp(GWEN_DB_NODE *n,
  * @param mask only those flags which are set in this mask are modified
  *  according to newflags
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_DB_ModifyBranchFlagsDown(GWEN_DB_NODE *n,
                                    uint32_t newflags,
                                    uint32_t mask);
@@ -801,42 +833,42 @@ void GWEN_DB_ModifyBranchFlagsDown(GWEN_DB_NODE *n,
 GWENHYWFAR_API
 int GWEN_DB_ReadFromFastBuffer(GWEN_DB_NODE *n,
                                GWEN_FAST_BUFFER *fb,
-			       uint32_t dbflags);
+                               uint32_t dbflags);
 
 GWENHYWFAR_API
 int GWEN_DB_ReadFromIo(GWEN_DB_NODE *n, GWEN_SYNCIO *sio, uint32_t dbflags);
 
 GWENHYWFAR_API
 int GWEN_DB_ReadFile(GWEN_DB_NODE *n,
-		     const char *fname,
-		     uint32_t dbflags);
+                     const char *fname,
+                     uint32_t dbflags);
 
 GWENHYWFAR_API
 int GWEN_DB_ReadFromString(GWEN_DB_NODE *n,
-			   const char *str,
+                           const char *str,
                            int len,
-			   uint32_t dbflags);
+                           uint32_t dbflags);
 
 GWENHYWFAR_API
 int GWEN_DB_WriteToFastBuffer(GWEN_DB_NODE *node,
-			      GWEN_FAST_BUFFER *fb,
-			      uint32_t dbflags);
+                              GWEN_FAST_BUFFER *fb,
+                              uint32_t dbflags);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_WriteToIo(GWEN_DB_NODE *node,
-		      GWEN_SYNCIO *sio,
-		      uint32_t dbflags);
+                      GWEN_SYNCIO *sio,
+                      uint32_t dbflags);
 
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_WriteFile(GWEN_DB_NODE *n,
-		      const char *fname,
-		      uint32_t dbflags);
+                      const char *fname,
+                      uint32_t dbflags);
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_WriteToBuffer(GWEN_DB_NODE *n,
-			  GWEN_BUFFER *buf,
-			  uint32_t dbflags);
+                          GWEN_BUFFER *buf,
+                          uint32_t dbflags);
 
 /**
  * Imports a file into a DB using a GWEN_DBIO importer.
@@ -848,12 +880,12 @@ int GWEN_DB_WriteToBuffer(GWEN_DB_NODE *n,
  * @param dbflags flags to use while importing (see
  * @ref GWEN_DB_FLAGS_OVERWRITE_VARS and others)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_ReadFileAs(GWEN_DB_NODE *n,
                        const char *fname,
                        const char *type,
                        GWEN_DB_NODE *params,
-		       uint32_t dbflags);
+                       uint32_t dbflags);
 
 /**
  * Exports a DB to a file using a GWEN_DBIO exporter.
@@ -865,7 +897,7 @@ int GWEN_DB_ReadFileAs(GWEN_DB_NODE *n,
  * @param dbflags flags to use while exporting (see
  * @ref GWEN_DB_FLAGS_OVERWRITE_VARS and others)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_WriteFileAs(GWEN_DB_NODE *n,
                         const char *fname,
                         const char *type,
@@ -885,7 +917,7 @@ int GWEN_DB_WriteFileAs(GWEN_DB_NODE *n,
  * If there is no variable then NULL is returned.
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetFirstVar(GWEN_DB_NODE *n);
 
 
@@ -910,18 +942,18 @@ GWEN_DB_NODE *GWEN_DB_GetFirstVar(GWEN_DB_NODE *n);
  *
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetNextVar(GWEN_DB_NODE *n);
 
 /**
  * Returns the name of the variable specified by the given node.
  * @param n db node specifying a variable (not a group !)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 const char *GWEN_DB_VariableName(GWEN_DB_NODE *n);
 
 
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_DB_VariableRename(GWEN_DB_NODE *n, const char *newname);
 
 /** Iterates through all variable nodes that are @e direct children
@@ -940,7 +972,7 @@ void GWEN_DB_VariableRename(GWEN_DB_NODE *n, const char *newname);
  * returns one. Otherwise (i.e. 'func' always returns NULL)
  * returns NULL.
  * @author Christian Stimming <stimming@tuhh.de> */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void *GWEN_DB_Variables_Foreach(GWEN_DB_NODE *node, GWEN_DB_NODES_CB func,
                                 void *user_data);
 
@@ -948,17 +980,17 @@ void *GWEN_DB_Variables_Foreach(GWEN_DB_NODE *node, GWEN_DB_NODES_CB func,
  * of the given node. In other words, this is the number of variable
  * nodes that will be reached in the GWEN_DB_Variables_Foreach()
  * function. */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 unsigned int GWEN_DB_Variables_Count(const GWEN_DB_NODE *node);
-    
+
 /**
  * Returns the type of the first value of the given variable
  * @param n root node of the DB
  * @param p path of the variable to inspect
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE_TYPE GWEN_DB_GetVariableType(GWEN_DB_NODE *n,
-					  const char *p);
+                                          const char *p);
 
 /**
  * Deletes the given variable by removing it and its values from the DB.
@@ -966,7 +998,7 @@ GWEN_DB_NODE_TYPE GWEN_DB_GetVariableType(GWEN_DB_NODE *n,
  * @param path path to the variable to remove
  * @return Zero on success, nonzero on error
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_DeleteVar(GWEN_DB_NODE *n,
                       const char *path);
 
@@ -976,7 +1008,7 @@ int GWEN_DB_DeleteVar(GWEN_DB_NODE *n,
  * @param n root of the DB
  * @param path path to the variable to check for
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_VariableExists(GWEN_DB_NODE *n,
                            const char *path);
 
@@ -988,9 +1020,9 @@ int GWEN_DB_VariableExists(GWEN_DB_NODE *n,
  * @param idx index number of the variable's value to check for
  */
 GWENHYWFAR_API
-  int GWEN_DB_ValueExists(GWEN_DB_NODE *n,
-                          const char *path,
-                          unsigned int idx);
+int GWEN_DB_ValueExists(GWEN_DB_NODE *n,
+                        const char *path,
+                        unsigned int idx);
 
 /** Predicate: Returns nonzero (TRUE) or zero (FALSE) if the given
  * NODE is a Variable or not. Usually the Application does not get in
@@ -998,7 +1030,7 @@ GWENHYWFAR_API
  *
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_IsVariable(const GWEN_DB_NODE *n);
 
 
@@ -1013,7 +1045,7 @@ int GWEN_DB_IsVariable(const GWEN_DB_NODE *n);
  * @param n db node
  * @param name name to look for (joker and wildcards allowed)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_FindFirstVar(GWEN_DB_NODE *n, const char *name);
 
 /**
@@ -1034,7 +1066,7 @@ GWEN_DB_NODE *GWEN_DB_FindFirstVar(GWEN_DB_NODE *n, const char *name);
  * @param n db node
  * @param name name to look for (joker and wildcards allowed)
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_FindNextVar(GWEN_DB_NODE *n, const char *name);
 
 /*@}*/
@@ -1049,7 +1081,7 @@ GWEN_DB_NODE *GWEN_DB_FindNextVar(GWEN_DB_NODE *n, const char *name);
  * If there is no value then NULL is returned.
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetFirstValue(GWEN_DB_NODE *n);
 
 /**
@@ -1068,7 +1100,7 @@ GWEN_DB_NODE *GWEN_DB_GetFirstValue(GWEN_DB_NODE *n);
  *
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE *GWEN_DB_GetNextValue(GWEN_DB_NODE *n);
 
 /** Iterates through all value nodes that are @e direct children
@@ -1087,27 +1119,27 @@ GWEN_DB_NODE *GWEN_DB_GetNextValue(GWEN_DB_NODE *n);
  * returns one. Otherwise (i.e. 'func' always returns NULL)
  * returns NULL.
  * @author Christian Stimming <stimming@tuhh.de> */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void *GWEN_DB_Values_Foreach(GWEN_DB_NODE *node, GWEN_DB_NODES_CB func,
                              void *user_data);
 
 /** Returns the number of value nodes that are @e direct children of
  * the given node. In other words, this is the number of value nodes
  * that will be reached in the GWEN_DB_Values_foreach() function. */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 unsigned int GWEN_DB_Values_Count(const GWEN_DB_NODE *node);
 
 /**
  * Returns the type of the given value.
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 GWEN_DB_NODE_TYPE GWEN_DB_GetValueType(GWEN_DB_NODE *n);
 
 GWENHYWFAR_API
 GWEN_DB_NODE_TYPE GWEN_DB_GetValueTypeByPath(GWEN_DB_NODE *n,
-					     const char *p,
-					     unsigned int i);
+                                             const char *p,
+                                             unsigned int i);
 
 /**
  * Returns the value data of the given value node.
@@ -1137,7 +1169,7 @@ const void *GWEN_DB_GetBinValueFromNode(const GWEN_DB_NODE *n,
  *
  * @param n db node
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 int GWEN_DB_IsValue(const GWEN_DB_NODE *n);
 /*@}*/
 
@@ -1158,11 +1190,28 @@ int GWEN_DB_IsValue(const GWEN_DB_NODE *n);
  * @param n node to dump
  * @param insert number of blanks to insert at every line
  */
-GWENHYWFAR_API 
+GWENHYWFAR_API
 void GWEN_DB_Dump(GWEN_DB_NODE *n, int insert);
 /*@}*/
 
 
+/** @name Higher Level Utility Functions
+ *
+ * These functions make use of GWEN_DB groups.
+ */
+/*@{*/
+
+
+/**
+ * Read the given string and replace every variable in that string ( noted as "$(varname)") with the
+ * value of the mentioned variable.
+ */
+GWENHYWFAR_API
+int GWEN_DB_ReplaceVars(GWEN_DB_NODE *db, const char *s, GWEN_BUFFER *dbuf);
+/*@}*/
+
+
+
 /*@}*/
 
 
