@@ -99,25 +99,25 @@ char *GWEN_Text_Unescape(const char *src,
 
 GWENHYWFAR_API
 char *GWEN_Text_UnescapeN(const char *src,
-			  unsigned int srclen,
+                          unsigned int srclen,
                           char *buffer,
                           unsigned int maxsize);
 
 GWENHYWFAR_API
 char *GWEN_Text_EscapeTolerant(const char *src,
-			       char *buffer,
-			       unsigned int maxsize);
+                               char *buffer,
+                               unsigned int maxsize);
 
 GWENHYWFAR_API
 char *GWEN_Text_UnescapeTolerant(const char *src,
-				 char *buffer,
-				 unsigned int maxsize);
+                                 char *buffer,
+                                 unsigned int maxsize);
 
 GWENHYWFAR_API
 char *GWEN_Text_UnescapeTolerantN(const char *src,
-				  unsigned int srclen,
-				  char *buffer,
-				  unsigned int maxsize);
+                                  unsigned int srclen,
+                                  char *buffer,
+                                  unsigned int maxsize);
 
 
 GWENHYWFAR_API
@@ -220,7 +220,7 @@ int GWEN_Text_NumToString(int num, char *buffer, unsigned int bufsize,
 
 /**
  * This functions transforms a string into a double float value.
- * It always uses a comma (",") regardless of the current locale settings.
+ * It always uses a decimal point (".") regardless of the current locale settings.
  * This makes sure that a value can always be parsed regardless of the
  * country settings of the producer of that string.
  */
@@ -229,7 +229,7 @@ int GWEN_Text_DoubleToBuffer(double num, GWEN_BUFFER *buf);
 
 /**
  * This functions transforms a double float value into a string.
- * It always uses a comma (",") regardless of the current locale settings.
+ * It always uses a decimal point (".") regardless of the current locale settings.
  * This makes sure that a value can always be parsed regardless of the
  * country settings of the producer of that string.
  */
@@ -255,6 +255,14 @@ GWENHYWFAR_API
 const char *GWEN_Text_StrCaseStr(const char *haystack, const char *needle);
 
 
+/**
+ * This function provides the functionality of strndup() which is not
+ * available on Windows (uses strndup() on all other systems).
+ */
+GWENHYWFAR_API
+char *GWEN_Text_strndup(const char *s, size_t n);
+
+
 /**
  * This function compares two string and returns the number of matches or
  * -1 on error.
@@ -291,7 +299,7 @@ void GWEN_Text_LogString(const char *s, unsigned int l,
  * This means removing unnecessary spaces.
  */
 GWENHYWFAR_API
-  void GWEN_Text_CondenseBuffer(GWEN_BUFFER *buf);
+void GWEN_Text_CondenseBuffer(GWEN_BUFFER *buf);
 
 
 /**
@@ -301,7 +309,7 @@ GWENHYWFAR_API
  *  counted)
  */
 GWENHYWFAR_API
-  int GWEN_Text_CountUtf8Chars(const char *s, int len);
+int GWEN_Text_CountUtf8Chars(const char *s, int len);
 
 
 /**
@@ -334,7 +342,39 @@ int GWEN_Text_UnescapeXmlToBuffer(const char *src, GWEN_BUFFER *buf);
  * @param ign if !=0 then the cases are ignored
  */
 GWENHYWFAR_API
-  double GWEN_Text_CheckSimilarity(const char *s1, const char *s2, int ign);
+double GWEN_Text_CheckSimilarity(const char *s1, const char *s2, int ign);
+
+
+/**
+ * This function converts a given text from one charset to another one.
+ * Currently, iconv is used for this conversion.
+ *
+ * @param fromCharset charset of the source text
+ * @param toCharset charset of the source text
+ * @param text text to convert
+ * @param len length of the text (excluding trailing 0)
+ * @param tbuf destination buffer for the converted text
+ */
+GWENHYWFAR_API
+int GWEN_Text_ConvertCharset(const char *fromCharset,
+                             const char *toCharset,
+                             const char *text, int len,
+                             GWEN_BUFFER *tbuf);
+
+
+
+
+
+typedef int GWENHYWFAR_CB(*GWEN_TEXT_REPLACE_VARS_CB)(void *cbPtr, const char *name, int index, int maxLen,
+                                                      GWEN_BUFFER *dstBuf);
+
+
+/**
+ * Read the given string and replace every variable in that string ( noted as "$(varname)") with the
+ * value of the mentioned variable. Uses a callback to actually retrieve the data.
+ */
+GWENHYWFAR_API
+int GWEN_Text_ReplaceVars(const char *s, GWEN_BUFFER *dbuf, GWEN_TEXT_REPLACE_VARS_CB fn, void *ptr);
 
 
 
