@@ -110,7 +110,8 @@ extern "C" {
 #define GWEN_XML_FLAGS_DEFAULT \
   (\
   GWEN_XML_FLAGS_INDENT | \
-  GWEN_XML_FLAGS_HANDLE_COMMENTS\
+  GWEN_XML_FLAGS_HANDLE_COMMENTS | \
+  GWEN_XML_FLAGS_HANDLE_HEADERS\
   )
 
 /*@}*/
@@ -516,8 +517,8 @@ int GWEN_XMLNode_GetXPath(const GWEN_XMLNODE *n1,
  */
 GWENHYWFAR_API
 GWEN_XMLNODE *GWEN_XMLNode_GetNodeByXPath(GWEN_XMLNODE *n,
-    const char *path,
-    uint32_t flags);
+                                          const char *path,
+                                          uint32_t flags);
 
 
 /*@}*/
@@ -664,11 +665,11 @@ GWEN_XMLNODE_NAMESPACE_LIST *GWEN_XMLNode_GetNameSpaces(const GWEN_XMLNODE *n);
 
 GWENHYWFAR_API
 GWEN_XMLNODE_NAMESPACE *GWEN_XMLNode_FindNameSpaceByName(const GWEN_XMLNODE *n,
-    const char *s);
+                                                         const char *s);
 
 GWENHYWFAR_API
 GWEN_XMLNODE_NAMESPACE *GWEN_XMLNode_FindNameSpaceByUrl(const GWEN_XMLNODE *n,
-    const char *s);
+                                                        const char *s);
 
 GWENHYWFAR_API
 void GWEN_XMLNode_AddNameSpace(GWEN_XMLNODE *n, const GWEN_XMLNODE_NAMESPACE *ns);
@@ -704,6 +705,10 @@ void GWEN_XMLNode_AddNameSpace(GWEN_XMLNODE *n, const GWEN_XMLNODE_NAMESPACE *ns
 /*@{*/
 
 /**
+ * Reads a char value. If no name is given (i.e. name is NULL or empty) then
+ * the data returned is that from the first data node below the given node.
+ * Otherwise a node with the given name is searched below the given node
+ * and its first data node's data is returned.
  * @param n Node which is expected to contain a node of the specified name
  * @param name name of the node below n to be looked up
  * @param defValue default value to return if the tag did not exist
@@ -732,8 +737,8 @@ void GWEN_XMLNode_SetCharValue(GWEN_XMLNODE *n,
  */
 GWENHYWFAR_API
 const char *GWEN_XMLNode_GetLocalizedCharValue(const GWEN_XMLNODE *n,
-    const char *name,
-    const char *defValue);
+                                               const char *name,
+                                               const char *defValue);
 
 /**
  * Internally calls @ref GWEN_XMLNode_GetCharValue and interpretes the
@@ -788,8 +793,8 @@ void GWEN_XMLNode_SetIntValue(GWEN_XMLNODE *n,
  */
 GWENHYWFAR_API
 const char *GWEN_XMLNode_GetCharValueByPath(GWEN_XMLNODE *n,
-    const char *path,
-    const char *defValue);
+                                            const char *path,
+                                            const char *defValue);
 
 GWENHYWFAR_API
 int GWEN_XMLNode_SetCharValueByPath(GWEN_XMLNODE *n, uint32_t flags,
@@ -875,7 +880,7 @@ void GWEN_XMLNode_Path_Dump(GWEN_XMLNODE_PATH *np);
 
 GWENHYWFAR_API
 GWEN_XMLNODE_NAMESPACE *GWEN_XMLNode_NameSpace_new(const char *name,
-    const char *url);
+                                                   const char *url);
 
 GWENHYWFAR_API
 void GWEN_XMLNode_NameSpace_free(GWEN_XMLNODE_NAMESPACE *ns);
