@@ -1,5 +1,5 @@
 /***************************************************************************
- copyright   : (C) 2007-2010 by Martin Preuss
+ copyright   : (C) 2020 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -26,152 +26,446 @@
 
 
 
-int GWEN_XMLNode__WriteToStream(const GWEN_XMLNODE *n,
-				GWEN_FAST_BUFFER *fb,
-				uint32_t flags,
-				unsigned int ind) {
-  GWEN_XMLPROPERTY *p;
-  GWEN_XMLNODE *c;
+static int GWEN_XMLNode__WriteIndents(GWEN_FAST_BUFFER *fb, int ind)
+{
   int i;
-  int simpleTag;
-  int rv;
+  int rv=0;
 
-#define CHECK_ERROR(rv) \
-  if (rv<0) {\
-    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);\
-    return rv;\
-  }
-
-  assert(n);
-
-  if (flags & GWEN_XML_FLAGS_INDENT) {
-    for(i=0; i<ind; i++) {
-      GWEN_FASTBUFFER_WRITEBYTE(fb, rv, ' ');
-      CHECK_ERROR(rv);
+  for (i=0; i<ind; i++) {
+    GWEN_FASTBUFFER_WRITEBYTE(fb, rv, ' ');
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
     }
   }
+  return 0;
+}
 
-  simpleTag=0;
-  if (n->type==GWEN_XMLNodeTypeTag) {
-    if (n->data) {
-      GWEN_FASTBUFFER_WRITEBYTE(fb, rv, '<');
-      CHECK_ERROR(rv);
-      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, n->data, -1);
-      CHECK_ERROR(rv);
+
+
+static int GWEN_XMLNode__WriteNamespacesToStream(const GWEN_XMLNODE *n, GWEN_FAST_BUFFER *fb)
+{
+  GWEN_XMLNODE_NAMESPACE *ns;
+
+  ns=GWEN_XMLNode_NameSpace_List_First(n->nameSpaces);
+  while (ns) {
+    const char *name;
+    const char *url;
+    int rv;
+
+    name=GWEN_XMLNode_NameSpace_GetName(ns);
+    url=GWEN_XMLNode_NameSpace_GetUrl(ns);
+    GWEN_FASTBUFFER_WRITEBYTE(fb, rv, ' ');
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
     }
-    else {
-      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "<UNKNOWN", -1);
-      CHECK_ERROR(rv);
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "xmlns", -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
     }
-
-    if (flags & GWEN_XML_FLAGS_HANDLE_NAMESPACES) {
-      GWEN_XMLNODE_NAMESPACE *ns;
-
-      ns=GWEN_XMLNode_NameSpace_List_First(n->nameSpaces);
-      while(ns) {
-	const char *name;
-	const char *url;
-
-	name=GWEN_XMLNode_NameSpace_GetName(ns);
-	url=GWEN_XMLNode_NameSpace_GetUrl(ns);
-	GWEN_FASTBUFFER_WRITEBYTE(fb, rv, ' ');
-	CHECK_ERROR(rv);
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "xmlns", -1);
-	CHECK_ERROR(rv);
-	if (name) {
-	  GWEN_FASTBUFFER_WRITEFORCED(fb, rv, ":", -1);
-	  CHECK_ERROR(rv);
-	  GWEN_FASTBUFFER_WRITEFORCED(fb, rv, name, -1);
-	  CHECK_ERROR(rv);
-	}
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "=\"", -1);
-	CHECK_ERROR(rv);
-	if (url) {
-	  GWEN_FASTBUFFER_WRITEFORCED(fb, rv, url, -1);
-	  CHECK_ERROR(rv);
-	}
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "\"", -1);
-	CHECK_ERROR(rv);
-
-	ns=GWEN_XMLNode_NameSpace_List_Next(ns);
+    if (name && *name) {
+      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, ":", -1);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, name, -1);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
       }
     }
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "=\"", -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+    if (url) {
+      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, url, -1);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "\"", -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
 
-    p=n->properties;
+    ns=GWEN_XMLNode_NameSpace_List_Next(ns);
+  }
+
+  return 0;
+}
+
+
+
+static int GWEN_XMLNode__WritePropertiesToStream(const GWEN_XMLNODE *n, GWEN_FAST_BUFFER *fb, const char *encoding)
+{
+  GWEN_XMLPROPERTY *p;
+
+  p=n->properties;
+  if (p) {
+    GWEN_BUFFER *buf;
+    int rv=0;
+
+    buf=GWEN_Buffer_new(0, 256, 0, 1);
     while (p) {
       GWEN_FASTBUFFER_WRITEBYTE(fb, rv, ' ');
-      CHECK_ERROR(rv);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        GWEN_Buffer_free(buf);
+        return rv;
+      }
       GWEN_FASTBUFFER_WRITEFORCED(fb, rv, p->name, -1);
-      CHECK_ERROR(rv);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        GWEN_Buffer_free(buf);
+        return rv;
+      }
       if (p->value) {
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "=\"", -1);
-	CHECK_ERROR(rv);
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, p->value, -1);
-	CHECK_ERROR(rv);
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "\"", -1);
-	CHECK_ERROR(rv);
+        GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "=\"", -1);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Buffer_free(buf);
+          return rv;
+        }
+        rv=GWEN_Text_ConvertCharset("UTF-8", encoding, p->value, strlen(p->value), buf);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Buffer_free(buf);
+          return rv;
+        }
+        GWEN_FASTBUFFER_WRITEFORCED(fb, rv, GWEN_Buffer_GetStart(buf), -1);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Buffer_free(buf);
+          return rv;
+        }
+        GWEN_Buffer_Reset(buf);
+        GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "\"", -1);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Buffer_free(buf);
+          return rv;
+        }
       }
       p=p->next;
     }
+  }
 
-    if (n->data) {
-      if (n->data[0]=='?') {
-        simpleTag=1;
-	GWEN_FASTBUFFER_WRITEBYTE(fb, rv, '?');
-	CHECK_ERROR(rv);
-      }
-      else if (n->data[0]=='!') {
-        simpleTag=1;
-      }
-    }
+  return 0;
+}
 
-    GWEN_FASTBUFFER_WRITELINE(fb, rv, ">");
-    CHECK_ERROR(rv);
-    if (!simpleTag) {
-      c=GWEN_XMLNode_GetChild(n);
-      while(c) {
-	rv=GWEN_XMLNode__WriteToStream(c, fb, flags, ind+2);
-	CHECK_ERROR(rv);
-        c=GWEN_XMLNode_Next(c);
-      }
-      if (flags & GWEN_XML_FLAGS_INDENT) {
-	for(i=0; i<ind; i++) {
-	  GWEN_FASTBUFFER_WRITEBYTE(fb, rv, ' ');
-	  CHECK_ERROR(rv);
-	}
-      }
-      if (n->data) {
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "</", -1);
-	CHECK_ERROR(rv);
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, n->data, -1);
-	CHECK_ERROR(rv);
-	GWEN_FASTBUFFER_WRITELINE(fb, rv, ">");
-	CHECK_ERROR(rv);
-      }
-      else {
-	GWEN_FASTBUFFER_WRITELINE(fb, rv, "</UNKNOWN>");
-	CHECK_ERROR(rv);
+
+
+static int GWEN_XMLNode__WriteTagToStream(const GWEN_XMLNODE *n,
+                                          GWEN_FAST_BUFFER *fb,
+                                          uint32_t flags,
+                                          const char *encoding,
+                                          unsigned int ind)
+{
+  int rv;
+  int simpleTag=0;
+
+  if (!(flags & GWEN_XML_FLAGS_SIMPLE)) {
+    if (flags & GWEN_XML_FLAGS_INDENT) {
+      rv=GWEN_XMLNode__WriteIndents(fb, ind);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
       }
     }
   }
-  else if (n->type==GWEN_XMLNodeTypeData) {
-    if (n->data) {
-      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, n->data, -1);
-      CHECK_ERROR(rv);
+
+  /* write element opening ("<NAME") */
+  if (n->data) {
+    GWEN_FASTBUFFER_WRITEBYTE(fb, rv, '<');
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, n->data, -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+  }
+  else {
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "<UNKNOWN", -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+  }
+
+  /* write namespaces */
+  if (flags & GWEN_XML_FLAGS_HANDLE_NAMESPACES) {
+    rv=GWEN_XMLNode__WriteNamespacesToStream(n, fb);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+  }
+
+  /* write properties */
+  rv=GWEN_XMLNode__WritePropertiesToStream(n, fb, encoding);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    return rv;
+  }
+
+
+  /* write element closing (">) */
+  if (n->data) {
+    if (n->data[0]=='?') {
+      simpleTag=1;
+      GWEN_FASTBUFFER_WRITEBYTE(fb, rv, '?');
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+    else if (n->data[0]=='!') {
+      simpleTag=1;
+    }
+  }
+  if (flags & GWEN_XML_FLAGS_SIMPLE) {
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, ">", -1);
+  }
+  else {
+    GWEN_FASTBUFFER_WRITELINE(fb, rv, ">");
+  }
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    return rv;
+  }
+
+  /* probably write children */
+  if (!simpleTag) {
+    int hasSubTags;
+    GWEN_XMLNODE *c;
+
+    hasSubTags=(GWEN_XMLNode_GetFirstTag(n)!=NULL);
+    if (hasSubTags) {
       GWEN_FASTBUFFER_WRITELINE(fb, rv, "");
-      CHECK_ERROR(rv);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+
+    c=GWEN_XMLNode_GetChild(n);
+    while (c) {
+      rv=GWEN_XMLNode__WriteToStream(c, fb, flags, encoding, ind+2);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+      c=GWEN_XMLNode_Next(c);
+    }
+
+    if (!(flags & GWEN_XML_FLAGS_SIMPLE)) {
+      if (flags & GWEN_XML_FLAGS_INDENT) {
+        rv=GWEN_XMLNode__WriteIndents(fb, ind);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          return rv;
+        }
+      }
+    }
+
+    /* write closing tag ("</NAME>") */
+    if (n->data) {
+      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "</", -1);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, n->data, -1);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+      if (flags & GWEN_XML_FLAGS_SIMPLE) {
+#if 0
+        if (!hasSubTags) {
+          GWEN_FASTBUFFER_WRITELINE(fb, rv, ">");
+        }
+        else {
+          GWEN_FASTBUFFER_WRITEFORCED(fb, rv, ">", -1);
+        }
+#else
+        GWEN_FASTBUFFER_WRITELINE(fb, rv, ">");
+#endif
+      }
+      else {
+        GWEN_FASTBUFFER_WRITELINE(fb, rv, ">");
+      }
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+    else {
+      GWEN_FASTBUFFER_WRITELINE(fb, rv, "</UNKNOWN>");
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+  }
+
+  return 0;
+}
+
+
+
+static int GWEN_XMLNode__WriteDataToStream(const GWEN_XMLNODE *n,
+                                           GWEN_FAST_BUFFER *fb,
+                                           uint32_t flags,
+                                           const char *encoding,
+                                           unsigned int ind)
+{
+
+  if (n->data) {
+    GWEN_BUFFER *buf;
+    int rv=0;
+
+    if (!(flags & GWEN_XML_FLAGS_SIMPLE)) {
+      if (flags & GWEN_XML_FLAGS_INDENT) {
+        rv=GWEN_XMLNode__WriteIndents(fb, ind);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          return rv;
+        }
+      }
+    }
+
+    buf=GWEN_Buffer_new(0, 256, 0, 1);
+    rv=GWEN_Text_ConvertCharset("UTF-8", encoding, n->data, strlen(n->data), buf);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      GWEN_Buffer_free(buf);
+      return rv;
+    }
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, GWEN_Buffer_GetStart(buf), -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      GWEN_Buffer_free(buf);
+      return rv;
+    }
+    GWEN_Buffer_free(buf);
+    if (!(flags & GWEN_XML_FLAGS_SIMPLE)) {
+      GWEN_FASTBUFFER_WRITELINE(fb, rv, "");
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+  }
+
+  return 0;
+}
+
+
+
+static int GWEN_XMLNode__WriteCommentToStream(const GWEN_XMLNODE *n,
+                                              GWEN_FAST_BUFFER *fb,
+                                              uint32_t flags,
+                                              const char *encoding,
+                                              unsigned int ind)
+{
+
+  if (n->data) {
+    GWEN_BUFFER *buf;
+    int rv=0;
+
+    if (!(flags & GWEN_XML_FLAGS_SIMPLE)) {
+      if (flags & GWEN_XML_FLAGS_INDENT) {
+        rv=GWEN_XMLNode__WriteIndents(fb, ind);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          return rv;
+        }
+      }
+    }
+
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "<!--", -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+
+    buf=GWEN_Buffer_new(0, 256, 0, 1);
+    rv=GWEN_Text_ConvertCharset("UTF-8", encoding, n->data, strlen(n->data), buf);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      GWEN_Buffer_free(buf);
+      return rv;
+    }
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, GWEN_Buffer_GetStart(buf), -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      GWEN_Buffer_free(buf);
+      return rv;
+    }
+    GWEN_Buffer_free(buf);
+
+    GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "-->", -1);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+
+    if (!(flags & GWEN_XML_FLAGS_SIMPLE)) {
+      GWEN_FASTBUFFER_WRITELINE(fb, rv, "");
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+  }
+
+  return 0;
+}
+
+
+
+static int GWEN_XMLNode__WriteToStream(const GWEN_XMLNODE *n,
+                                       GWEN_FAST_BUFFER *fb,
+                                       uint32_t flags,
+                                       const char *encoding,
+                                       unsigned int ind)
+{
+  int rv;
+
+  assert(n);
+
+  if (n->type==GWEN_XMLNodeTypeTag) {
+    rv=GWEN_XMLNode__WriteTagToStream(n, fb, flags, encoding, ind);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+  }
+  else if (n->type==GWEN_XMLNodeTypeData) {
+    rv=GWEN_XMLNode__WriteDataToStream(n, fb, flags, encoding, ind);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      return rv;
     }
   }
   else if (n->type==GWEN_XMLNodeTypeComment) {
     if (flags & GWEN_XML_FLAGS_HANDLE_COMMENTS) {
-      GWEN_FASTBUFFER_WRITEFORCED(fb, rv, "<!--", -1);
-      CHECK_ERROR(rv);
-      if (n->data) {
-	GWEN_FASTBUFFER_WRITEFORCED(fb, rv, n->data, -1);
-	CHECK_ERROR(rv);
+      rv=GWEN_XMLNode__WriteCommentToStream(n, fb, flags, encoding, ind);
+      if (rv<0) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        return rv;
       }
-      GWEN_FASTBUFFER_WRITELINE(fb, rv, "-->");
-      CHECK_ERROR(rv);
     }
   }
   else {
@@ -179,14 +473,14 @@ int GWEN_XMLNode__WriteToStream(const GWEN_XMLNODE *n,
   }
 
   return 0;
-#undef CHECK_ERROR
 }
 
 
 
 int GWEN_XMLNode_WriteToStream(const GWEN_XMLNODE *n,
-			       GWEN_XML_CONTEXT *ctx,
-			       GWEN_SYNCIO *sio){
+                               GWEN_XML_CONTEXT *ctx,
+                               GWEN_SYNCIO *sio)
+{
   const GWEN_XMLNODE *nn;
   const GWEN_XMLNODE *nchild;
   const GWEN_XMLNODE *nheader;
@@ -201,29 +495,39 @@ int GWEN_XMLNode_WriteToStream(const GWEN_XMLNODE *n,
   fb=GWEN_FastBuffer_new(512, sio);
 
   if (nheader && (flags & GWEN_XML_FLAGS_HANDLE_HEADERS)) {
-    uint32_t lflags;
 
-    lflags=flags & ~GWEN_XML_FLAGS_HANDLE_HEADERS;
     nn=nheader;
-    while(nn) {
+    while (nn) {
       const GWEN_XMLNODE *next;
 
-      rv=GWEN_XMLNode__WriteToStream(nn, fb, GWEN_XmlCtx_GetFlags(ctx), 0);
+      rv=GWEN_XMLNode__WriteToStream(nn, fb, flags,
+                                     GWEN_XmlCtx_GetEncoding(ctx), 0);
       if (rv<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	GWEN_FastBuffer_free(fb);
-	return rv;
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        GWEN_FastBuffer_free(fb);
+        return rv;
       }
       next=GWEN_XMLNode_Next(nn);
       if (next) {
         int err;
 
-	GWEN_FASTBUFFER_WRITELINE(fb, err, "");
-	if (err<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", err);
-	  GWEN_FastBuffer_free(fb);
-	  return err;
-	}
+        GWEN_FASTBUFFER_WRITELINE(fb, err, "");
+        if (err<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", err);
+          GWEN_FastBuffer_free(fb);
+          return err;
+        }
+      }
+      if (strcmp(GWEN_XMLNode_GetData(nn), "?xml")==0) {
+        const char *encoding;
+
+        encoding=GWEN_XMLNode_GetProperty(nn, "encoding", NULL);
+        if (encoding) {
+          if (strcasecmp(encoding, "UTF-8")==0 ||
+              strcasecmp(encoding, "UTF8")==0)
+            encoding=NULL;
+          GWEN_XmlCtx_SetEncoding(ctx, encoding);
+        }
       }
 
       nn=next;
@@ -234,18 +538,19 @@ int GWEN_XMLNode_WriteToStream(const GWEN_XMLNODE *n,
 
       GWEN_FASTBUFFER_WRITELINE(fb, err, "");
       if (err<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", err);
-	GWEN_FastBuffer_free(fb);
-	return err;
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", err);
+        GWEN_FastBuffer_free(fb);
+        return err;
       }
     }
   }
 
   nn=nchild;
-  while(nn) {
+  while (nn) {
     const GWEN_XMLNODE *next;
 
-    if (GWEN_XMLNode__WriteToStream(nn, fb, GWEN_XmlCtx_GetFlags(ctx), 0))
+    if (GWEN_XMLNode__WriteToStream(nn, fb, flags,
+                                    GWEN_XmlCtx_GetEncoding(ctx), 0))
       return -1;
     next=GWEN_XMLNode_Next(nn);
     if (next) {
@@ -253,9 +558,9 @@ int GWEN_XMLNode_WriteToStream(const GWEN_XMLNODE *n,
 
       GWEN_FASTBUFFER_WRITELINE(fb, err, "");
       if (err<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", err);
-	GWEN_FastBuffer_free(fb);
-	return err;
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", err);
+        GWEN_FastBuffer_free(fb);
+        return err;
       }
     }
 
@@ -277,7 +582,8 @@ int GWEN_XMLNode_WriteToStream(const GWEN_XMLNODE *n,
 
 int GWEN_XMLNode_WriteFile(const GWEN_XMLNODE *n,
                            const char *fname,
-                           uint32_t flags){
+                           uint32_t flags)
+{
   GWEN_XML_CONTEXT *ctx;
   GWEN_SYNCIO *sio;
   int rv;
@@ -317,7 +623,8 @@ int GWEN_XMLNode_WriteFile(const GWEN_XMLNODE *n,
 
 
 
-int GWEN_XMLNode_toBuffer(const GWEN_XMLNODE *n, GWEN_BUFFER *buf, uint32_t flags){
+int GWEN_XMLNode_toBuffer(const GWEN_XMLNODE *n, GWEN_BUFFER *buf, uint32_t flags)
+{
   GWEN_XML_CONTEXT *ctx;
   GWEN_SYNCIO *sio;
   int rv;
@@ -351,8 +658,9 @@ int GWEN_XMLNode_toBuffer(const GWEN_XMLNODE *n, GWEN_BUFFER *buf, uint32_t flag
 
 
 int GWEN_XML__ReadData(GWEN_XML_CONTEXT *ctx,
-		       GWEN_FAST_BUFFER *fb,
-		       GWEN_UNUSED uint32_t flags){
+                       GWEN_FAST_BUFFER *fb,
+                       GWEN_UNUSED uint32_t flags)
+{
   int chr;
   unsigned char uc;
   GWEN_BUFFER *dbuf;
@@ -363,10 +671,10 @@ int GWEN_XML__ReadData(GWEN_XML_CONTEXT *ctx,
     GWEN_FASTBUFFER_PEEKBYTE(fb, chr);
     if (chr<0) {
       if (chr==GWEN_ERROR_EOF)
-	break;
+        break;
       else {
-	GWEN_Buffer_free(dbuf);
-	return chr;
+        GWEN_Buffer_free(dbuf);
+        return chr;
       }
     }
 
@@ -379,14 +687,26 @@ int GWEN_XML__ReadData(GWEN_XML_CONTEXT *ctx,
 
   if (GWEN_Buffer_GetUsedBytes(dbuf)) {
     int rv;
-    const char *s;
+    uint32_t len;
+    char *s;
 
+    len=GWEN_Buffer_GetUsedBytes(dbuf);
+    s=strdup(GWEN_Buffer_GetStart(dbuf));
+    assert(s);
+    GWEN_Buffer_Reset(dbuf);
+    rv=GWEN_Text_ConvertCharset(GWEN_XmlCtx_GetEncoding(ctx), "UTF-8",
+                                s, len, dbuf);
+    free(s);
+    if (rv) {
+      GWEN_Buffer_free(dbuf);
+      return rv;
+    }
     s=GWEN_Buffer_GetStart(dbuf);
     if (*s) {
       rv=GWEN_XmlCtx_AddData(ctx, s);
       if (rv) {
-	GWEN_Buffer_free(dbuf);
-	return rv;
+        GWEN_Buffer_free(dbuf);
+        return rv;
       }
     }
   }
@@ -398,9 +718,10 @@ int GWEN_XML__ReadData(GWEN_XML_CONTEXT *ctx,
 
 
 int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
-		      GWEN_FAST_BUFFER *fb,
+                      GWEN_FAST_BUFFER *fb,
                       GWEN_UNUSED uint32_t flags,
-                      GWEN_BUFFER *dbuf){
+                      GWEN_BUFFER *dbuf)
+{
   int chr;
   unsigned char uc=0;
   int rv;
@@ -422,11 +743,11 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
     for (;;) {
       GWEN_FASTBUFFER_READBYTE(fb, chr);
       if (chr<0) {
-	return chr;
+        return chr;
       }
       uc=(unsigned char) chr;
       if (uc=='>' || uc<33)
-	break;
+        break;
 
       GWEN_Buffer_AppendByte(dbuf, uc);
     }
@@ -437,18 +758,21 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
     }
     if (uc!='>') {
       for (;;) {
-	/* skip blanks, expect '>' */
-	GWEN_FASTBUFFER_READBYTE(fb, chr);
-	if (chr<0) {
-	  return chr;
-	}
-	uc=(unsigned char) chr;
-	if (uc>32)
-	  break;
+        /* skip blanks, expect '>' */
+        GWEN_FASTBUFFER_READBYTE(fb, chr);
+        if (chr<0) {
+          return chr;
+        }
+        uc=(unsigned char) chr;
+        if (uc>32)
+          break;
       }
     }
     if (uc!='>') {
       DBG_ERROR(GWEN_LOGDOMAIN, "Unexpected character");
+      DBG_ERROR(GWEN_LOGDOMAIN, "Data so far:");
+      GWEN_Buffer_Dump(dbuf, 2);
+
       return GWEN_ERROR_BAD_DATA;
     }
 
@@ -470,43 +794,56 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
       fb->bufferReadPos++;
       GWEN_FASTBUFFER_PEEKBYTE(fb, chr);
       if (chr<0) {
-	return chr;
+        return chr;
       }
       uc=(unsigned char) chr;
       if (uc=='-') {
-	GWEN_BUFFER *cbuf;
+        GWEN_BUFFER *cbuf;
 
-	/* found comment */
-	fb->bufferReadPos++;
-	cbuf=GWEN_Buffer_new(0, 256, 0, 1);
-	for (;;) {
-	  GWEN_FASTBUFFER_READBYTE(fb, chr);
-	  if (chr<0) {
-	    GWEN_Buffer_free(cbuf);
-	    return chr;
-	  }
-	  uc=(unsigned char) chr;
-	  GWEN_Buffer_AppendByte(cbuf, uc);
-	  if (GWEN_Buffer_GetUsedBytes(cbuf)>2) {
-	    char *p;
+        /* found comment */
+        fb->bufferReadPos++;
+        cbuf=GWEN_Buffer_new(0, 256, 0, 1);
+        for (;;) {
+          GWEN_FASTBUFFER_READBYTE(fb, chr);
+          if (chr<0) {
+            GWEN_Buffer_free(cbuf);
+            return chr;
+          }
+          uc=(unsigned char) chr;
+          GWEN_Buffer_AppendByte(cbuf, uc);
+          if (GWEN_Buffer_GetUsedBytes(cbuf)>2) {
+            char *p;
 
-	    p=GWEN_Buffer_GetStart(cbuf);
-	    p+=GWEN_Buffer_GetUsedBytes(cbuf)-3;
-	    if (strcmp(p, "-->")==0) {
-	      *p=0;
-	      rv=GWEN_XmlCtx_AddComment(ctx, GWEN_Buffer_GetStart(cbuf));
-	      if (rv) {
-		GWEN_Buffer_free(cbuf);
+            p=GWEN_Buffer_GetStart(cbuf);
+            p+=GWEN_Buffer_GetUsedBytes(cbuf)-3;
+            if (strcmp(p, "-->")==0) {
+              uint32_t len;
+
+              *p=0;
+              len=GWEN_Buffer_GetUsedBytes(cbuf)-3;
+              p=strdup(GWEN_Buffer_GetStart(cbuf));
+              assert(p);
+              GWEN_Buffer_Reset(cbuf);
+              rv=GWEN_Text_ConvertCharset(GWEN_XmlCtx_GetEncoding(ctx), "UTF-8",
+                                          p, len, cbuf);
+              free(p);
+              if (rv) {
+                GWEN_Buffer_free(cbuf);
                 return rv;
-	      }
-	      GWEN_Buffer_free(cbuf);
-	      return 0;
-	    }
-	  }
-	}
+              }
+              rv=GWEN_XmlCtx_AddComment(ctx, GWEN_Buffer_GetStart(cbuf));
+              if (rv) {
+                GWEN_Buffer_free(cbuf);
+                return rv;
+              }
+              GWEN_Buffer_free(cbuf);
+              return 0;
+            }
+          }
+        }
       }
       else {
-	GWEN_Buffer_AppendString(dbuf, "!-");
+        GWEN_Buffer_AppendString(dbuf, "!-");
       }
     }
     else
@@ -522,15 +859,15 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
 
       fc=*GWEN_Buffer_GetStart(dbuf);
       if ((fc=='!' && uc=='!') || (fc=='?' && uc=='?')) {
-	GWEN_FASTBUFFER_PEEKBYTE(fb, chr);
-	if (chr<0) {
-	  return chr;
-	}
-	uc=(unsigned char) chr;
-	if (uc=='>') {
-	  fb->bufferReadPos++;
-	  break;
-	}
+        GWEN_FASTBUFFER_PEEKBYTE(fb, chr);
+        if (chr<0) {
+          return chr;
+        }
+        uc=(unsigned char) chr;
+        if (uc=='>') {
+          fb->bufferReadPos++;
+          break;
+        }
       }
     }
 
@@ -539,10 +876,10 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
     GWEN_FASTBUFFER_READBYTE(fb, chr);
     if (chr<0) {
       if (chr==GWEN_ERROR_EOF) {
-	return chr;
+        return chr;
       }
       else {
-	return chr;
+        return chr;
       }
     }
 
@@ -570,7 +907,7 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
       fb->bufferReadPos++;
       rv=GWEN_XmlCtx_EndTag(ctx, 1);
       if (rv) {
-	return rv;
+        return rv;
       }
       /* tag finished */
       return 0;
@@ -597,99 +934,115 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
     for (;;) {
       GWEN_FASTBUFFER_READBYTE(fb, chr);
       if (chr<0) {
-	GWEN_Buffer_free(nbuf);
-	return chr;
+        GWEN_Buffer_free(nbuf);
+        return chr;
       }
       uc=(unsigned char) chr;
       if (uc>32)
-	break;
+        break;
     }
 
     /* read attribute name */
     for (;;) {
       if (uc=='/' || uc=='!' || uc=='?' || uc=='=' || uc=='>')
-	break;
+        break;
       GWEN_Buffer_AppendByte(nbuf, uc);
 
       GWEN_FASTBUFFER_READBYTE(fb, chr);
       if (chr<0) {
-	GWEN_Buffer_free(nbuf);
-	return chr;
+        GWEN_Buffer_free(nbuf);
+        return chr;
       }
       uc=(unsigned char) chr;
     }
 
     if (GWEN_Buffer_GetUsedBytes(nbuf)) {
       if (uc=='=') {
-	/* read attribute value if there is an equation mark */
-	int inQuote=0;
-  
-	vbuf=GWEN_Buffer_new(0, 256, 0, 1);
-	for (;;) {
-	  GWEN_FASTBUFFER_READBYTE(fb, chr);
-	  if (chr<0) {
-	    GWEN_Buffer_free(nbuf);
-	    return chr;
-	  }
-	  uc=(unsigned char) chr;
-	  if (uc=='"') {
-	    if (inQuote) {
-	      inQuote=0;
-	      break;
-	    }
-	    else
-	      inQuote=1;
-	  }
-	  else {
-	    if (!inQuote) {
-	      if (uc=='>' || uc<33)
-		break;
-	      else if (uc=='<') {
-		DBG_ERROR(GWEN_LOGDOMAIN,
-			  "Nested element definitions");
-		GWEN_Buffer_free(vbuf);
-		GWEN_Buffer_free(nbuf);
-		return GWEN_ERROR_BAD_DATA;
-	      }
-	      else if (GWEN_Buffer_GetUsedBytes(dbuf)) {
-		if (uc=='/' || uc=='!' || uc=='?') {
-		  unsigned char tc;
+        /* read attribute value if there is an equation mark */
+        int inQuote=0;
+        uint32_t len;
 
-		  GWEN_FASTBUFFER_PEEKBYTE(fb, chr);
-		  if (chr<0) {
-		    GWEN_Buffer_free(vbuf);
-		    GWEN_Buffer_free(nbuf);
-		    return chr;
-		  }
-		  tc=(unsigned char) chr;
-		  if (tc=='>') {
-		    break;
-		  }
-		}
-	      }
-	    }
-	    GWEN_Buffer_AppendByte(vbuf, uc);
-	  }
-	}
-	if (inQuote) {
-	  DBG_ERROR(GWEN_LOGDOMAIN, "No matching number of quote chars");
-	  GWEN_Buffer_free(vbuf);
-	  GWEN_Buffer_free(nbuf);
-	  return GWEN_ERROR_BAD_DATA;
-	}
+        vbuf=GWEN_Buffer_new(0, 256, 0, 1);
+        for (;;) {
+          GWEN_FASTBUFFER_READBYTE(fb, chr);
+          if (chr<0) {
+            GWEN_Buffer_free(nbuf);
+            return chr;
+          }
+          uc=(unsigned char) chr;
+          if (uc=='"') {
+            if (inQuote) {
+              inQuote=0;
+              break;
+            }
+            else
+              inQuote=1;
+          }
+          else {
+            if (!inQuote) {
+              if (uc=='>' || uc<33)
+                break;
+              else if (uc=='<') {
+                DBG_ERROR(GWEN_LOGDOMAIN,
+                          "Nested element definitions");
+                GWEN_Buffer_free(vbuf);
+                GWEN_Buffer_free(nbuf);
+                return GWEN_ERROR_BAD_DATA;
+              }
+              else if (GWEN_Buffer_GetUsedBytes(dbuf)) {
+                if (uc=='/' || uc=='!' || uc=='?') {
+                  unsigned char tc;
 
-	if (GWEN_Buffer_GetUsedBytes(vbuf)==0) {
-	  GWEN_Buffer_free(vbuf);
-	  vbuf=NULL;
-	}
+                  GWEN_FASTBUFFER_PEEKBYTE(fb, chr);
+                  if (chr<0) {
+                    GWEN_Buffer_free(vbuf);
+                    GWEN_Buffer_free(nbuf);
+                    return chr;
+                  }
+                  tc=(unsigned char) chr;
+                  if (tc=='>') {
+                    break;
+                  }
+                }
+              }
+            }
+            GWEN_Buffer_AppendByte(vbuf, uc);
+          }
+        }
+        if (inQuote) {
+          DBG_ERROR(GWEN_LOGDOMAIN, "No matching number of quote chars");
+          GWEN_Buffer_free(vbuf);
+          GWEN_Buffer_free(nbuf);
+          return GWEN_ERROR_BAD_DATA;
+        }
+
+        len=GWEN_Buffer_GetUsedBytes(vbuf);
+        if (len==0) {
+          GWEN_Buffer_free(vbuf);
+          vbuf=NULL;
+        }
+        else {
+          char *s;
+
+          s=strdup(GWEN_Buffer_GetStart(vbuf));
+          GWEN_Buffer_Reset(vbuf);
+          rv=GWEN_Text_ConvertCharset(GWEN_XmlCtx_GetEncoding(ctx), "UTF-8",
+                                      s, len, vbuf);
+          free(s);
+          if (rv) {
+            GWEN_Buffer_free(vbuf);
+            GWEN_Buffer_free(nbuf);
+            return rv;
+          }
+        }
       }
       rv=GWEN_XmlCtx_AddAttr(ctx,
-			     GWEN_Buffer_GetStart(nbuf),
-			     vbuf?GWEN_Buffer_GetStart(vbuf):NULL);
+                             GWEN_Buffer_GetStart(nbuf),
+                             vbuf?GWEN_Buffer_GetStart(vbuf):NULL);
       if (rv) {
-	GWEN_Buffer_free(vbuf);
-	GWEN_Buffer_free(nbuf);
-	return rv;
+        GWEN_Buffer_free(vbuf);
+        GWEN_Buffer_free(nbuf);
+        return rv;
       }
     }
 
@@ -713,16 +1066,16 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
       fb->bufferReadPos++;
       rv=GWEN_XmlCtx_EndTag(ctx, 1);
       if (rv) {
-	return rv;
+        return rv;
       }
       /* tag finished */
       return 0;
     }
     else {
       DBG_ERROR(GWEN_LOGDOMAIN,
-		"Got an unexpected character here (after %02x[%c]): %02x[%c], "
-		"maybe the text contains unescaped XML characters?",
-		ucsave, ucsave, uc, uc);
+                "Got an unexpected character here (after %02x[%c]): %02x[%c], "
+                "maybe the text contains unescaped XML characters?",
+                ucsave, ucsave, uc, uc);
     }
   }
   else if (uc=='>') {
@@ -735,14 +1088,15 @@ int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
   }
 
   DBG_ERROR(GWEN_LOGDOMAIN,
-	    "Internal error: Should never reach this point");
+            "Internal error: Should never reach this point");
   return GWEN_ERROR_INTERNAL;
 }
 
 
 
 
-int GWEN_XML_ReadFromFastBuffer(GWEN_XML_CONTEXT *ctx, GWEN_FAST_BUFFER *fb){
+int GWEN_XML_ReadFromFastBuffer(GWEN_XML_CONTEXT *ctx, GWEN_FAST_BUFFER *fb)
+{
   int oks=0;
   int startingDepth;
   GWEN_BUFFER *workBuf;
@@ -760,7 +1114,7 @@ int GWEN_XML_ReadFromFastBuffer(GWEN_XML_CONTEXT *ctx, GWEN_FAST_BUFFER *fb){
         DBG_DEBUG(GWEN_LOGDOMAIN, "here (%d), after reading %d bytes",
                   rv, (int) GWEN_FastBuffer_GetBytesRead(fb));
         GWEN_Buffer_free(workBuf);
-	return rv;
+        return rv;
       }
       GWEN_Buffer_free(workBuf);
       return 0;
@@ -777,10 +1131,11 @@ int GWEN_XML_ReadFromFastBuffer(GWEN_XML_CONTEXT *ctx, GWEN_FAST_BUFFER *fb){
     GWEN_FASTBUFFER_PEEKBYTE(fb, rv);
     if (rv<0) {
       if (rv!=GWEN_ERROR_EOF || !oks ||
-	  (GWEN_XmlCtx_GetDepth(ctx)!=startingDepth)) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          (GWEN_XmlCtx_GetDepth(ctx)!=startingDepth)) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (rv=%d, oks=%d, depth=%d, startingDepth=%d)",
+                 rv, oks, GWEN_XmlCtx_GetDepth(ctx), startingDepth);
         GWEN_Buffer_free(workBuf);
-	return rv;
+        return rv;
       }
       GWEN_Buffer_free(workBuf);
       return 0;
@@ -789,23 +1144,25 @@ int GWEN_XML_ReadFromFastBuffer(GWEN_XML_CONTEXT *ctx, GWEN_FAST_BUFFER *fb){
       fb->bufferReadPos++;
       rv=GWEN_XML__ReadTag(ctx, fb, GWEN_XmlCtx_GetFlags(ctx), workBuf);
       if (rv) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
         GWEN_Buffer_free(workBuf);
-	return rv;
+        return rv;
       }
       GWEN_Buffer_Reset(workBuf);
       oks=1;
     }
 
     if (GWEN_XmlCtx_GetFinishedElement(ctx) &&
-	GWEN_XmlCtx_GetDepth(ctx)==startingDepth)
+        GWEN_XmlCtx_GetDepth(ctx)==startingDepth) {
+      DBG_INFO(GWEN_LOGDOMAIN, "Finished element at depth %d", GWEN_XmlCtx_GetDepth(ctx));
       break;
+    }
   }
 
   if (GWEN_XmlCtx_GetDepth(ctx)!=startingDepth) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Not on same level where we started...(%d!=%d)",
-	      GWEN_XmlCtx_GetDepth(ctx), startingDepth);
+              "Not on same level where we started...(%d!=%d)",
+              GWEN_XmlCtx_GetDepth(ctx), startingDepth);
   }
   GWEN_Buffer_free(workBuf);
 
@@ -814,7 +1171,8 @@ int GWEN_XML_ReadFromFastBuffer(GWEN_XML_CONTEXT *ctx, GWEN_FAST_BUFFER *fb){
 
 
 
-int GWEN_XML__ReadAllFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio){
+int GWEN_XML__ReadAllFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio)
+{
   GWEN_FAST_BUFFER *fb;
   int oks=0;
 
@@ -826,11 +1184,11 @@ int GWEN_XML__ReadAllFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio){
     rv=GWEN_XML_ReadFromFastBuffer(ctx, fb);
     if (rv<0) {
       if (rv==GWEN_ERROR_EOF && oks)
-	break;
+        break;
       else {
-	DBG_INFO(GWEN_LOGDOMAIN, "here");
-	GWEN_FastBuffer_free(fb);
-	return rv;
+        DBG_INFO(GWEN_LOGDOMAIN, "here (rv=%d, oks=%d)", rv, oks);
+        GWEN_FastBuffer_free(fb);
+        return rv;
       }
     }
     oks=1;
@@ -842,7 +1200,8 @@ int GWEN_XML__ReadAllFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio){
 
 
 
-int GWEN_XMLContext_ReadFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio){
+int GWEN_XMLContext_ReadFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio)
+{
 #if 0
   GWEN_FAST_BUFFER *fb;
   int rv;
@@ -873,7 +1232,8 @@ int GWEN_XMLContext_ReadFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio){
 
 
 
-int GWEN_XMLContext_ReadFromFile(GWEN_XML_CONTEXT *ctx, const char *fname) {
+int GWEN_XMLContext_ReadFromFile(GWEN_XML_CONTEXT *ctx, const char *fname)
+{
   GWEN_SYNCIO *sio;
   int rv;
 
@@ -902,7 +1262,8 @@ int GWEN_XMLContext_ReadFromFile(GWEN_XML_CONTEXT *ctx, const char *fname) {
 
 
 
-int GWEN_XMLContext_ReadFromString(GWEN_XML_CONTEXT *ctx, const char *text) {
+int GWEN_XMLContext_ReadFromString(GWEN_XML_CONTEXT *ctx, const char *text)
+{
   if (text && *text) {
     GWEN_SYNCIO *sio;
     int rv;
@@ -910,7 +1271,7 @@ int GWEN_XMLContext_ReadFromString(GWEN_XML_CONTEXT *ctx, const char *text) {
     int i;
 
     i=strlen(text)+1;
-    tbuf=GWEN_Buffer_new((char*)text, i, i, 0);
+    tbuf=GWEN_Buffer_new((char *)text, i, i, 0);
     /* static buffer, don't resize */
     GWEN_Buffer_SubMode(tbuf, GWEN_BUFFER_MODE_DYNAMIC);
     GWEN_Buffer_AddMode(tbuf, GWEN_BUFFER_MODE_READONLY);
@@ -933,7 +1294,8 @@ int GWEN_XMLContext_ReadFromString(GWEN_XML_CONTEXT *ctx, const char *text) {
 
 
 
-int GWEN_XML_ReadFile(GWEN_XMLNODE *n, const char *filepath, uint32_t flags) {
+int GWEN_XML_ReadFile(GWEN_XMLNODE *n, const char *filepath, uint32_t flags)
+{
   GWEN_XML_CONTEXT *ctx;
   GWEN_SYNCIO *sio;
   int rv;
@@ -967,7 +1329,8 @@ int GWEN_XML_ReadFile(GWEN_XMLNODE *n, const char *filepath, uint32_t flags) {
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_fromString(const char *s, int len, uint32_t flags) {
+GWEN_XMLNODE *GWEN_XMLNode_fromString(const char *s, int len, uint32_t flags)
+{
 #if 0
   GWEN_XML_CONTEXT *ctx;
   GWEN_SYNCIO *sio;
@@ -976,7 +1339,7 @@ GWEN_XMLNODE *GWEN_XMLNode_fromString(const char *s, int len, uint32_t flags) {
 
   if (len==0)
     len=strlen(s);
-  sio=GWEN_SyncIo_Memory_fromBuffer((const uint8_t*)s, len);
+  sio=GWEN_SyncIo_Memory_fromBuffer((const uint8_t *)s, len);
 
   n=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "doc");
   ctx=GWEN_XmlCtxStore_new(n, flags);
@@ -1001,7 +1364,7 @@ GWEN_XMLNODE *GWEN_XMLNode_fromString(const char *s, int len, uint32_t flags) {
   int rv;
   GWEN_BUFFER *tbuf;
 
-  tbuf=GWEN_Buffer_new((char*)s, len, len, 0);
+  tbuf=GWEN_Buffer_new((char *)s, len, len, 0);
   /* static buffer, don't resize */
   GWEN_Buffer_SubMode(tbuf, GWEN_BUFFER_MODE_DYNAMIC);
   GWEN_Buffer_AddMode(tbuf, GWEN_BUFFER_MODE_READONLY);
