@@ -47,7 +47,8 @@
 
 
 
-GWEN_SAR *GWEN_Sar_new(void) {
+GWEN_SAR *GWEN_Sar_new(void)
+{
   GWEN_SAR *sr;
 
   GWEN_NEW_OBJECT(GWEN_SAR, sr);
@@ -60,7 +61,8 @@ GWEN_SAR *GWEN_Sar_new(void) {
 
 
 
-void GWEN_Sar_Attach(GWEN_SAR *sr) {
+void GWEN_Sar_Attach(GWEN_SAR *sr)
+{
   assert(sr);
   assert(sr->refCount);
   sr->refCount++;
@@ -68,7 +70,8 @@ void GWEN_Sar_Attach(GWEN_SAR *sr) {
 
 
 
-void GWEN_Sar_free(GWEN_SAR *sr) {
+void GWEN_Sar_free(GWEN_SAR *sr)
+{
   if (sr) {
     assert(sr->refCount);
     if (sr->refCount==1) {
@@ -86,7 +89,8 @@ void GWEN_Sar_free(GWEN_SAR *sr) {
 
 
 
-int GWEN_Sar_CreateArchive(GWEN_SAR *sr, const char *aname) {
+int GWEN_Sar_CreateArchive(GWEN_SAR *sr, const char *aname)
+{
   GWEN_SYNCIO *sio;
   int rv;
 
@@ -129,7 +133,8 @@ int GWEN_Sar_CreateArchive(GWEN_SAR *sr, const char *aname) {
 
 int GWEN_Sar_OpenArchive(GWEN_SAR *sr, const char *aname,
                          GWEN_SYNCIO_FILE_CREATIONMODE cm,
-                         uint32_t acc) {
+                         uint32_t acc)
+{
   GWEN_SYNCIO *sio;
   int rv;
 
@@ -173,7 +178,8 @@ int GWEN_Sar_OpenArchive(GWEN_SAR *sr, const char *aname,
 
 
 
-int GWEN_Sar_CloseArchive(GWEN_SAR *sr, int abandon) {
+int GWEN_Sar_CloseArchive(GWEN_SAR *sr, int abandon)
+{
   int rv;
 
   assert(sr);
@@ -222,7 +228,8 @@ int GWEN_Sar_CloseArchive(GWEN_SAR *sr, int abandon) {
 
 
 
-int GWEN_Sar_FileHeaderToTlv(const GWEN_SAR_FILEHEADER *fh, GWEN_BUFFER *tbuf) {
+int GWEN_Sar_FileHeaderToTlv(const GWEN_SAR_FILEHEADER *fh, GWEN_BUFFER *tbuf)
+{
   const char *s;
   uint16_t v8;
   uint32_t v32;
@@ -335,10 +342,11 @@ int GWEN_Sar_FileHeaderToTlv(const GWEN_SAR_FILEHEADER *fh, GWEN_BUFFER *tbuf) {
 
 
 
-uint64_t GWEN_Sar_ReadUint64(const uint8_t *p, uint32_t bs) {
+uint64_t GWEN_Sar_ReadUint64(const uint8_t *p, uint32_t bs)
+{
   uint64_t v=0;
 
-  switch(bs) {
+  switch (bs) {
   case 8:
     v=(((uint64_t)(p[0]))<<56)+
       (((uint64_t)(p[1]))<<48)+
@@ -402,8 +410,9 @@ uint64_t GWEN_Sar_ReadUint64(const uint8_t *p, uint32_t bs) {
 
 
 
-int GWEN_Sar_TlvToFileHeader(GWEN_BUFFER *mbuf, GWEN_SAR_FILEHEADER *fh) {
-  while(GWEN_Buffer_GetBytesLeft(mbuf)) {
+int GWEN_Sar_TlvToFileHeader(GWEN_BUFFER *mbuf, GWEN_SAR_FILEHEADER *fh)
+{
+  while (GWEN_Buffer_GetBytesLeft(mbuf)) {
     GWEN_TLV *tlv;
 
     tlv=GWEN_TLV_fromBuffer(mbuf, 1);
@@ -415,10 +424,10 @@ int GWEN_Sar_TlvToFileHeader(GWEN_BUFFER *mbuf, GWEN_SAR_FILEHEADER *fh) {
 
       p=GWEN_TLV_GetTagData(tlv);
       bs=GWEN_TLV_GetTagLength(tlv);
-      switch(GWEN_TLV_GetTagType(tlv)) {
+      switch (GWEN_TLV_GetTagType(tlv)) {
       case GWEN_SAR_TAG_HEADER_VERSION:
         v=GWEN_Sar_ReadUint64(p, bs);
-        DBG_DEBUG(GWEN_LOGDOMAIN, "File Header Version: %08x", (unsigned int) (v & 0xffffffff));
+        DBG_DEBUG(GWEN_LOGDOMAIN, "File Header Version: %08x", (unsigned int)(v & 0xffffffff));
         break;
 
       case GWEN_SAR_TAG_HEADER_STATUS:
@@ -432,7 +441,7 @@ int GWEN_Sar_TlvToFileHeader(GWEN_BUFFER *mbuf, GWEN_SAR_FILEHEADER *fh) {
         break;
 
       case GWEN_SAR_TAG_HEADER_PATH:
-        GWEN_SarFileHeader_SetPath(fh, (const char*)p);
+        GWEN_SarFileHeader_SetPath(fh, (const char *)p);
         break;
 
       case GWEN_SAR_TAG_HEADER_TYPE:
@@ -446,17 +455,17 @@ int GWEN_Sar_TlvToFileHeader(GWEN_BUFFER *mbuf, GWEN_SAR_FILEHEADER *fh) {
         break;
 
       case GWEN_SAR_TAG_HEADER_ATIME:
-        ti=GWEN_Time_fromUtcString((const char*) p, "YYYYMMDDhhmmss");
+        ti=GWEN_Time_fromUtcString((const char *) p, "YYYYMMDDhhmmss");
         GWEN_SarFileHeader_SetAtime(fh, ti);
         break;
 
       case GWEN_SAR_TAG_HEADER_MTIME:
-        ti=GWEN_Time_fromUtcString((const char*) p, "YYYYMMDDhhmmss");
+        ti=GWEN_Time_fromUtcString((const char *) p, "YYYYMMDDhhmmss");
         GWEN_SarFileHeader_SetMtime(fh, ti);
         break;
 
       case GWEN_SAR_TAG_HEADER_CTIME:
-        ti=GWEN_Time_fromUtcString((const char*) p, "YYYYMMDDhhmmss");
+        ti=GWEN_Time_fromUtcString((const char *) p, "YYYYMMDDhhmmss");
         GWEN_SarFileHeader_SetCtime(fh, ti);
         break;
 
@@ -480,7 +489,8 @@ int GWEN_Sar_TlvToFileHeader(GWEN_BUFFER *mbuf, GWEN_SAR_FILEHEADER *fh) {
 
 
 
-int GWEN_Sar_AddAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GWEN_MDIGEST *md) {
+int GWEN_Sar_AddAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GWEN_MDIGEST *md)
+{
   int rv;
   const char *fname;
   uint64_t fsize;
@@ -505,7 +515,7 @@ int GWEN_Sar_AddAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GW
 
   /* write TLV header */
   rv=GWEN_SyncIo_WriteForced(sr->archiveSio,
-                             (const uint8_t*) GWEN_Buffer_GetStart(hbuf),
+                             (const uint8_t *) GWEN_Buffer_GetStart(hbuf),
                              GWEN_Buffer_GetUsedBytes(hbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -539,7 +549,7 @@ int GWEN_Sar_AddAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GW
                                fsize,
                                0);
     bytesDone=0;
-    while(fsize) {
+    while (fsize) {
       uint8_t fbuf[10240];
       uint64_t bs;
 
@@ -613,8 +623,10 @@ int GWEN_Sar_AddAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GW
 
 
 
-int GWEN_Sar_AddAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GWEN_MDIGEST *md) {
-#if _BSD_SOURCE || _XOPEN_SOURCE >= 500 || (_XOPEN_SOURCE && _XOPEN_SOURCE_EXTENDED) || _POSIX_C_SOURCE >= 200112L || defined(OS_DARWIN)
+int GWEN_Sar_AddAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GWEN_MDIGEST *md)
+{
+#if ((_BSD_SOURCE || _XOPEN_SOURCE >= 500 || (_XOPEN_SOURCE && _XOPEN_SOURCE_EXTENDED) || _POSIX_C_SOURCE >= 200112L) && !defined(__MINGW32__)) || defined(OS_DARWIN)
+
   int rv;
   const char *fname;
   GWEN_BUFFER *hbuf;
@@ -646,7 +658,7 @@ int GWEN_Sar_AddAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, G
 
   /* write TLV */
   rv=GWEN_SyncIo_WriteForced(sr->archiveSio,
-                             (const uint8_t*) GWEN_Buffer_GetStart(hbuf),
+                             (const uint8_t *) GWEN_Buffer_GetStart(hbuf),
                              GWEN_Buffer_GetUsedBytes(hbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -656,7 +668,7 @@ int GWEN_Sar_AddAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, G
   GWEN_Buffer_free(hbuf);
 
   /* digest data */
-  rv=GWEN_MDigest_Update(md, (const uint8_t*) lbuf, len+1);
+  rv=GWEN_MDigest_Update(md, (const uint8_t *) lbuf, len+1);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     return rv;
@@ -664,7 +676,7 @@ int GWEN_Sar_AddAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, G
 
   return 0;
 #else
-# warning "Function readlink() is not available"
+  /*# warning "Function readlink() is not available"*/
   DBG_ERROR(GWEN_LOGDOMAIN, "Function readlink() is not available");
   return GWEN_ERROR_IO;
 #endif
@@ -672,10 +684,11 @@ int GWEN_Sar_AddAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, G
 
 
 
-int GWEN_Sar_AddAndDigestFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GWEN_MDIGEST *md) {
+int GWEN_Sar_AddAndDigestFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GWEN_MDIGEST *md)
+{
   int rv;
 
-  switch(GWEN_SarFileHeader_GetFileType(fh)) {
+  switch (GWEN_SarFileHeader_GetFileType(fh)) {
   case GWEN_SarFileHeader_FType_File:
     rv=GWEN_Sar_AddAndDigestFileReg(sr, fh, md);
     break;
@@ -700,7 +713,8 @@ int GWEN_Sar_AddAndDigestFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, GWEN_
 
 
 
-int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
+int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname)
+{
   struct stat st;
   int rv;
   GWEN_SAR_FILEHEADER *fh;
@@ -708,7 +722,7 @@ int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
   GWEN_BUFFER *hbuf;
   GWEN_BUFFER *xbuf;
   GWEN_MDIGEST *md;
-  uint64_t pos;
+  int64_t pos;
 
   assert(sr);
   assert(sr->refCount);
@@ -732,7 +746,7 @@ int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
   GWEN_SarFileHeader_SetPath(fh, fname);
 
   /* file type */
-  switch(st.st_mode & S_IFMT) {
+  switch (st.st_mode & S_IFMT) {
 #ifdef S_IFLNK
   case S_IFLNK:
     GWEN_SarFileHeader_SetFileType(fh, GWEN_SarFileHeader_FType_SymLink);
@@ -750,28 +764,37 @@ int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
   }
 
   /* permissions */
-  if (st.st_mode & S_IRUSR) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_UREAD);
-  if (st.st_mode & S_IWUSR) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_UWRITE);
-  if (st.st_mode & S_IXUSR) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_UEXEC);
+  if (st.st_mode & S_IRUSR)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_UREAD);
+  if (st.st_mode & S_IWUSR)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_UWRITE);
+  if (st.st_mode & S_IXUSR)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_UEXEC);
 
 #ifdef S_IRGRP
-  if (st.st_mode & S_IRGRP) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_GREAD);
+  if (st.st_mode & S_IRGRP)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_GREAD);
 #endif
 #ifdef S_IWGRP
-  if (st.st_mode & S_IWGRP) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_GWRITE);
+  if (st.st_mode & S_IWGRP)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_GWRITE);
 #endif
 #ifdef S_IXGRP
-  if (st.st_mode & S_IXGRP) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_GEXEC);
+  if (st.st_mode & S_IXGRP)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_GEXEC);
 #endif
 
 #ifdef S_IROTH
-  if (st.st_mode & S_IROTH) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_OREAD);
+  if (st.st_mode & S_IROTH)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_OREAD);
 #endif
 #ifdef S_IWOTH
-  if (st.st_mode & S_IWOTH) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_OWRITE);
+  if (st.st_mode & S_IWOTH)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_OWRITE);
 #endif
 #ifdef S_IXOTH
-  if (st.st_mode & S_IXOTH) GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_OEXEC);
+  if (st.st_mode & S_IXOTH)
+    GWEN_SarFileHeader_AddPermissions(fh, GWEN_SYNCIO_FILE_FLAGS_OEXEC);
 #endif
 
   /* atime */
@@ -832,7 +855,7 @@ int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
 
   /* write header into archive file */
   rv=GWEN_SyncIo_WriteForced(sr->archiveSio,
-                             (const uint8_t*) GWEN_Buffer_GetStart(hbuf),
+                             (const uint8_t *) GWEN_Buffer_GetStart(hbuf),
                              GWEN_Buffer_GetUsedBytes(hbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -853,7 +876,7 @@ int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
   }
 
   /* digest header */
-  rv=GWEN_MDigest_Update(md, (const uint8_t*) GWEN_Buffer_GetStart(hbuf), GWEN_Buffer_GetUsedBytes(hbuf));
+  rv=GWEN_MDigest_Update(md, (const uint8_t *) GWEN_Buffer_GetStart(hbuf), GWEN_Buffer_GetUsedBytes(hbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_MDigest_free(md);
@@ -893,7 +916,7 @@ int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
 
   /* write hash into archive file */
   rv=GWEN_SyncIo_WriteForced(sr->archiveSio,
-                             (const uint8_t*) GWEN_Buffer_GetStart(hbuf),
+                             (const uint8_t *) GWEN_Buffer_GetStart(hbuf),
                              GWEN_Buffer_GetUsedBytes(hbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -911,7 +934,8 @@ int GWEN_Sar_AddFile(GWEN_SAR *sr, const char *fname) {
 
 
 
-int GWEN_Sar_ScanFile(GWEN_SAR *sr) {
+int GWEN_Sar_ScanFile(GWEN_SAR *sr)
+{
   int rv;
   int64_t pos;
   GWEN_BUFFER *mbuf;
@@ -984,7 +1008,7 @@ int GWEN_Sar_ScanFile(GWEN_SAR *sr) {
       GWEN_Buffer_AllocRoom(mbuf, tagLength);
 
       /* read header data */
-      rv=GWEN_SyncIo_ReadForced(sr->archiveSio, (uint8_t*) GWEN_Buffer_GetStart(mbuf), tagLength);
+      rv=GWEN_SyncIo_ReadForced(sr->archiveSio, (uint8_t *) GWEN_Buffer_GetStart(mbuf), tagLength);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
         GWEN_Buffer_free(mbuf);
@@ -1093,7 +1117,8 @@ int GWEN_Sar_ScanFile(GWEN_SAR *sr) {
 
 
 
-int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly) {
+int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly)
+{
   int rv;
   const char *fname;
   uint32_t perms;
@@ -1103,7 +1128,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
   uint64_t hsize;
   uint64_t hpos;
   uint64_t mpos;
-  uint64_t pos;
+  int64_t pos;
   GWEN_MDIGEST *md;
 
   assert(sr);
@@ -1138,7 +1163,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
 
     mbuf=GWEN_Buffer_new(0, hsize, 0, 1);
     rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-                              (uint8_t*) GWEN_Buffer_GetStart(mbuf),
+                              (uint8_t *) GWEN_Buffer_GetStart(mbuf),
                               hsize);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -1150,7 +1175,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
     GWEN_Buffer_AdjustUsedBytes(mbuf);
 
     /* digest TLV */
-    rv=GWEN_MDigest_Update(md, (const uint8_t*) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
+    rv=GWEN_MDigest_Update(md, (const uint8_t *) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(mbuf);
@@ -1191,7 +1216,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
         GWEN_MDigest_free(md);
         return (int) pos;
       }
-  
+
       /* start extracting */
       pid=GWEN_Gui_ProgressStart(GWEN_GUI_PROGRESS_DELAY |
                                  GWEN_GUI_PROGRESS_SHOW_ABORT |
@@ -1202,14 +1227,14 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
                                  fsize,
                                  0);
       bytesDone=0;
-      while(fsize) {
+      while (fsize) {
         uint8_t fbuf[10240];
         uint64_t bs;
-  
+
         bs=fsize;
         if (bs>sizeof(fbuf))
           bs=sizeof(fbuf);
-  
+
         /* read from input */
         rv=GWEN_SyncIo_Read(sr->archiveSio, fbuf, bs);
         if (rv<0) {
@@ -1223,7 +1248,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
           return rv;
         }
         bs=rv;
-  
+
         /* digest data */
         rv=GWEN_MDigest_Update(md, fbuf, bs);
         if (rv<0) {
@@ -1236,7 +1261,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
           GWEN_MDigest_free(md);
           return rv;
         }
-  
+
         if (!checkOnly) {
           /* write to archive */
           rv=GWEN_SyncIo_WriteForced(sio, fbuf, bs);
@@ -1251,7 +1276,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
             return rv;
           }
         }
-  
+
         if (bs>fsize) {
           DBG_ERROR(GWEN_LOGDOMAIN, "Internal error: bs>fsize (%lu>%lu)",
                     (unsigned long int)bs, (unsigned long int) fsize);
@@ -1263,10 +1288,10 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
           GWEN_MDigest_free(md);
           return rv;
         }
-  
+
         bytesDone+=bs;
         fsize-=bs;
-  
+
         /* advance progress bar */
         rv=GWEN_Gui_ProgressAdvance(pid, bytesDone);
         if (rv<0) {
@@ -1279,7 +1304,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
           GWEN_MDigest_free(md);
           return rv;
         }
-  
+
       } /* while */
       GWEN_Gui_ProgressEnd(pid);
     }
@@ -1302,7 +1327,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
     mpos=GWEN_SarFileHeader_GetHashPos(fh);
     if (mpos) {
       GWEN_BUFFER *mbuf;
-  
+
       /* seek to end of file */
       pos=GWEN_SyncIo_File_Seek(sr->archiveSio, mpos, GWEN_SyncIo_File_Whence_Set);
       if (pos<0) {
@@ -1314,7 +1339,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
       /* read 20 bytes of hash */
       mbuf=GWEN_Buffer_new(0, 20, 0, 1);
       rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-                                (uint8_t*) GWEN_Buffer_GetStart(mbuf),
+                                (uint8_t *) GWEN_Buffer_GetStart(mbuf),
                                 20);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -1330,7 +1355,7 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
                  20)!=0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
         DBG_ERROR(0, "Hash don't match:");
-        GWEN_Text_LogString((const char*) GWEN_MDigest_GetDigestPtr(md), 20,
+        GWEN_Text_LogString((const char *) GWEN_MDigest_GetDigestPtr(md), 20,
                             GWEN_LOGDOMAIN, GWEN_LoggerLevel_Error);
 
         GWEN_Text_LogString(GWEN_Buffer_GetStart(mbuf), 20,
@@ -1351,8 +1376,9 @@ int GWEN_Sar_ExtractAndDigestFileReg(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
 
 
 
-int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly) {
-#if _BSD_SOURCE || _XOPEN_SOURCE >= 500 || (_XOPEN_SOURCE && _XOPEN_SOURCE_EXTENDED) || _POSIX_C_SOURCE >= 200112L || defined(OS_DARWIN)
+int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly)
+{
+#if ((_BSD_SOURCE || _XOPEN_SOURCE >= 500 || (_XOPEN_SOURCE && _XOPEN_SOURCE_EXTENDED) || _POSIX_C_SOURCE >= 200112L) && !defined(__MINGW32__)) || defined(OS_DARWIN)
   int rv;
   const char *fname;
   uint32_t perms;
@@ -1361,7 +1387,7 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
   uint64_t hsize;
   uint64_t hpos;
   uint64_t mpos;
-  uint64_t pos;
+  int64_t pos;
   GWEN_MDIGEST *md;
 
   assert(sr);
@@ -1396,7 +1422,7 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
 
     mbuf=GWEN_Buffer_new(0, hsize, 0, 1);
     rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-                              (uint8_t*) GWEN_Buffer_GetStart(mbuf),
+                              (uint8_t *) GWEN_Buffer_GetStart(mbuf),
                               hsize);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -1408,7 +1434,7 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
     GWEN_Buffer_AdjustUsedBytes(mbuf);
 
     /* digest header TLV */
-    rv=GWEN_MDigest_Update(md, (const uint8_t*) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
+    rv=GWEN_MDigest_Update(md, (const uint8_t *) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(mbuf);
@@ -1432,7 +1458,7 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
 
     mbuf=GWEN_Buffer_new(0, fsize, 0, 1);
     rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-                              (uint8_t*) GWEN_Buffer_GetStart(mbuf),
+                              (uint8_t *) GWEN_Buffer_GetStart(mbuf),
                               fsize);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -1444,7 +1470,7 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
     GWEN_Buffer_AdjustUsedBytes(mbuf);
 
     /* digest TLV */
-    rv=GWEN_MDigest_Update(md, (const uint8_t*) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
+    rv=GWEN_MDigest_Update(md, (const uint8_t *) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(mbuf);
@@ -1475,24 +1501,30 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
 
       /* group perms */
 #ifdef S_IRGRP
-      if (perms & GWEN_SYNCIO_FILE_FLAGS_GREAD) mode|=S_IRGRP;
+      if (perms & GWEN_SYNCIO_FILE_FLAGS_GREAD)
+        mode|=S_IRGRP;
 #endif
 #ifdef S_IWGRP
-      if (perms & GWEN_SYNCIO_FILE_FLAGS_GWRITE) mode|=S_IWGRP;
+      if (perms & GWEN_SYNCIO_FILE_FLAGS_GWRITE)
+        mode|=S_IWGRP;
 #endif
 #ifdef S_IXGRP
-      if (perms & GWEN_SYNCIO_FILE_FLAGS_GEXEC) mode|=S_IXGRP;
+      if (perms & GWEN_SYNCIO_FILE_FLAGS_GEXEC)
+        mode|=S_IXGRP;
 #endif
 
       /* other perms */
 #ifdef S_IROTH
-      if (perms & GWEN_SYNCIO_FILE_FLAGS_OREAD) mode|=S_IROTH;
+      if (perms & GWEN_SYNCIO_FILE_FLAGS_OREAD)
+        mode|=S_IROTH;
 #endif
 #ifdef S_IWOTH
-      if (perms & GWEN_SYNCIO_FILE_FLAGS_OWRITE) mode|=S_IWOTH;
+      if (perms & GWEN_SYNCIO_FILE_FLAGS_OWRITE)
+        mode|=S_IWOTH;
 #endif
 #ifdef S_IXOTH
-      if (perms & GWEN_SYNCIO_FILE_FLAGS_OEXEC) mode|=S_IXOTH;
+      if (perms & GWEN_SYNCIO_FILE_FLAGS_OEXEC)
+        mode|=S_IXOTH;
 #endif
 
       rv=chmod(fname, mode);
@@ -1530,7 +1562,7 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
     /* read 20 bytes of hash */
     mbuf=GWEN_Buffer_new(0, 20, 0, 1);
     rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-                              (uint8_t*) GWEN_Buffer_GetStart(mbuf),
+                              (uint8_t *) GWEN_Buffer_GetStart(mbuf),
                               20);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -1561,7 +1593,7 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
 
   return 0;
 #else
-# warning "Function symlink() is not available"
+  /*# warning "Function symlink() is not available"*/
   DBG_ERROR(GWEN_LOGDOMAIN, "Function symlink() is not available");
   return GWEN_ERROR_IO;
 #endif
@@ -1569,15 +1601,16 @@ int GWEN_Sar_ExtractAndDigestFileLink(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *f
 
 
 
-int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly) {
+int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly)
+{
   int rv;
   const char *fname;
-  uint64_t dpos;
-  uint64_t fsize;
+  //uint64_t dpos;
+  //uint64_t fsize;
   uint64_t hsize;
   uint64_t hpos;
   uint64_t mpos;
-  uint64_t pos;
+  int64_t pos;
   GWEN_MDIGEST *md;
   GWEN_BUFFER *mbuf;
   uint32_t perms;
@@ -1596,8 +1629,8 @@ int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
   fname=GWEN_SarFileHeader_GetPath(fh);
   assert(fname);
   perms=GWEN_SarFileHeader_GetPermissions(fh);
-  fsize=GWEN_SarFileHeader_GetDataSize(fh); /* not FileSize!! */
-  dpos=GWEN_SarFileHeader_GetDataPos(fh);
+  //fsize=GWEN_SarFileHeader_GetDataSize(fh); /* not FileSize!! */
+  //dpos=GWEN_SarFileHeader_GetDataPos(fh);
 
   hpos=GWEN_SarFileHeader_GetHeaderStartPos(fh);
   hsize=GWEN_SarFileHeader_GetHeaderSize(fh);
@@ -1613,7 +1646,7 @@ int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
 
   mbuf=GWEN_Buffer_new(0, hsize, 0, 1);
   rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-                            (uint8_t*) GWEN_Buffer_GetStart(mbuf),
+                            (uint8_t *) GWEN_Buffer_GetStart(mbuf),
                             hsize);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -1625,7 +1658,7 @@ int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
   GWEN_Buffer_AdjustUsedBytes(mbuf);
 
   /* digest TLV */
-  rv=GWEN_MDigest_Update(md, (const uint8_t*) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
+  rv=GWEN_MDigest_Update(md, (const uint8_t *) GWEN_Buffer_GetStart(mbuf), GWEN_Buffer_GetUsedBytes(mbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_free(mbuf);
@@ -1658,7 +1691,7 @@ int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
     /* read 20 bytes of hash */
     mbuf=GWEN_Buffer_new(0, 20, 0, 1);
     rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-                              (uint8_t*) GWEN_Buffer_GetStart(mbuf),
+                              (uint8_t *) GWEN_Buffer_GetStart(mbuf),
                               20);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -1698,24 +1731,30 @@ int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
 
     /* group perms */
 #ifdef S_IRGRP
-    if (perms & GWEN_SYNCIO_FILE_FLAGS_GREAD) mode|=S_IRGRP;
+    if (perms & GWEN_SYNCIO_FILE_FLAGS_GREAD)
+      mode|=S_IRGRP;
 #endif
 #ifdef S_IWGRP
-    if (perms & GWEN_SYNCIO_FILE_FLAGS_GWRITE) mode|=S_IWGRP;
+    if (perms & GWEN_SYNCIO_FILE_FLAGS_GWRITE)
+      mode|=S_IWGRP;
 #endif
 #ifdef S_IXGRP
-    if (perms & GWEN_SYNCIO_FILE_FLAGS_GEXEC) mode|=S_IXGRP;
+    if (perms & GWEN_SYNCIO_FILE_FLAGS_GEXEC)
+      mode|=S_IXGRP;
 #endif
 
     /* other perms */
 #ifdef S_IROTH
-    if (perms & GWEN_SYNCIO_FILE_FLAGS_OREAD) mode|=S_IROTH;
+    if (perms & GWEN_SYNCIO_FILE_FLAGS_OREAD)
+      mode|=S_IROTH;
 #endif
 #ifdef S_IWOTH
-    if (perms & GWEN_SYNCIO_FILE_FLAGS_OWRITE) mode|=S_IWOTH;
+    if (perms & GWEN_SYNCIO_FILE_FLAGS_OWRITE)
+      mode|=S_IWOTH;
 #endif
 #ifdef S_IXOTH
-    if (perms & GWEN_SYNCIO_FILE_FLAGS_OEXEC) mode|=S_IXOTH;
+    if (perms & GWEN_SYNCIO_FILE_FLAGS_OEXEC)
+      mode|=S_IXOTH;
 #endif
 
     /* create folder */
@@ -1736,10 +1775,11 @@ int GWEN_Sar_ExtractAndDigestFileDir(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh
 
 
 
-int GWEN_Sar_ExtractAndDigestFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly) {
+int GWEN_Sar_ExtractAndDigestFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, int checkOnly)
+{
   int rv;
 
-  switch(GWEN_SarFileHeader_GetFileType(fh)) {
+  switch (GWEN_SarFileHeader_GetFileType(fh)) {
   case GWEN_SarFileHeader_FType_File:
     rv=GWEN_Sar_ExtractAndDigestFileReg(sr, fh, checkOnly);
     break;
@@ -1764,7 +1804,8 @@ int GWEN_Sar_ExtractAndDigestFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh, i
 
 
 
-int GWEN_Sar_ExtractFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh) {
+int GWEN_Sar_ExtractFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh)
+{
   int rv;
 
   rv=GWEN_Sar_ExtractAndDigestFile(sr, fh, 0);
@@ -1778,7 +1819,8 @@ int GWEN_Sar_ExtractFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh) {
 
 
 
-int GWEN_Sar_CheckFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh) {
+int GWEN_Sar_CheckFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh)
+{
   int rv;
 
   rv=GWEN_Sar_ExtractAndDigestFile(sr, fh, 1);
@@ -1792,7 +1834,8 @@ int GWEN_Sar_CheckFile(GWEN_SAR *sr, const GWEN_SAR_FILEHEADER *fh) {
 
 
 
-const GWEN_SAR_FILEHEADER_LIST *GWEN_Sar_GetHeaders(GWEN_SAR *sr) {
+const GWEN_SAR_FILEHEADER_LIST *GWEN_Sar_GetHeaders(GWEN_SAR *sr)
+{
   assert(sr);
   assert(sr->refCount);
   return sr->headers;
@@ -1800,7 +1843,8 @@ const GWEN_SAR_FILEHEADER_LIST *GWEN_Sar_GetHeaders(GWEN_SAR *sr) {
 
 
 
-int GWEN_Sar__UnpackArchive(const char *inFile, const char *where) {
+int GWEN_Sar__UnpackArchive(const char *inFile, const char *where)
+{
   GWEN_SAR *sr;
   int rv;
   const GWEN_SAR_FILEHEADER_LIST *fhl;
@@ -1838,16 +1882,16 @@ int GWEN_Sar__UnpackArchive(const char *inFile, const char *where) {
                                0);
 
     fh=GWEN_SarFileHeader_List_First(fhl);
-    while(fh) {
-      const char *s;
+    while (fh) {
+      //const char *s;
 
-      s=GWEN_SarFileHeader_GetPath(fh);
+      //s=GWEN_SarFileHeader_GetPath(fh);
       rv=GWEN_Sar_ExtractFile(sr, fh);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
         GWEN_Gui_ProgressEnd(pid);
-	GWEN_Sar_CloseArchive(sr, 1);
-	GWEN_Sar_free(sr);
+        GWEN_Sar_CloseArchive(sr, 1);
+        GWEN_Sar_free(sr);
       }
 
       rv=GWEN_Gui_ProgressAdvance(pid, GWEN_GUI_PROGRESS_ONE);
@@ -1875,7 +1919,8 @@ int GWEN_Sar__UnpackArchive(const char *inFile, const char *where) {
 
 
 
-int GWEN_Sar_UnpackArchive(const char *inFile, const char *where) {
+int GWEN_Sar_UnpackArchive(const char *inFile, const char *where)
+{
   char savedPwd[300];
   int rv;
 
@@ -1902,7 +1947,8 @@ int GWEN_Sar_UnpackArchive(const char *inFile, const char *where) {
 
 
 
-int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
+int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm)
+{
   int rv;
   GWEN_SAR_FILEHEADER_LIST *fhl;
 
@@ -1940,7 +1986,7 @@ int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
 
     /* clear SIGNED flags */
     fh=GWEN_SarFileHeader_List_First(fhl);
-    while(fh) {
+    while (fh) {
       GWEN_SarFileHeader_SubFlags(fh, GWEN_SAR_FILEHEADER_FLAGS_SIGNED);
       fh=GWEN_SarFileHeader_List_Next(fh);
     }
@@ -1951,56 +1997,56 @@ int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
                                GWEN_GUI_PROGRESS_ALLOW_EMBED |
                                GWEN_GUI_PROGRESS_SHOW_PROGRESS,
                                I18N("File Operation"),
-			       I18N("Signing archive file"),
-			       GWEN_SarFileHeader_List_GetCount(fhl),
-			       0);
+                               I18N("Signing archive file"),
+                               GWEN_SarFileHeader_List_GetCount(fhl),
+                               0);
     fh=GWEN_SarFileHeader_List_First(fhl);
-    while(fh) {
+    while (fh) {
       const char *s;
       uint64_t hpos;
 
       s=GWEN_SarFileHeader_GetPath(fh);
       hpos=GWEN_SarFileHeader_GetHashPos(fh);
       if (hpos==0) {
-	DBG_WARN(GWEN_LOGDOMAIN, "File %s has no valid hash", s?s:"(unnamed)");
+        DBG_WARN(GWEN_LOGDOMAIN, "File %s has no valid hash", s?s:"(unnamed)");
       }
       else {
-	/* seek to start of hash */
-	pos=GWEN_SyncIo_File_Seek(sr->archiveSio, hpos, GWEN_SyncIo_File_Whence_Set);
-	if (pos<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", (int) pos);
-	  GWEN_Gui_ProgressEnd(pid);
-	  GWEN_MDigest_free(md);
-	  return (int) pos;
-	}
+        /* seek to start of hash */
+        pos=GWEN_SyncIo_File_Seek(sr->archiveSio, hpos, GWEN_SyncIo_File_Whence_Set);
+        if (pos<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", (int) pos);
+          GWEN_Gui_ProgressEnd(pid);
+          GWEN_MDigest_free(md);
+          return (int) pos;
+        }
 
-	/* read hash */
-	rv=GWEN_SyncIo_ReadForced(sr->archiveSio, hashBuf, 20);
-	if (rv<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	  GWEN_Gui_ProgressEnd(pid);
-	  GWEN_MDigest_free(md);
-	  return rv;
-	}
+        /* read hash */
+        rv=GWEN_SyncIo_ReadForced(sr->archiveSio, hashBuf, 20);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Gui_ProgressEnd(pid);
+          GWEN_MDigest_free(md);
+          return rv;
+        }
 
-	/* digest hash */
-	rv=GWEN_MDigest_Update(md, hashBuf, 20);
-	if (rv<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	  GWEN_Gui_ProgressEnd(pid);
-	  GWEN_MDigest_free(md);
-	  return rv;
-	}
+        /* digest hash */
+        rv=GWEN_MDigest_Update(md, hashBuf, 20);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Gui_ProgressEnd(pid);
+          GWEN_MDigest_free(md);
+          return rv;
+        }
 
 
-	GWEN_SarFileHeader_AddFlags(fh, GWEN_SAR_FILEHEADER_FLAGS_SIGNED);
+        GWEN_SarFileHeader_AddFlags(fh, GWEN_SAR_FILEHEADER_FLAGS_SIGNED);
       }
 
       rv=GWEN_Gui_ProgressAdvance(pid, GWEN_GUI_PROGRESS_ONE);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
         GWEN_Gui_ProgressEnd(pid);
-	GWEN_MDigest_free(md);
+        GWEN_MDigest_free(md);
         return rv;
       }
 
@@ -2019,9 +2065,9 @@ int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
     /* sign hash */
     sbuf=GWEN_Buffer_new(0, 256, 0, 1);
     rv=GWEN_CryptMgr_Sign(cm,
-			  GWEN_MDigest_GetDigestPtr(md),
-			  GWEN_MDigest_GetDigestSize(md),
-			  sbuf);
+                          GWEN_MDigest_GetDigestPtr(md),
+                          GWEN_MDigest_GetDigestSize(md),
+                          sbuf);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(sbuf);
@@ -2034,9 +2080,9 @@ int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
     /* create signature TLV */
     tbuf=GWEN_Buffer_new(0, 256, 0, 1);
     rv=GWEN_TLV_DirectlyToBuffer(GWEN_SAR_TAG_SIGNATURE, 0x00,
-				 GWEN_Buffer_GetStart(sbuf),
-				 GWEN_Buffer_GetUsedBytes(sbuf),
-				 1, tbuf);
+                                 GWEN_Buffer_GetStart(sbuf),
+                                 GWEN_Buffer_GetUsedBytes(sbuf),
+                                 1, tbuf);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(tbuf);
@@ -2054,11 +2100,11 @@ int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
       GWEN_Gui_ProgressEnd(pid);
       return (int) pos;
     }
-  
+
     /* write TLV into archive file */
     rv=GWEN_SyncIo_WriteForced(sr->archiveSio,
-			       (const uint8_t*) GWEN_Buffer_GetStart(tbuf),
-			       GWEN_Buffer_GetUsedBytes(tbuf));
+                               (const uint8_t *) GWEN_Buffer_GetStart(tbuf),
+                               GWEN_Buffer_GetUsedBytes(tbuf));
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(tbuf);
@@ -2079,7 +2125,8 @@ int GWEN_Sar_Sign(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
 
 
 
-int GWEN_Sar_Verify(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
+int GWEN_Sar_Verify(GWEN_SAR *sr, GWEN_CRYPTMGR *cm)
+{
   int rv;
   GWEN_SAR_FILEHEADER_LIST *fhl;
 
@@ -2117,7 +2164,7 @@ int GWEN_Sar_Verify(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
 
     /* clear SIGNED flags */
     fh=GWEN_SarFileHeader_List_First(fhl);
-    while(fh) {
+    while (fh) {
       GWEN_SarFileHeader_SubFlags(fh, GWEN_SAR_FILEHEADER_FLAGS_SIGNED);
       fh=GWEN_SarFileHeader_List_Next(fh);
     }
@@ -2128,56 +2175,56 @@ int GWEN_Sar_Verify(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
                                GWEN_GUI_PROGRESS_ALLOW_EMBED |
                                GWEN_GUI_PROGRESS_SHOW_PROGRESS,
                                I18N("File Operation"),
-			       I18N("Signing archive file"),
-			       GWEN_SarFileHeader_List_GetCount(fhl),
-			       0);
+                               I18N("Signing archive file"),
+                               GWEN_SarFileHeader_List_GetCount(fhl),
+                               0);
     fh=GWEN_SarFileHeader_List_First(fhl);
-    while(fh) {
+    while (fh) {
       const char *s;
       uint64_t hpos;
 
       s=GWEN_SarFileHeader_GetPath(fh);
       hpos=GWEN_SarFileHeader_GetHashPos(fh);
       if (hpos==0) {
-	DBG_WARN(GWEN_LOGDOMAIN, "File %s has no valid hash", s?s:"(unnamed)");
+        DBG_WARN(GWEN_LOGDOMAIN, "File %s has no valid hash", s?s:"(unnamed)");
       }
       else {
-	/* seek to start of hash */
-	pos=GWEN_SyncIo_File_Seek(sr->archiveSio, hpos, GWEN_SyncIo_File_Whence_Set);
-	if (pos<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", (int) pos);
-	  GWEN_Gui_ProgressEnd(pid);
-	  GWEN_MDigest_free(md);
-	  return (int) pos;
-	}
+        /* seek to start of hash */
+        pos=GWEN_SyncIo_File_Seek(sr->archiveSio, hpos, GWEN_SyncIo_File_Whence_Set);
+        if (pos<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", (int) pos);
+          GWEN_Gui_ProgressEnd(pid);
+          GWEN_MDigest_free(md);
+          return (int) pos;
+        }
 
-	/* read hash */
-	rv=GWEN_SyncIo_ReadForced(sr->archiveSio, hashBuf, 20);
-	if (rv<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	  GWEN_Gui_ProgressEnd(pid);
-	  GWEN_MDigest_free(md);
-	  return rv;
-	}
+        /* read hash */
+        rv=GWEN_SyncIo_ReadForced(sr->archiveSio, hashBuf, 20);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Gui_ProgressEnd(pid);
+          GWEN_MDigest_free(md);
+          return rv;
+        }
 
-	/* digest hash */
-	rv=GWEN_MDigest_Update(md, hashBuf, 20);
-	if (rv<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	  GWEN_Gui_ProgressEnd(pid);
-	  GWEN_MDigest_free(md);
-	  return rv;
-	}
+        /* digest hash */
+        rv=GWEN_MDigest_Update(md, hashBuf, 20);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          GWEN_Gui_ProgressEnd(pid);
+          GWEN_MDigest_free(md);
+          return rv;
+        }
 
 
-	GWEN_SarFileHeader_AddFlags(fh, GWEN_SAR_FILEHEADER_FLAGS_SIGNED);
+        GWEN_SarFileHeader_AddFlags(fh, GWEN_SAR_FILEHEADER_FLAGS_SIGNED);
       }
 
       rv=GWEN_Gui_ProgressAdvance(pid, GWEN_GUI_PROGRESS_ONE);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
         GWEN_Gui_ProgressEnd(pid);
-	GWEN_MDigest_free(md);
+        GWEN_MDigest_free(md);
         return rv;
       }
 
@@ -2205,8 +2252,8 @@ int GWEN_Sar_Verify(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
     /* read signature data */
     sbuf=GWEN_Buffer_new(0, sr->signatureSize, 0, 1);
     rv=GWEN_SyncIo_ReadForced(sr->archiveSio,
-			      (uint8_t*) GWEN_Buffer_GetStart(sbuf),
-			      sr->signatureSize);
+                              (uint8_t *) GWEN_Buffer_GetStart(sbuf),
+                              sr->signatureSize);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(sbuf);
@@ -2220,9 +2267,9 @@ int GWEN_Sar_Verify(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
     /* verify signature */
     hbuf=GWEN_Buffer_new(0, 256, 0, 1);
     rv=GWEN_CryptMgr_Verify(cm,
-			    (const uint8_t*) GWEN_Buffer_GetStart(sbuf),
-			    GWEN_Buffer_GetUsedBytes(sbuf),
-			    hbuf);
+                            (const uint8_t *) GWEN_Buffer_GetStart(sbuf),
+                            GWEN_Buffer_GetUsedBytes(sbuf),
+                            hbuf);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       GWEN_Buffer_free(hbuf);
@@ -2261,7 +2308,8 @@ int GWEN_Sar_Verify(GWEN_SAR *sr, GWEN_CRYPTMGR *cm) {
 
 
 
-int GWEN_Sar_VerifyArchive(const char *inFile, const char *signer, GWEN_CRYPT_KEY *key) {
+int GWEN_Sar_VerifyArchive(const char *inFile, const char *signer, GWEN_CRYPT_KEY *key)
+{
   GWEN_SAR *sr;
   int rv;
 
@@ -2306,7 +2354,8 @@ int GWEN_Sar_VerifyArchive(const char *inFile, const char *signer, GWEN_CRYPT_KE
 
 
 
-int GWEN_Sar_SignArchive(const char *inFile, const char *signer, GWEN_CRYPT_KEY *key) {
+int GWEN_Sar_SignArchive(const char *inFile, const char *signer, GWEN_CRYPT_KEY *key)
+{
   GWEN_SAR *sr;
   int rv;
 
@@ -2351,7 +2400,8 @@ int GWEN_Sar_SignArchive(const char *inFile, const char *signer, GWEN_CRYPT_KEY
 
 
 
-int GWEN_Sar_CheckArchive(const char *inFile) {
+int GWEN_Sar_CheckArchive(const char *inFile)
+{
   GWEN_SAR *sr;
   int rv;
   const GWEN_SAR_FILEHEADER_LIST *fhl;
@@ -2381,16 +2431,16 @@ int GWEN_Sar_CheckArchive(const char *inFile) {
                                0);
 
     fh=GWEN_SarFileHeader_List_First(fhl);
-    while(fh) {
-      const char *s;
+    while (fh) {
+      //const char *s;
 
-      s=GWEN_SarFileHeader_GetPath(fh);
+      //s=GWEN_SarFileHeader_GetPath(fh);
       rv=GWEN_Sar_CheckFile(sr, fh);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
         GWEN_Gui_ProgressEnd(pid);
-	GWEN_Sar_CloseArchive(sr, 1);
-	GWEN_Sar_free(sr);
+        GWEN_Sar_CloseArchive(sr, 1);
+        GWEN_Sar_free(sr);
       }
 
       rv=GWEN_Gui_ProgressAdvance(pid, GWEN_GUI_PROGRESS_ONE);
