@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Thu Jul 02 2009
-    copyright   : (C) 2009 by Martin Preuss
+    copyright   : (C) 2018 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -25,6 +25,8 @@ GWEN_LIST_FUNCTION_DEFS(TYPEMAKER2_MEMBER, Typemaker2_Member);
 #include "tm_type.h"
 #include "tm_enum.h"
 #include "tm_define.h"
+#include "tm_group.h"
+#include "tm_code.h"
 
 
 TYPEMAKER2_MEMBER *Typemaker2_Member_new();
@@ -38,6 +40,12 @@ void Typemaker2_Member_SetName(TYPEMAKER2_MEMBER *tm, const char *s);
 const char *Typemaker2_Member_GetTypeName(const TYPEMAKER2_MEMBER *tm);
 void Typemaker2_Member_SetTypeName(TYPEMAKER2_MEMBER *tm, const char *s);
 
+const char *Typemaker2_Member_GetElementName(const TYPEMAKER2_MEMBER *tm);
+void Typemaker2_Member_SetElementName(TYPEMAKER2_MEMBER *tm, const char *s);
+
+const char *Typemaker2_Member_GetDescription(const TYPEMAKER2_MEMBER *tm);
+void Typemaker2_Member_SetDescription(TYPEMAKER2_MEMBER *tm, const char *s);
+
 const char *Typemaker2_Member_GetFieldId(const TYPEMAKER2_MEMBER *tm);
 void Typemaker2_Member_SetFieldId(TYPEMAKER2_MEMBER *tm, const char *s);
 
@@ -59,6 +67,9 @@ void Typemaker2_Member_SetGetFlags(TYPEMAKER2_MEMBER *tm, uint32_t i);
 uint32_t Typemaker2_Member_GetDupFlags(const TYPEMAKER2_MEMBER *tm);
 void Typemaker2_Member_SetDupFlags(TYPEMAKER2_MEMBER *tm, uint32_t i);
 
+uint32_t Typemaker2_Member_GetCopyFlags(const TYPEMAKER2_MEMBER *tm);
+void Typemaker2_Member_SetCopyFlags(TYPEMAKER2_MEMBER *tm, uint32_t i);
+
 TYPEMAKER2_TYPE *Typemaker2_Member_GetTypePtr(const TYPEMAKER2_MEMBER *tm);
 void Typemaker2_Member_SetTypePtr(TYPEMAKER2_MEMBER *tm, TYPEMAKER2_TYPE *ty);
 
@@ -68,6 +79,9 @@ void Typemaker2_Member_SetEnumPtr(TYPEMAKER2_MEMBER *tm, TYPEMAKER2_ENUM *te);
 TYPEMAKER2_DEFINE *Typemaker2_Member_GetDefinePtr(const TYPEMAKER2_MEMBER *tm);
 void Typemaker2_Member_SetDefinePtr(TYPEMAKER2_MEMBER *tm, TYPEMAKER2_DEFINE *td);
 
+TYPEMAKER2_GROUP *Typemaker2_Member_GetGroupPtr(const TYPEMAKER2_MEMBER *tm);
+void Typemaker2_Member_SetGroupPtr(TYPEMAKER2_MEMBER *tm, TYPEMAKER2_GROUP *gr);
+
 int Typemaker2_Member_GetAccess(const TYPEMAKER2_MEMBER *tm);
 void Typemaker2_Member_SetAccess(TYPEMAKER2_MEMBER *tm, int i);
 
@@ -86,7 +100,9 @@ void Typemaker2_Member_SetAqDbType(TYPEMAKER2_MEMBER *tm, const char *s);
 int Typemaker2_Member_GetMemberPosition(const TYPEMAKER2_MEMBER *tm);
 void Typemaker2_Member_SetMemberPosition(TYPEMAKER2_MEMBER *tm, int i);
 
-int Typemaker2_Member_readXml(TYPEMAKER2_MEMBER *tm, GWEN_XMLNODE *node);
+TYPEMAKER2_CODE_LIST *Typemaker2_Member_GetCodeDefs(const TYPEMAKER2_MEMBER *tm);
+
+int Typemaker2_Member_readXml(TYPEMAKER2_MEMBER *tm, GWEN_XMLNODE *node, const char *wantedLang);
 
 
 void Typemaker2_Member_Dump(TYPEMAKER2_MEMBER *tm, FILE *f, int indent);
